@@ -31,9 +31,6 @@ int main( int /*argc*/, char ** argv)
     if(getenv("SRCDIR") != 0)
       srcdir = getenv("SRCDIR");
     
-    // Common font to use.
-    string font = "Helvetica";
-
     list<Image> montage;
 
     {
@@ -80,9 +77,8 @@ int main( int /*argc*/, char ** argv)
       example.label( "Annotate" );
       example.density( "72x72" );
       example.fontPointsize( 18 );
-      example.font( font );
       example.strokeColor( Color() );
-      example.fillColor( "gold" );
+      example.fillColor( "goldenrod" );
       example.annotate( "Magick++", "+0+20", NorthGravity );
       images.push_back( example );
 
@@ -95,7 +91,7 @@ int main( int /*argc*/, char ** argv)
       cout << "  border ..." << endl;
       example = model;
       example.label( "Border" );
-      example.borderColor( "gold" );
+      example.borderColor( "goldenrod" );
       example.border( Geometry(6,6) );
       images.push_back( example );
 
@@ -149,7 +145,7 @@ int main( int /*argc*/, char ** argv)
       example = model;
       example.label( "Draw" );
       example.fillColor(Color());
-      example.strokeColor( "gold" );
+      example.strokeColor( "goldenrod" );
       example.strokeWidth( 2 );
       example.draw( DrawableCircle( 60,90, 60,120 ) );
       images.push_back( example );
@@ -229,6 +225,18 @@ int main( int /*argc*/, char ** argv)
       example.implode( 0.5 );
       images.push_back( example );
 
+      cout << "  level ..." << endl;
+      example = model;
+      example.label( "Level" );
+      example.level( 0.20*QuantumRange, 0.90*QuantumRange, 1.20 );
+      images.push_back( example );
+
+      cout << "  level red channel ..." << endl;
+      example = model;
+      example.label( "Level Red" );
+      example.levelChannel( RedChannel, 0.20*QuantumRange, 0.90*QuantumRange, 1.20 );
+      images.push_back( example );
+
       cout << "  median filter ..." << endl;
       example = model;
       example.label( "Median Filter" );
@@ -388,7 +396,6 @@ int main( int /*argc*/, char ** argv)
       //
       cout <<  "Montage images..." << endl;
 
-      for_each( images.begin(), images.end(), fontImage( font ) );
       for_each( images.begin(), images.end(), strokeColorImage( Color("#600") ) );
 
       MontageFramed montageOpts;
@@ -399,7 +406,6 @@ int main( int /*argc*/, char ** argv)
       montageOpts.tile( "5x12" );
       montageOpts.compose( OverCompositeOp );
       montageOpts.backgroundColor( "#ffffff" );
-      montageOpts.font( font );
       montageOpts.pointSize( 18 );
       montageOpts.fillColor( "#600" );
       montageOpts.strokeColor( Color() );
@@ -422,7 +428,7 @@ int main( int /*argc*/, char ** argv)
 
     cout << "Writing image \"demo_out.miff\" ..." << endl;
     montage_image.matte( false );
-    montage_image.compressType( RunlengthEncodedCompression );
+    montage_image.compressType( RLECompression );
     montage_image.write( "demo_out.miff" );
 
     // Uncomment following lines to display image to screen
