@@ -228,7 +228,7 @@ Magick::DrawableAffine::DrawableAffine( double sx_, double sy_,
 }
 Magick::DrawableAffine::DrawableAffine( void )
 {
-  IdentityAffine(&_affine);
+  GetAffineMatrix(&_affine);
 }
 Magick::DrawableAffine::~DrawableAffine( void )
 {
