@@ -294,8 +294,7 @@ MagickDLLDecl void Magick::throwException( ExceptionInfo &exception_ )
 
 
   ExceptionType severity = exception_.severity;
-  DestroyExceptionInfo( &exception_ );
-  GetExceptionInfo( &exception_ );
+  ClearMagickException( &exception_ );
 
   switch ( severity )
     {
