@@ -196,10 +196,10 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
     {
       char *pageptr = GetPageGeometry( geom );
       if ( pageptr != 0 )
-	{
-	  (void) CopyMagickString(geom,pageptr,MaxTextExtent);
-	  pageptr=(char *) RelinquishMagickMemory( pageptr );
-	}
+        {
+          (void) CopyMagickString(geom,pageptr,MaxTextExtent);
+          pageptr=(char *) RelinquishMagickMemory( pageptr );
+        }
     }
 
   long x = 0;
@@ -223,7 +223,10 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
     }
 
   if ( ( flags & HeightValue ) != 0 )
-    _height = height_val;
+    {
+      _height = height_val;
+      isValid( true );
+    }
 
   if ( ( flags & XValue ) != 0 )
     {
@@ -279,13 +282,13 @@ Magick::Geometry::operator std::string() const
 
   if ( _width )
     {
-      FormatString( buffer, "%u", _width );
+      FormatMagickString( buffer, MaxTextExtent, "%u", _width );
       geometry += buffer;
     }
 
-  if ( _width && _height )
+  if ( _height )
     {
-      FormatString( buffer, "%u",  _height);
+      FormatMagickString( buffer, MaxTextExtent, "%u",  _height);
       geometry += 'x';
       geometry +=  buffer;
     }
@@ -297,7 +300,7 @@ Magick::Geometry::operator std::string() const
       else
         geometry += '+';
 
-      FormatString( buffer, "%u", _xOff);
+      FormatMagickString( buffer, MaxTextExtent, "%u", _xOff);
       geometry += buffer;
 
       if ( _yNegative )
@@ -305,7 +308,7 @@ Magick::Geometry::operator std::string() const
       else
         geometry += '+';
 
-      FormatString( buffer, "%u", _yOff);
+      FormatMagickString( buffer, MaxTextExtent, "%u", _yOff);
       geometry += buffer;
     }
 
