@@ -762,9 +762,12 @@ namespace Magick
     unsigned int    colorMapSize ( void );
 
     // Image Color Space
-    void            colorSpace( const ColorspaceType colorSpace_ );
+    void            colorSpace ( const ColorspaceType colorSpace_ );
     ColorspaceType  colorSpace ( void ) const;
 
+    void            colorspaceType ( const ColorspaceType colorSpace_ );
+    ColorspaceType  colorspaceType ( void ) const;
+
     // Image width
     unsigned int    columns ( void ) const;
     
