@@ -400,6 +400,9 @@ namespace Magick
   using MagickLib::AbsoluteIntent;
   using MagickLib::RelativeIntent;
   
+  // Resource types
+  using MagickLib::MemoryResource;
+
   // Resolution units
   using MagickLib::ResolutionType;
   using MagickLib::UndefinedResolution;
@@ -465,6 +468,7 @@ namespace Magick
   using MagickLib::AspectValue;
   using MagickLib::Base64Decode;
   using MagickLib::Base64Encode;
+  using MagickLib::BilevelImage;
   using MagickLib::BlobError;
   using MagickLib::BlobFatalError;
   using MagickLib::BlobToImage;
@@ -474,7 +478,6 @@ namespace Magick
   using MagickLib::CacheError;
   using MagickLib::CacheFatalError;
   using MagickLib::CacheWarning;
-  using MagickLib::ChannelImage;
   using MagickLib::CharcoalImage;
   using MagickLib::ChopImage;
   using MagickLib::ClearMagickException;
@@ -517,7 +520,6 @@ namespace Magick
   using MagickLib::DestroyPixelWand;
   using MagickLib::DestroyQuantizeInfo;
   using MagickLib::DestroyStringInfo;
-  using MagickLib::DispatchImage;
   using MagickLib::DisplayImages;
   using MagickLib::DrawAffine;
   using MagickLib::DrawAllocateWand;
@@ -615,6 +617,7 @@ namespace Magick
   using MagickLib::ExceptionInfo;
   using MagickLib::ExceptionType;
   using MagickLib::ExecuteModuleProcess;
+  using MagickLib::ExportImagePixels;
   using MagickLib::ExportQuantumPixels;
   using MagickLib::FileOpenError;
   using MagickLib::FileOpenFatalError;
@@ -622,12 +625,14 @@ namespace Magick
   using MagickLib::FlattenImages;
   using MagickLib::FlipImage;
   using MagickLib::FlopImage;
-  using MagickLib::FormatString;
+  using MagickLib::FormatMagickString;
   using MagickLib::FrameImage;
   using MagickLib::FrameInfo;
   using MagickLib::GammaImage;
   using MagickLib::GammaImage;
   using MagickLib::GaussianBlurImage;
+  using MagickLib::GetAffineMatrix;
+  using MagickLib::GetBlobSize;
   using MagickLib::GetCacheView;
   using MagickLib::GetCacheViewIndexes;
   using MagickLib::GetImageChannelExtrema;
@@ -648,7 +653,6 @@ namespace Magick
   using MagickLib::GetImageQuantizeError;
   using MagickLib::GetImageType;
   using MagickLib::GetIndexes;
-  using MagickLib::GetMagickGeometry;
   using MagickLib::GetMagickInfo;
   using MagickLib::GetMagickRegistry;
   using MagickLib::GetNumberColors;
@@ -663,7 +667,6 @@ namespace Magick
   using MagickLib::GreaterValue;
   using MagickLib::HSLTransform;
   using MagickLib::HeightValue;
-  using MagickLib::IdentityAffine;
   using MagickLib::ImageError;
   using MagickLib::ImageFatalError;
   using MagickLib::ImageInfo;
@@ -676,7 +679,6 @@ namespace Magick
   using MagickLib::IsEventLogging;
   using MagickLib::IsGeometry;
   using MagickLib::IsImagesEqual;
-  using MagickLib::IsSubimage;
   using MagickLib::LessValue;
   using MagickLib::LevelImage;
   using MagickLib::LevelImageChannel;
@@ -709,12 +711,14 @@ namespace Magick
   using MagickLib::NoiseType;
   using MagickLib::NormalizeImage;
   using MagickLib::OilPaintImage;
-  using MagickLib::OpaqueImage;
   using MagickLib::OpenCacheView;
   using MagickLib::OptionError;
   using MagickLib::OptionFatalError;
   using MagickLib::OptionWarning;
+  using MagickLib::ParseMetaGeometry;
   using MagickLib::PercentValue;
+  using MagickLib::PaintOpaqueImage;
+  using MagickLib::PaintTransparentImage;
   using MagickLib::PingBlob;
   using MagickLib::PingImage;
   using MagickLib::PixelSetQuantumColor;
@@ -726,6 +730,7 @@ namespace Magick
   using MagickLib::QuantizeInfo;
   using MagickLib::QuantumInfo;
   using MagickLib::QueryColorDatabase;
+  using MagickLib::QueryMagickColor;
   using MagickLib::RGBTransformImage;
   using MagickLib::RaiseImage;
   using MagickLib::ReadImage;
@@ -749,10 +754,10 @@ namespace Magick
   using MagickLib::SampleImage;
   using MagickLib::ScaleImage;
   using MagickLib::SegmentImage;
-  using MagickLib::SetCacheThreshold;
+  using MagickLib::SeparateImageChannel;
   using MagickLib::SetCacheView;
   using MagickLib::SetClientName;
-  using MagickLib::SetImage;
+  using MagickLib::SetImageBackgroundColor;
   using MagickLib::SetImageChannelDepth;
   using MagickLib::SetImageClipMask;
   using MagickLib::SetImageDepth;
@@ -767,6 +772,7 @@ namespace Magick
   using MagickLib::SetLogEventMask;
   using MagickLib::SetMagickInfo;
   using MagickLib::SetMagickRegistry;
+  using MagickLib::SetMagickResourceLimit;
   using MagickLib::SetStringInfoDatum;
   using MagickLib::ShadeImage;
   using MagickLib::SharpenImage;
@@ -774,7 +780,6 @@ namespace Magick
   using MagickLib::ShearImage;
   using MagickLib::SigmoidalContrastImageChannel;
   using MagickLib::SignatureImage;
-  using MagickLib::SizeBlob;
   using MagickLib::SolarizeImage;
   using MagickLib::SpreadImage;
   using MagickLib::SteganoImage;
@@ -788,12 +793,10 @@ namespace Magick
   using MagickLib::SyncImage;
   using MagickLib::SyncImagePixels;
   using MagickLib::TextureImage;
-  using MagickLib::ThresholdImage;
   using MagickLib::ThrowException;
   using MagickLib::TransformHSL;
   using MagickLib::TransformImage;
   using MagickLib::TransformRGBImage;
-  using MagickLib::TransparentImage;
   using MagickLib::TrimImage;
   using MagickLib::TypeError;
   using MagickLib::TypeFatalError;
