@@ -788,6 +788,18 @@ namespace Magick
     unsigned int _order;
   };
 
+  // Resize image to specified size.
+  class MagickDLLDecl resizeImage : public std::unary_function<Image&,void>
+  {
+  public:
+    resizeImage( const Geometry &geometry_ );
+
+    void operator()( Image &image_ ) const;
+
+  private:
+    Geometry _geometry;
+  };
+
   // Roll image (rolls image vertically and horizontally) by specified
   // number of columnms and rows)
   class MagickDLLDecl rollImage : public std::unary_function<Image&,void>
@@ -1907,7 +1919,7 @@ namespace Magick
     // Clear out container
     container_->clear();
 
-    for ( int i=0; i < number_formats; i++)
+    for ( int i=0; i < (long) number_formats; i++)
       {
         const MagickLib::MagickInfo *magick_info =
           MagickLib::GetMagickInfo( coder_list[i], &exceptionInfo );
