@@ -976,6 +976,16 @@ void Magick::waveImage::operator()( Magick::Image &image_ ) const
   image_.wave( _amplitude, _wavelength );
 }
 
+// resize image to specified size.
+Magick::resizeImage::resizeImage( const Magick::Geometry &geometry_ )
+  : _geometry( geometry_ )
+{
+}
+void Magick::resizeImage::operator()( Magick::Image &image_ ) const
+{
+  image_.resize( _geometry );
+}
+
 // Zoom image to specified size.
 Magick::zoomImage::zoomImage( const Magick::Geometry &geometry_ )
   : _geometry( geometry_ )
