@@ -30,6 +30,18 @@ $smile->Set(background=>'white');
 print "Transform image...\n";
 $images=Image::Magick->new();
 
+print "Adaptive Blur...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Blur');
+$example->AdaptiveBlur('0x1');
+push(@$images,$example);
+
+print "Adaptive Resize...\n";
+$example=$model->Clone();
+$example->Label('Adaptive Resize');
+$example->AdaptiveResize('60%');
+push(@$images,$example);
+
 print "Adaptive Sharpen...\n";
 $example=$model->Clone();
 $example->Label('Adaptive Sharpen');
@@ -258,6 +270,12 @@ warn "$x" if "$x";
 $plasma->Label('Plasma');
 push(@$images,$plasma);
 
+print "Polaroid...\n";
+$example=$model->Clone();
+$example->Label('Polaroid');
+$example->Polaroid(caption=>'Magick',rotate=>-5.0,gravity=>'center');
+push(@$images,$example);
+
 print "Quantize...\n";
 $example=$model->Clone();
 $example->Label('Quantize');
@@ -276,6 +294,13 @@ $example->Label('Raise');
 $example->Raise('10x10');
 push(@$images,$example);
 
+push(@$images,$example);
+print "Recolor...\n";
+$example=$model->Clone();
+$example->Label('Recolor');
+$example->Recolor([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
+push(@$images,$example);
+
 print "Reduce Noise...\n";
 $example=$model->Clone();
 $example->Label('Reduce Noise');
@@ -389,7 +414,8 @@ push(@$images,$example);
 print "Montage...\n";
 $montage=$images->Montage(geometry=>'128x160+8+4>',gravity=>'Center',
   tile=>'5x+10+200',compose=>'over',background=>'#ffffff',
-  font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none');
+  font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none',
+	shadow=>'true');
 
 $logo=Image::Magick->new();
 $logo->Read('logo:');
