@@ -1,5 +1,17 @@
-# Copyright (C) 1994-2004 ImageMagick Studio LLC
-# Copyright (C) 2003 GraphicsMagick Group
+#  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+#  dedicated to making software imaging solutions freely available.
+#
+#  You may not use this file except in compliance with the License.  You may
+#  obtain a copy of the License at
+#
+#    http://www.imagemagick.org/script/license.php
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+#
 #
 # Common subroutines to support tests
 #
@@ -18,21 +30,21 @@ sub quantumDepth ( ) {
 }
 
 #
-# Establish some global constants (MaxRGB, OpaqueOpacity, & QuantumDepth)
+# Establish some global constants (QuantumRange, OpaqueOpacity, & QuantumDepth)
 #
 $QuantumDepth=quantumDepth();
 $OpaqueOpacity=0;
 if ($QuantumDepth == 8)
   {
-    $MaxRGB=255;
+    $QuantumRange=255;
   }
 elsif ($QuantumDepth == 16)
   {
-    $MaxRGB=65535;
+    $QuantumRange=65535;
   }
 elsif ($QuantumDepth == 32)
   {
-    $MaxRGB=4294967295;
+    $QuantumRange=4294967295;
   }
 
 #
@@ -180,7 +192,7 @@ sub testCompositeCompare {
 # Test reading a 16-bit file in which two signatures are possible,
 # depending on whether 16-bit pixels data has been enabled
 #
-# Usage: testRead( read filename, expected ref_8 [, expected ref_16] );
+# Usage: testRead( read filename, expected ref_8 [, expected ref_16] [, expected ref_32] );
 #
 sub testRead {
   my( $infile, $ref_8, $ref_16, $ref_32 ) =  @_;
@@ -358,14 +370,27 @@ sub testReadCompare {
 #      goto COMPARE_RUNTIME_ERROR;
 #    }
 
-  $status=$srcimage->Compare($refimage);
-  if ("$status")
+  # Verify that $srcimage and $refimage contain the same number of frames.
+  if ( $#srcimage != $#refimage )
     {
-      $errorinfo = "Compare($refimage_name): $status";
+      $errorinfo = "Source and reference images contain different number of frames ($#srcimage != $#refimage)";
       warn("$errorinfo");
       goto COMPARE_RUNTIME_ERROR;
     }
 
+  # Compare each frame in the sequence.
+  for ($index = 0; $srcimage->[$index] && $refimage->[$index]; $index++)
+    {
+      $status=$srcimage->[$index]->Compare($refimage->[$index]);
+      if ("$status")
+        {
+          $errorinfo = "Compare($refimage_name)->[$index]: $status";
+          warn("$errorinfo");
+          goto COMPARE_RUNTIME_ERROR;
+        }
+    }
+
+
   $normalized_mean_error=0;
   $normalized_mean_error=$srcimage->GetAttribute('mean-error');
   if ( !defined($normalized_mean_error) )
@@ -407,7 +432,7 @@ sub testReadCompare {
 # Test reading a file which requires a file size to read (GRAY, RGB, CMYK)
 # or supports multiple resolutions (JBIG, JPEG, PCD)
 #
-# Usage: testRead( read filename, size, depth, expected ref_8 [, expected ref_16] );
+# Usage: testRead( read filename, size, depth, expected ref_8 [, expected ref_16] [, expected ref_32] );
 #
 sub testReadSized {
   my( $infile, $size, $depth, $ref_8, $ref_16, $ref_32 ) =  @_;
