@@ -18,7 +18,7 @@
 %                                March  2004                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -428,7 +428,7 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
   for (p=comment; i-- >= 0; p++)
     *p=(char) GetCharacter(jpeg_info);
   *p='\0';
-  (void) SetImageProperty(image,"Comment",comment);
+  (void) SetImageProperty(image,"comment",comment);
   comment=DestroyString(comment);
   return(MagickTrue);
 }
@@ -1248,7 +1248,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               LosslessJPEGCompression : JPEGCompression;
             if (jpeg_info.data_precision > 8)
               (void) ThrowMagickException(exception,GetMagickModule(),
-                OptionError,
+                OptionWarning,
                 "12-bit JPEG not supported. Reducing pixel data to 8 bits",
                 "`%s'",image->filename);
 #else
@@ -1614,7 +1614,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             (void) FormatMagickString(message,MaxTextExtent,
               "AVI compression %s not yet supported",bmp_info.compression);
             (void) ThrowMagickException(exception,GetMagickModule(),
-              CorruptImageError,message,"`%s'",image->filename);
+              CorruptImageWarning,message,"`%s'",image->filename);
             for ( ; chunk_size != 0; chunk_size--)
               (void) ReadBlobByte(image);
             continue;
@@ -2088,7 +2088,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     (void) FormatMagickString(message,MaxTextExtent,
       "AVI chunk %s not yet supported",id);
-    (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageError,
+    (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageWarning,
       message,"`%s'",image->filename);
     for ( ; chunk_size != 0; chunk_size--)
       (void) ReadBlobByte(image);
