@@ -18,7 +18,7 @@
 %                               December 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -865,7 +865,9 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           packet_size=3;
         else
           packet_size=4;
-        (void) SeekBlob(image,start_position+14+bmp_info.size,SEEK_SET);
+        offset=SeekBlob(image,start_position+14+bmp_info.size,SEEK_SET);
+        if (offset < 0)
+          ThrowReaderException(CorruptImageError,"ImproperImageHeader");
         count=ReadBlob(image,packet_size*image->colors,bmp_colormap);
         if (count != (ssize_t) (packet_size*image->colors))
           ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
@@ -886,7 +888,9 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read image data.
     */
-    (void) SeekBlob(image,start_position+bmp_info.offset_bits,SEEK_SET);
+    offset=SeekBlob(image,start_position+bmp_info.offset_bits,SEEK_SET);
+    if (offset < 0)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     if (bmp_info.compression == BI_RLE4)
       bmp_info.bits_per_pixel<<=1;
     bytes_per_line=4*((image->columns*bmp_info.bits_per_pixel+31)/32);
@@ -1095,7 +1099,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(MagickOffsetType) image->rows-y-1;
+          offset=(ssize_t) image->rows-y-1;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1163,7 +1167,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(MagickOffsetType) image->rows-y-1;
+          offset=(ssize_t) image->rows-y-1;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1197,7 +1201,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(MagickOffsetType) image->rows-y-1;
+          offset=(ssize_t) image->rows-y-1;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1258,7 +1262,7 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
           if (SyncImagePixels(image) == MagickFalse)
             break;
-          offset=(MagickOffsetType) image->rows-y-1;
+          offset=(ssize_t) image->rows-y-1;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                 (QuantumTick(offset,image->rows) != MagickFalse))
@@ -1306,7 +1310,11 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
     *magick='\0';
     if (bmp_info.ba_offset != 0)
-      (void) SeekBlob(image,(MagickOffsetType) bmp_info.ba_offset,SEEK_SET);
+      {
+        offset=SeekBlob(image,(MagickOffsetType) bmp_info.ba_offset,SEEK_SET);
+        if (offset < 0)
+          ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+      }
     count=ReadBlob(image,2,magick);
     if ((count == 2) && (IsBMP(magick,2) != MagickFalse))
       {
