@@ -20,7 +20,7 @@
 %                               October 2003                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -239,6 +239,9 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   MagickBooleanType
     status;
 
+  MagickOffsetType
+    offset;
+
   QuantumInfo
     quantum_info;
 
@@ -301,7 +304,9 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   (void) ReadBlobByte(image);
   image->columns=ReadBlobLong(image);
   image->rows=ReadBlobLong(image);
-  (void) SeekBlob(image,(MagickOffsetType) headersize,SEEK_SET);
+  offset=SeekBlob(image,(MagickOffsetType) headersize,SEEK_SET);
+  if (offset < 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   if (image_info->ping)
     {
       CloseBlob(image);
