@@ -306,6 +306,10 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image *image,*palette;
   ImageInfo *clone_info;
   MagickBooleanType status;
+
+  MagickOffsetType
+    offset;
+
   unsigned long EncodedByte;
   unsigned char RunCount,RunValue,RunCountMasked;
   CUTHeader  Header;
@@ -357,7 +361,9 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     {
       i=1;
       if((int) RunCount<0x80) i=(long) RunCountMasked;
-      (void) SeekBlob(image,TellBlob(image)+i,SEEK_SET);
+      offset=SeekBlob(image,TellBlob(image)+i,SEEK_SET);
+      if (offset < 0)
+        ThrowReaderException(CorruptImageError,"ImproperImageHeader");
       if(EOFBlob(image) != MagickFalse) goto CUT_KO;  /*wrong data*/
       EncodedByte-=i+1;
       ldblk+=(long) RunCountMasked;
@@ -459,13 +465,16 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if((j % 512)>512-6)
             {
               j=((j / 512)+1)*512;
-              (void) SeekBlob(palette,j,SEEK_SET);
+              offset=SeekBlob(palette,j,SEEK_SET);
+              if (offset < 0)
+                ThrowReaderException(CorruptImageError,"ImproperImageHeader");
             }
           image->colormap[i].red=ReadBlobLSBShort(palette);
           if(QuantumRange!=(Quantum) PalHeader.MaxRed)
             {
-              image->colormap[i].red=(Quantum)
-                (((double) image->colormap[i].red*QuantumRange+(PalHeader.MaxRed>>1))/PalHeader.MaxRed+0.5);
+              image->colormap[i].red=(Quantum) (((double)
+                image->colormap[i].red*QuantumRange+(PalHeader.MaxRed>>1))/
+                PalHeader.MaxRed+0.5);
             }
           image->colormap[i].green=ReadBlobLSBShort(palette);
           if(QuantumRange!=(Quantum) PalHeader.MaxGreen)
@@ -509,9 +518,11 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   BImgBuff=(unsigned char *) AcquireMagickMemory((size_t) ldblk);  /*Ldblk was set in the check phase*/
   if(BImgBuff==NULL) goto NoMemory;
 
-  (void) SeekBlob(image,6 /*sizeof(Header)*/,SEEK_SET);
-  for(i=0;i<(int) Header.Height;i++)
-    {
+  offset=SeekBlob(image,6 /*sizeof(Header)*/,SEEK_SET);
+  if (offset < 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  for (i=0; i < (int) Header.Height; i++)
+  {
       EncodedByte=ReadBlobLSBShort(image);
 
       ptrB=BImgBuff;
