@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -188,8 +188,8 @@ ModuleExport void RegisterDOTImage(void)
   entry->decoder=(DecoderHandler *) ReadDOTImage;
 #endif
   entry->blob_support=MagickFalse;
-  entry->description=AcquireString("Graphviz");
-  entry->module=AcquireString("DOT");
+  entry->description=ConstantString("Graphviz");
+  entry->module=ConstantString("DOT");
   (void) RegisterMagickInfo(entry);
 #if defined(HasGVC)
   graphic_context=gvContext();
@@ -219,6 +219,6 @@ ModuleExport void UnregisterDOTImage(void)
 {
   (void) UnregisterMagickInfo("DOT");
 #if defined(HasGVC)
-  gvCleanup(graphic_context);
+  gvFreeContext(graphic_context);
 #endif
 }
