@@ -17,7 +17,7 @@
 %                                March 2001                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/option.h"
+#include "magick/profile.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
-#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/version.h"
@@ -614,7 +615,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ReadBlob(image,sizeof(dpx.file.timestamp),(unsigned char *)
     dpx.file.timestamp);
   if (*dpx.file.timestamp != '\0')
-    (void) FormatImageProperty(image,"dpx:file.tilestamp","%.24s",
+    (void) FormatImageProperty(image,"dpx:file.timestamp","%.24s",
       dpx.file.timestamp);
   (void) ReadBlob(image,sizeof(dpx.file.creator),(unsigned char *)
     dpx.file.creator);
@@ -799,6 +800,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       TimeCodeToString(dpx.television.time_code,value);
       (void) SetImageProperty(image,"dpx:television.time.code",value);
       dpx.television.user_bits=(unsigned char) ReadBlobLong(image);
+      TimeCodeToString(dpx.television.user_bits,value);
+      (void) SetImageProperty(image,"dpx:television.user.bits",value);
       dpx.television.interlace=(unsigned char) ReadBlobByte(image);
       dpx.television.field_number=(unsigned char) ReadBlobByte(image);
       dpx.television.video_signal=(unsigned char) ReadBlobByte(image);
@@ -826,7 +829,12 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) ReadBlob(image,sizeof(dpx.television.reserve),(unsigned char *)
         dpx.television.reserve);
     }
-  if (dpx.file.image_offset >= 2080UL)
+  if (dpx.file.image_offset < 2080UL)
+    {
+      for (i=0; i < (long) (dpx.file.image_offset-2080); i++)
+        (void) ReadBlobByte(image);
+    }
+  else
     {
       /*
         Read DPX user header.
@@ -834,12 +842,26 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) ReadBlob(image,sizeof(dpx.user.id),(unsigned char *) dpx.user.id);
       if (*dpx.user.id != '\0')
         (void) FormatImageProperty(image,"dpx:user.id","%.32s",dpx.user.id);
+      if (dpx.file.user_size == 0)
+        {
+          for (i=0; i < (long) (dpx.file.image_offset-2080); i++)
+            (void) ReadBlobByte(image);
+        }
+      else
+        {
+          StringInfo
+            *profile;
+
+           profile=AcquireStringInfo(dpx.file.user_size-sizeof(dpx.user.id));
+           (void) ReadBlob(image,GetStringInfoLength(profile),
+             GetStringInfoDatum(profile));
+           (void) SetImageProfile(image,"dpx:user.data",profile);
+           profile=DestroyStringInfo(profile);
+        }
     }
   /*
     Read DPX image header.
   */
-  for (i=0; i < (long) (dpx.file.image_offset-2080); i++)
-    (void) ReadBlobByte(image);
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
@@ -896,90 +918,32 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   pixels=(unsigned char *) AcquireMagickMemory(length);
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  if ((quantum_type == GrayPadQuantum) && (image->depth == 10))
-    {
-      unsigned long
-        pixel;
-
-      /*
-        Cineon 10-bit pixel format.
-      */
-      pixel=0UL;
-      i=0;
-      for (y=0; y < (long) image->rows; y++)
-      {
-        q=SetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        for (x=0; x < (long) image->columns; x++)
+  for (y=0; y < (long) image->rows; y++)
+  {
+    /*
+      DPX any-bit pixel format.
+    */
+    q=SetImagePixels(image,0,y,image->columns,1);
+    if (q == (PixelPacket *) NULL)
+      break;
+    p=ReadBlobStream(image,length,pixels,&count);
+    if ((size_t) count != length)
+      break;
+    status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+    if (status == MagickFalse)
+      break;
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
+    if (image->previous == (Image *) NULL)
+      if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+          (QuantumTick(y,image->rows) != MagickFalse))
         {
-          switch (i % 3)
-          {
-            case 0:
-            {
-              pixel=ReadBlobMSBLong(image);
-              q->red=(Quantum) ((MagickRealType) QuantumRange*((pixel >> 0) &
-                0x3ff)/1023+0.5);
-              break;
-            }
-            case 1:
-            {
-              q->red=(Quantum) ((MagickRealType) QuantumRange*((pixel >> 10) &
-                0x3ff)/1023+0.5);
-              break;
-            }
-            case 2:
-            {
-              q->red=(Quantum) ((MagickRealType) QuantumRange*((pixel >> 20) &
-                0x3ff)/1023+0.5);
-              break;
-            }
-          }
-          q->green=q->red;
-          q->blue=q->red;
-          q++;
-          i++;
+          status=image->progress_monitor(LoadImageTag,y,image->rows,
+            image->client_data);
+          if (status == MagickFalse)
+            break;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-        if (image->previous == (Image *) NULL)
-          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(y,image->rows) != MagickFalse))
-            {
-              status=image->progress_monitor(LoadImageTag,y,image->rows,
-                image->client_data);
-              if (status == MagickFalse)
-                break;
-            }
-      }
-    }
-  else
-    for (y=0; y < (long) image->rows; y++)
-    {
-      /*
-        DPX any-bit pixel format.
-      */
-      q=SetImagePixels(image,0,y,image->columns,1);
-      if (q == (PixelPacket *) NULL)
-        break;
-      p=ReadBlobStream(image,length,pixels,&count);
-      if ((size_t) count != length)
-        break;
-      status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
-      if (status == MagickFalse)
-        break;
-      if (SyncImagePixels(image) == MagickFalse)
-        break;
-      if (image->previous == (Image *) NULL)
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
-          {
-            status=image->progress_monitor(LoadImageTag,y,image->rows,
-              image->client_data);
-            if (status == MagickFalse)
-              break;
-          }
-    }
+  }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   if (EOFBlob(image))
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
@@ -1027,7 +991,7 @@ ModuleExport void RegisterDPXImage(void)
   entry->decoder=(DecoderHandler *) ReadDPXImage;
   entry->encoder=(EncoderHandler *) WriteDPXImage;
   entry->magick=(MagickHandler *) IsDPX;
-  entry->description=ConstantString("SMPTE 268M-2003 (DPX)");
+  entry->description=ConstantString("SMPTE 268M-2003 (DPX 2.0)");
   entry->note=ConstantString(DPXNote);
   entry->module=ConstantString("DPX");
   (void) RegisterMagickInfo(entry);
@@ -1080,8 +1044,37 @@ ModuleExport void UnregisterDPXImage(void)
 %
 %    o image:  The image.
 %
-%
 */
+
+static unsigned long DecodeSMPTEBits(const char *key)
+{
+  char
+    buffer[2];
+
+  register long
+    i;
+
+  unsigned long
+    shift,
+    value;
+
+  value=0;
+  shift=28;
+  buffer[1]='\0';
+  for (i=0; (*key != 0) && (i < 11); i++)
+  {
+    if (isdigit((int) ((unsigned char) *key)) == 0)
+      {
+        key++;
+        continue;
+      }
+    buffer[0]=(*key++);
+    value|=(unsigned long) ((strtol(buffer,(char **) NULL,10)) << shift);
+    shift-=4;
+  }
+  return(value);
+}
+
 static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
 {
   const char
@@ -1158,6 +1151,11 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   dpx.file.user_size=0x00001800UL;
   (void) WriteBlobLong(image,dpx.file.user_size);
   (void) CopyMagickString(dpx.file.filename,"V2.0",sizeof(dpx.file.filename));
+  value=GetImageOption(image_info,"dpx:file.filename");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:file.filename");
+  if (value != (const char *) NULL)
+    (void) CopyMagickString(dpx.file.filename,value,sizeof(dpx.file.filename));
   (void) WriteBlob(image,sizeof(dpx.file.filename),(unsigned char *)
     dpx.file.filename);
   seconds=time((time_t *) NULL);
@@ -1167,14 +1165,23 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     dpx.file.timestamp);
   (void) CopyMagickString(dpx.file.creator,GetMagickVersion((unsigned long *)
     NULL),sizeof(dpx.file.creator));
+  value=GetImageOption(image_info,"dpx:file.creator");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:file.creator");
+  if (value != (const char *) NULL)
+    (void) CopyMagickString(dpx.file.creator,value,sizeof(dpx.file.creator));
   (void) WriteBlob(image,sizeof(dpx.file.creator),(unsigned char *)
     dpx.file.creator);
-  value=GetImageProperty(image,"dpx:file.project");
+  value=GetImageOption(image_info,"dpx:file.project");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:file.project");
   if (value != (const char *) NULL)
     (void) CopyMagickString(dpx.file.project,value,sizeof(dpx.file.project));
   (void) WriteBlob(image,sizeof(dpx.file.project),(unsigned char *)
     dpx.file.project);
-  value=GetImageProperty(image,"dpx:file.copyright");
+  value=GetImageOption(image_info,"dpx:file.copyright");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:file.copyright");
   if (value != (const char *) NULL)
     (void) CopyMagickString(dpx.file.copyright,value,
       sizeof(dpx.file.copyright));
@@ -1224,8 +1231,6 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
       dpx.image.image_element[i].packing=1;
     (void) WriteBlobShort(image,dpx.image.image_element[i].packing);
     dpx.image.image_element[i].encoding=0;
-    if (i == 0)
-      dpx.image.image_element[i].encoding=1;
     (void) WriteBlobShort(image,dpx.image.image_element[i].encoding);
     dpx.image.image_element[i].data_offset=0UL;
     (void) WriteBlobLong(image,dpx.image.image_element[i].data_offset);
@@ -1252,7 +1257,9 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobLong(image,dpx.orientation.x_size);
   dpx.orientation.y_size=0UL;
   (void) WriteBlobLong(image,dpx.orientation.y_size);
-  value=GetImageProperty(image,"dpx:orientation.filename");
+  value=GetImageOption(image_info,"dpx:orientation.filename");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:orientation.filename");
   if (value != (const char *) NULL)
     (void) CopyMagickString(dpx.orientation.filename,value,
       sizeof(dpx.orientation.filename));
@@ -1260,6 +1267,12 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     dpx.orientation.filename);
   (void) WriteBlob(image,sizeof(dpx.orientation.timestamp),(unsigned char *)
     dpx.orientation.timestamp);
+  value=GetImageOption(image_info,"dpx:orientation.device");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:orientation.device");
+  if (value != (const char *) NULL)
+    (void) CopyMagickString(dpx.orientation.device,value,
+      sizeof(dpx.orientation.device));
   (void) WriteBlob(image,sizeof(dpx.orientation.device),(unsigned char *)
     dpx.orientation.device);
   (void) WriteBlob(image,sizeof(dpx.orientation.serial),(unsigned char *)
@@ -1303,7 +1316,17 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   /*
     Write television header.
   */
+  value=GetImageOption(image_info,"dpx:television.time.code");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:television.time.code");
+  if (value != (const char *) NULL)
+    dpx.television.time_code=DecodeSMPTEBits(value);
   (void) WriteBlobLong(image,dpx.television.time_code);
+  value=GetImageOption(image_info,"dpx:television.user.bits");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:television.user.bits");
+  if (value != (const char *) NULL)
+    dpx.television.user_bits=DecodeSMPTEBits(value);
   (void) WriteBlobLong(image,dpx.television.user_bits);
   (void) WriteBlobByte(image,dpx.television.interlace);
   (void) WriteBlobByte(image,dpx.television.field_number);
@@ -1326,6 +1349,11 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   /*
     Write user header.
   */
+  value=GetImageOption(image_info,"dpx:user.id");
+  if (value == (const char *) NULL)
+    value=GetImageProperty(image,"dpx:user.id");
+  if (value != (const char *) NULL)
+    (void) CopyMagickString(dpx.user.id,value,sizeof(dpx.user.id));
   (void) WriteBlob(image,sizeof(dpx.user.id),(unsigned char *) dpx.user.id);
   offset=TellBlob(image);
   for (i=0; i < (0x2000-offset); i++)
