@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -315,14 +315,15 @@ static MagickBooleanType WriteFAXImage(const ImageInfo *image_info,Image *image)
   if (status == MagickFalse)
     return(status);
   write_info=CloneImageInfo(image_info);
-  (void) strcpy(write_info->magick,"FAX");
+  (void) CopyMagickString(write_info->magick,"FAX",MaxTextExtent);
   scene=0;
   do
   {
     /*
       Convert MIFF to monochrome.
     */
-    (void) SetImageColorspace(image,RGBColorspace);
+    if (image_info->colorspace == UndefinedColorspace)
+      (void) SetImageColorspace(image,RGBColorspace);
     status=HuffmanEncodeImage(write_info,image);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
