@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -848,7 +848,7 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   (void) FormatMagickString(header,MaxTextExtent,"DATAMIN =         %E",0.0);
   (void) strncpy(fits_info+offset,header,strlen(header));
   offset+=80;
-  (void) FormatMagickString(header,MaxTextExtent,"HISTORY %s",
+  (void) FormatMagickString(header,MaxTextExtent,"HISTORY %.72s",
     GetMagickVersion((unsigned long *) NULL));
   (void) strncpy(fits_info+offset,header,strlen(header));
   offset+=80;
