@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -120,7 +120,7 @@ typedef struct _LZWInfo
 /*
   Forward declarations.
 */
-static int
+static inline int
   GetNextLZWCode(LZWInfo *,const unsigned long);
 
 static MagickBooleanType
@@ -128,13 +128,6 @@ static MagickBooleanType
 
 static ssize_t
   ReadBlobBlock(Image *,unsigned char *);
-
-static long
-  PopLZWStack(LZWStack *);
-
-static void
-  PushLZWStack(LZWStack *,const unsigned long),
-  ResetLZWInfo(LZWInfo *);
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -180,6 +173,14 @@ static LZWInfo *RelinquishLZWInfo(LZWInfo *lzw_info)
   return((LZWInfo *) NULL);
 }
 
+static inline void ResetLZWInfo(LZWInfo *lzw_info)
+{
+  lzw_info->bits=lzw_info->data_size+1;
+  lzw_info->maximum_code=1UL << lzw_info->bits;
+  lzw_info->slot=lzw_info->maximum_data_value+3;
+  lzw_info->genesis=MagickTrue;
+}
+
 static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
 {
   LZWInfo
@@ -237,7 +238,7 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
   return(lzw_info);
 }
 
-static int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
+static inline int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
 {
   int
     code;
@@ -276,7 +277,7 @@ static int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
   return(code);
 }
 
-static long PopLZWStack(LZWStack *stack_info)
+static inline long PopLZWStack(LZWStack *stack_info)
 {
   if (stack_info->index <= stack_info->codes)
     return(-1);
@@ -284,7 +285,7 @@ static long PopLZWStack(LZWStack *stack_info)
   return((long) *stack_info->index);
 }
 
-static void PushLZWStack(LZWStack *stack_info,const unsigned long value)
+static inline void PushLZWStack(LZWStack *stack_info,const unsigned long value)
 {
   if (stack_info->index >= stack_info->top)
     return;
@@ -362,14 +363,6 @@ static int ReadBlobLZWByte(LZWInfo *lzw_info)
   return(PopLZWStack(lzw_info->stack));
 }
 
-static void ResetLZWInfo(LZWInfo *lzw_info)
-{
-  lzw_info->bits=lzw_info->data_size+1;
-  lzw_info->maximum_code=1UL << lzw_info->bits;
-  lzw_info->slot=lzw_info->maximum_data_value+3;
-  lzw_info->genesis=MagickTrue;
-}
-
 static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
 {
   IndexPacket
@@ -942,6 +935,32 @@ static inline size_t MagickMin(const size_t x,const size_t y)
   return(y);
 }
 
+static MagickBooleanType PingGIFImage(Image *image)
+{
+  unsigned char
+    buffer[256],
+    length,
+    data_size;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  if (ReadBlob(image,1,&data_size) != 1)
+    ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
+  if (data_size > MaximumLZWBits)
+    ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
+  if (ReadBlob(image,1,&length) != 1)
+    ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
+  while (length != 0)
+  {
+    if (ReadBlob(image,length,buffer) != length)
+      ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
+    if (ReadBlob(image,1,&length) != 1)
+      ThrowBinaryException(CorruptImageError,"CorruptImage",image->filename);
+  }
+  return(MagickTrue);
+}
 
 static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -1235,7 +1254,10 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Decode image.
     */
-    status=DecodeImage(image,(Quantum) opacity);
+    if (image_info->ping != MagickFalse)
+      status=PingGIFImage(image);
+    else
+      status=DecodeImage(image,(Quantum) opacity);
     if ((image_info->ping == MagickFalse) && (status == MagickFalse))
       {
         global_colormap=(unsigned char *) RelinquishMagickMemory(
