@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -197,7 +197,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     *p;
 
   ssize_t
-    count;
+    count,
+    offset;
 
   unsigned long
     bit,
@@ -246,8 +247,10 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     /*
       Verify Icon identifier.
     */
-    (void) SeekBlob(image,(MagickOffsetType) icon_file.directory[i].offset,
+    offset=SeekBlob(image,(MagickOffsetType) icon_file.directory[i].offset,
       SEEK_SET);
+    if (offset < 0)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     icon_info.size=ReadBlobLSBLong(image);
     icon_info.width=(unsigned char) ReadBlobLSBLong(image);
     icon_info.height=(unsigned char) ReadBlobLSBLong(image)/2;
@@ -281,13 +284,13 @@ static Image *ReadICONImage(const ImageInfo *image_info,
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),"   bpp    = %d",
         icon_info.bits_per_pixel);
     }
-    if ((icon_info.number_colors != 0) || (icon_info.bits_per_pixel < 16))
-      {
-        image->storage_class=PseudoClass;
-        image->colors=icon_info.number_colors;
-        if (image->colors == 0)
-          image->colors=1 << icon_info.bits_per_pixel;
-      }
+  if ((icon_info.number_colors != 0) || (icon_info.bits_per_pixel <= 16))
+    {
+      image->storage_class=PseudoClass;
+      image->colors=icon_info.number_colors;
+      if (image->colors == 0)
+        image->colors=1 << icon_info.bits_per_pixel;
+    }
   if (image->storage_class == PseudoClass)
     {
       register long
@@ -712,6 +715,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     status;
 
   MagickOffsetType
+    offset,
     scene;
 
   register const PixelPacket
@@ -1114,7 +1118,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  (void) SeekBlob(image,0,SEEK_SET);
+  offset=SeekBlob(image,0,SEEK_SET);
   (void) WriteBlobLSBShort(image,0);
   (void) WriteBlobLSBShort(image,1);
   (void) WriteBlobLSBShort(image,(unsigned short) (scene+1));
