@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1405,7 +1405,7 @@ static void WriteProfile(j_compress_ptr jpeg_info,Image *image)
             custom_profile),(unsigned int) (length+tag_length));
         }
       }
-    if (LocaleCompare(name,"IPTC") == 0)
+    if ((LocaleCompare(name,"IPTC") == 0) || (LocaleCompare(name,"8BIM") == 0))
       {
         register unsigned char
           *p;
