@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -421,6 +421,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   LinkedListInfo
     *profiles;
 
+  MagickOffsetType
+    offset;
+
   long
     y;
 
@@ -1170,8 +1173,13 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           if (y == (long) (image->rows-1))
             {
               if (version == 0)
-                (void) SeekBlob(image,-((MagickOffsetType) zip_info.avail_in),
-                  SEEK_CUR);
+                {
+                  offset=SeekBlob(image,-((MagickOffsetType) zip_info.avail_in),
+                    SEEK_CUR);
+                  if (offset < 0)
+                    ThrowReaderException(CorruptImageError,
+                      "ImproperImageHeader");
+                }
               code=inflateEnd(&zip_info);
               if (code >= 0)
                 status=MagickTrue;
@@ -1213,8 +1221,13 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           if (y == (long) (image->rows-1))
             {
               if (version == 0)
-                (void) SeekBlob(image,-((MagickOffsetType) bzip_info.avail_in),
-                  SEEK_CUR);
+                {
+                  offset=SeekBlob(image,-((MagickOffsetType)
+                    bzip_info.avail_in),SEEK_CUR);
+                  if (offset < 0)
+                    ThrowReaderException(CorruptImageError,
+                      "ImproperImageHeader");
+                }
               code=BZ2_bzDecompressEnd(&bzip_info);
               if (code >= 0)
                 status=MagickTrue;
