@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -83,7 +83,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMPRImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -145,8 +144,8 @@ ModuleExport void RegisterMPRImage(void)
   entry->encoder=(EncoderHandler *) WriteMPRImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
-  entry->description=AcquireString("Magick Persistent Registry");
-  entry->module=AcquireString("MPR");
+  entry->description=ConstantString("Magick Persistent Registry");
+  entry->module=ConstantString("MPR");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPRI");
   entry->decoder=(DecoderHandler *) ReadMPRImage;
@@ -154,8 +153,8 @@ ModuleExport void RegisterMPRImage(void)
   entry->stealth=MagickTrue;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
-  entry->description=AcquireString("Magick Persistent Registry");
-  entry->module=AcquireString("MPRI");
+  entry->description=ConstantString("Magick Persistent Registry");
+  entry->module=ConstantString("MPRI");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -209,7 +208,6 @@ ModuleExport void UnregisterMPRImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteMPRImage(const ImageInfo *image_info,Image *image)
 {
@@ -230,12 +228,12 @@ static MagickBooleanType WriteMPRImage(const ImageInfo *image_info,Image *image)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   GetExceptionInfo(&exception);
   registry_image=GetImageFromMagickRegistry(image->filename,&id,&exception);
-  DestroyExceptionInfo(&exception);
+  (void) DestroyExceptionInfo(&exception);
   if (registry_image != (Image *) NULL)
     {
       (void) DeleteMagickRegistry(id);
       registry_image=DestroyImage(registry_image);
     }
   id=SetMagickRegistry(ImageRegistryType,image,sizeof(Image),&image->exception);
-  return((MagickBooleanType) (id >= 0));
+  return(id >= 0 ? MagickTrue : MagickFalse);
 }
