@@ -17,7 +17,7 @@
 %                                 April 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/draw.h"
@@ -51,6 +50,7 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -193,7 +193,7 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
     DefaultResolution;
   image->columns=(unsigned long) (draw_info->affine.sx*image->columns);
   image->rows=(unsigned long) (draw_info->affine.sy*image->rows);
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   /*
     Render drawing.
   */
@@ -221,8 +221,8 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterMVGImage() adds attributes for the MVG image format
-%  to the list of supported formats.  The attributes include the image format
+%  RegisterMVGImage() adds properties for the MVG image format
+%  to the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -300,8 +300,8 @@ ModuleExport void UnregisterMVGImage(void)
 */
 static MagickBooleanType WriteMVGImage(const ImageInfo *image_info,Image *image)
 {
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   MagickBooleanType
     status;
@@ -315,14 +315,14 @@ static MagickBooleanType WriteMVGImage(const ImageInfo *image_info,Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  attribute=GetImageAttribute(image,"[MVG]");
-  if (attribute == (ImageAttribute *) NULL)
+  value=GetImageProperty(image,"[MVG]");
+  if (value == (const char *) NULL)
     ThrowWriterException(OptionError,"NoImageVectorGraphics");
   status=OpenBlob(image_info,image,WriteBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-    attribute->value);
+  (void) WriteBlob(image,strlen(value),(unsigned char *)
+    value);
   CloseBlob(image);
   return(MagickTrue);
 }
