@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -130,7 +130,7 @@ static Image *ReadNULLImage(const ImageInfo *image_info,
     image->rows=1;
   image->matte=MagickTrue;
   GetMagickPixelPacket(image,&background);
-  background.opacity=TransparentOpacity;
+  background.opacity=(MagickRealType) TransparentOpacity;
   if (image->colorspace == CMYKColorspace)
     RGBtoCMYK(&background);
   for (y=0; y < (long) image->rows; y++)
@@ -141,7 +141,7 @@ static Image *ReadNULLImage(const ImageInfo *image_info,
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      SetPixelPacket(&background,q,indexes);
+      SetPixelPacket(image,&background,q,indexes);
       q++;
       indexes++;
     }
@@ -183,8 +183,8 @@ ModuleExport void RegisterNULLImage(void)
   entry->decoder=(DecoderHandler *) ReadNULLImage;
   entry->encoder=(EncoderHandler *) WriteNULLImage;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Constant image of uniform color");
-  entry->module=AcquireString("NULL");
+  entry->description=ConstantString("Constant image of uniform color");
+  entry->module=ConstantString("NULL");
   (void) RegisterMagickInfo(entry);
 }
 
