@@ -483,7 +483,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
     if (flags & PALM_HAS_TRANSPARENCY_FLAG)
       {
         if (bits_per_pixel != 16)
-          SetMagickPixelPacket(image->colormap+(mask-transparentIndex),
+          SetMagickPixelPacket(image,image->colormap+(mask-transparentIndex),
             (const IndexPacket *) NULL,&transpix);
         (void) PaintTransparentImage(image,&transpix,TransparentOpacity);
       }
@@ -894,14 +894,14 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
       }
     if (flags & PALM_HAS_TRANSPARENCY_FLAG)
       {
-        (void) SeekBlob(image,currentOffset+6,SEEK_SET);
+        offset=SeekBlob(image,currentOffset+6,SEEK_SET);
         (void) WriteBlobMSBShort(image,flags);
-        (void) SeekBlob(image,currentOffset+12,SEEK_SET);
+        offset=SeekBlob(image,currentOffset+12,SEEK_SET);
         (void) WriteBlobByte(image,(unsigned char) transparentIndex);  /* trans index */
       }
     if (bits_per_pixel == 16)
       {
-        (void) SeekBlob(image,currentOffset+20,SEEK_SET);
+        offset=SeekBlob(image,currentOffset+20,SEEK_SET);
         (void) WriteBlobByte(image,0);  /* reserved by Palm */
         (void) WriteBlobByte(image,(unsigned char) ((31*transpix.red)/QuantumRange));
         (void) WriteBlobByte(image,(unsigned char) ((63*transpix.green)/QuantumRange));
@@ -909,7 +909,7 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
       }
     if (flags & PALM_IS_COMPRESSED_FLAG)  /* fill in size now */
       {
-        (void) SeekBlob(image,currentOffset+offset,SEEK_SET);
+        offset=SeekBlob(image,currentOffset+offset,SEEK_SET);
         (void) WriteBlobMSBShort(image,(unsigned short) (GetBlobSize(image)-currentOffset-offset));
       }
     if (one_row != (unsigned char *) NULL) 
@@ -924,11 +924,11 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,
       (void) WriteBlobByte(image,0);
     } 
     /* write nextDepthOffset and return to end of image */
-    (void) SeekBlob(image,currentOffset+10,SEEK_SET);
+    offset=SeekBlob(image,currentOffset+10,SEEK_SET);
     nextDepthOffset=(unsigned long) ((GetBlobSize(image)-currentOffset)/4);
     (void) WriteBlobMSBShort(image,(unsigned short) nextDepthOffset);
     currentOffset=(MagickOffsetType) GetBlobSize(image);
-    (void) SeekBlob(image,currentOffset,SEEK_SET);
+    offset=SeekBlob(image,currentOffset,SEEK_SET);
     image=SyncNextImageInList(image);
   } while (image_info->adjoin != MagickFalse);
   CloseBlob(image);
