@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -771,7 +771,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Upsample(768,512,image->columns,chroma2);
           image->rows=2048;
           offset=TellBlob(image)/0x800+12;
-          (void) SeekBlob(image,offset*0x800,SEEK_SET);
+          offset=SeekBlob(image,offset*0x800,SEEK_SET);
           status=DecodeImage(image,luma,chroma1,chroma2);
           if ((scene >= 6) && (status != MagickFalse))
             {
