@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -195,6 +195,13 @@ static MagickBooleanType IsPCX(const unsigned char *magick,const size_t length)
 %
 */
 
+static inline long MagickAbsoluteValue(const long x)
+{
+  if (x < 0)
+    return(-x);
+  return(x);
+}
+
 static inline size_t MagickMax(const size_t x,const size_t y)
 {
   if (x > y)
@@ -202,6 +209,13 @@ static inline size_t MagickMax(const size_t x,const size_t y)
   return(y);
 }
 
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image
@@ -219,6 +233,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     status;
 
   MagickOffsetType
+    offset,
     *page_table;
 
   PCXInfo
@@ -296,7 +311,11 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     }
   if (page_table != (MagickOffsetType *) NULL)
-    (void) SeekBlob(image,(MagickOffsetType) page_table[0],SEEK_SET);
+    {
+      offset=SeekBlob(image,(MagickOffsetType) page_table[0],SEEK_SET);
+      if (offset < 0)
+        ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+    }
   pcx_colormap=(unsigned char *) NULL;
   count=ReadBlob(image,1,&pcx_info.identifier);
   for (id=1; id < 1024; id++)
@@ -318,8 +337,11 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read PCX raster colormap.
     */
-    image->columns=(pcx_info.right-pcx_info.left)+1UL;
-    image->rows=(pcx_info.bottom-pcx_info.top)+1UL;
+    image->columns=MagickAbsoluteValue(pcx_info.right-pcx_info.left)+1UL;
+    image->rows=MagickAbsoluteValue(pcx_info.bottom-pcx_info.top)+1UL;
+    if ((image->columns == 0) || (image->rows == 0) ||
+        (pcx_info.bits_per_pixel == 0))
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     image->depth=pcx_info.bits_per_pixel <= 8 ? 8U : QuantumDepth;
     image->units=PixelsPerInchResolution;
     image->x_resolution=(double) pcx_info.horizontal_resolution;
@@ -335,7 +357,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((pcx_info.bits_per_pixel != 8) || (pcx_info.planes == 1))
       if ((pcx_info.version == 3) || (pcx_info.version == 5) ||
           ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
-        image->colors=1 << (pcx_info.bits_per_pixel*pcx_info.planes);
+        image->colors=(unsigned long) MagickMin(1UL << (pcx_info.bits_per_pixel*
+          pcx_info.planes),256UL);
     if (AllocateImageColormap(image,image->colors) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((pcx_info.bits_per_pixel >= 8) && (pcx_info.planes != 1))
@@ -361,8 +384,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       pcx_info.planes;
     pcx_pixels=(unsigned char *) AcquireMagickMemory(pcx_packets*
       sizeof(*pcx_pixels));
-    scanline=(unsigned char *) AcquireMagickMemory(4*MagickMax(image->columns,
-      pcx_info.bytes_per_line)*pcx_info.planes*sizeof(*scanline));
+    scanline=(unsigned char *) AcquireMagickMemory(MagickMax(image->columns,
+      pcx_info.bytes_per_line)*MagickMax(8,pcx_info.planes)*sizeof(*scanline));
     if ((pcx_pixels == (unsigned char *) NULL) ||
         (scanline == (unsigned char *) NULL))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -620,7 +643,9 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
     if (page_table[id] == 0)
       break;
-    (void) SeekBlob(image,(MagickOffsetType) page_table[id],SEEK_SET);
+    offset=SeekBlob(image,(MagickOffsetType) page_table[id],SEEK_SET);
+    if (offset < 0)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     count=ReadBlob(image,1,&pcx_info.identifier);
     if ((count != 0) && (pcx_info.identifier == 0x0a))
       {
@@ -805,6 +830,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     status;
 
   MagickOffsetType
+    offset,
     *page_table,
     scene;
 
@@ -1127,7 +1153,9 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         Write the DCX page table.
       */
       page_table[scene+1]=0;
-      (void) SeekBlob(image,0L,SEEK_SET);
+      offset=SeekBlob(image,0L,SEEK_SET);
+      if (offset < 0)
+        ThrowWriterException(CorruptImageError,"ImproperImageHeader");
       (void) WriteBlobLSBLong(image,0x3ADE68B1L);
       for (i=0; i <= (long) scene; i++)
         (void) WriteBlobLSBLong(image,(unsigned long) page_table[i]);
