@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -465,7 +465,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
     if (count != 4)
       continue;
-    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
+    if (((unsigned long) (bounds.x2-bounds.x1+0.5) > page.width) ||
+        ((unsigned long) (bounds.y2-bounds.y1+0.5) > page.height))
       {
         /*
           Set PDF render geometry.
@@ -520,6 +521,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       return((Image *) NULL);
     }
   *options='\0';
+  if (cmyk != MagickFalse)
+    (void) ConcatenateMagickString(options,"-dUseCIEColor ",MaxTextExtent);
   if (cropbox != MagickFalse)
     (void) ConcatenateMagickString(options,"-dUseCropBox ",MaxTextExtent);
   if (trimbox != MagickFalse)
@@ -1989,13 +1992,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       (unsigned long) offset);
     (void) WriteBlobString(image,buffer);
     (void) WriteBlobString(image,"endobj\n");
-    xref[object++]=TellBlob(image);
     if ((image->storage_class != DirectClass) && (image->colors <= 256) &&
         (compression != FaxCompression) && (compression != Group4Compression))
       {
         /*
           Write Colormap object.
         */
+        xref[object++]=TellBlob(image);
         (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
         (void) WriteBlobString(image,buffer);
         (void) WriteBlobString(image,"<<\n");
