@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -84,12 +84,15 @@
   pixmap.reserved=ReadBlobMSBLong(image); \
 }
 
-#define ReadRectangle(rectangle) \
+#define ReadRectangle(image,rectangle) \
 { \
   rectangle.top=(short) ReadBlobMSBShort(image); \
   rectangle.left=(short) ReadBlobMSBShort(image); \
   rectangle.bottom=(short) ReadBlobMSBShort(image); \
   rectangle.right=(short) ReadBlobMSBShort(image); \
+  if ((rectangle.left > rectangle.right) || \
+      (rectangle.top > rectangle.bottom)) \
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader"); \
 }
 
 typedef struct _PICTCode
@@ -320,13 +323,14 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DecodeImage decompresses an image via Macintosh pack bits
-%  decoding for Macintosh PICT images.
+%  DecodeImage decompresses an image via Macintosh pack bits decoding for
+%  Macintosh PICT images.
 %
 %  The format of the DecodeImage method is:
 %
 %      unsigned char* DecodeImage(const ImageInfo *image_info,Image *blob,
-%        Image *image,unsigned long bytes_per_line,const int bits_per_pixel)
+%        Image *image,unsigned long bytes_per_line,const int bits_per_pixel,
+%        unsigned long *extent)
 %
 %  A description of each parameter follows:
 %
@@ -339,6 +343,7 @@ static MagickBooleanType
 %
 %    o bits_per_pixel: The number of bits in a pixel.
 %
+%    o extent: The number of pixels allocated.
 %
 */
 
@@ -411,7 +416,8 @@ static unsigned char *ExpandBuffer(unsigned char *pixels,
 }
 
 static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
-  Image *image,unsigned long bytes_per_line,const unsigned int bits_per_pixel)
+  Image *image,unsigned long bytes_per_line,const unsigned int bits_per_pixel,
+  unsigned long *extent)
 {
   long
     j,
@@ -468,11 +474,11 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
   /*
     Allocate pixel and scanline buffer.
   */
-  pixels=(unsigned char *) AcquireMagickMemory(row_bytes*image->rows*
-    sizeof(*pixels));
+  *extent=row_bytes*image->rows*sizeof(*pixels);
+  pixels=(unsigned char *) AcquireMagickMemory(*extent);
   if (pixels == (unsigned char *) NULL)
     return((unsigned char *) NULL);
-  (void) ResetMagickMemory(pixels,0,row_bytes*image->rows);
+  (void) ResetMagickMemory(pixels,0,*extent);
   scanline=(unsigned char *) AcquireMagickMemory(row_bytes*sizeof(scanline));
   if (scanline == (unsigned char *) NULL)
     return((unsigned char *) NULL);
@@ -823,6 +829,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   StringInfo
     *profile;
 
+  unsigned long
+    extent;
+
   /*
     Open image file.
   */
@@ -849,7 +858,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   for (i=0; i < 512; i++)
     (void) ReadBlobByte(image);  /* skip header */
   (void) ReadBlobMSBShort(image);  /* skip picture size */
-  ReadRectangle(frame);
+  ReadRectangle(image,frame);
   while ((c=ReadBlobByte(image)) == 0);
   if (c != 0x11)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -909,7 +918,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                   (void) ReadBlobByte(image);
                 break;
               }
-            ReadRectangle(frame);
+            ReadRectangle(image,frame);
             if (((frame.left & 0x8000) != 0) || ((frame.top & 0x8000) != 0))
               break;
             image->columns=1UL*(frame.right-frame.left);
@@ -943,7 +952,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             if (pattern != 1)
               ThrowReaderException(CorruptImageError,"UnknownPatternType");
             length=ReadBlobMSBShort(image);
-            ReadRectangle(frame);
+            ReadRectangle(image,frame);
             ReadPixmap(pixmap);
             image->depth=1UL*pixmap.component_size;
             image->x_resolution=1.0*pixmap.horizontal_resolution;
@@ -1045,7 +1054,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 (void) ReadBlobMSBShort(image);
                 (void) ReadBlobMSBShort(image);
               }
-            ReadRectangle(frame);
+            ReadRectangle(image,frame);
             /*
               Initialize tile image.
             */
@@ -1115,8 +1124,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     }
                   }
               }
-            ReadRectangle(source);
-            ReadRectangle(destination);
+            ReadRectangle(image,source);
+            ReadRectangle(image,destination);
             (void) ReadBlobMSBShort(image);
             if ((code == 0x91) || (code == 0x99) || (code == 0x9b))
               {
@@ -1130,10 +1139,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             if ((code != 0x9a) && (code != 0x9b) &&
                 (bytes_per_line & 0x8000) == 0)
               pixels=DecodeImage(image_info,image,tile_image,1UL*
-                bytes_per_line,1);
+                bytes_per_line,1,&extent);
             else
               pixels=DecodeImage(image_info,image,tile_image,1UL*bytes_per_line,
-                1U*pixmap.bits_per_pixel);
+                1U*pixmap.bits_per_pixel,&extent);
             if (pixels == (unsigned char *) NULL)
               {
                 tile_image=DestroyImage(tile_image);
@@ -1146,6 +1155,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             p=pixels;
             for (y=0; y < (long) tile_image->rows; y++)
             {
+              if (p > (pixels+extent+image->columns))
+                ThrowReaderException(CorruptImageError,"NotEnoughPixelData");
               q=SetImagePixels(tile_image,0,y,tile_image->columns,1);
               if (q == (PixelPacket *) NULL)
                 break;
@@ -1176,6 +1187,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     else
                       if (tile_image->matte == MagickFalse)
                         {
+                          if (p > (pixels+extent+2*image->columns))
+                            ThrowReaderException(CorruptImageError,
+                              "NotEnoughPixelData");
                           q->red=ScaleCharToQuantum(*p);
                           q->green=ScaleCharToQuantum(
                             *(p+tile_image->columns));
@@ -1184,6 +1198,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                         }
                       else
                         {
+                          if (p > (pixels+extent+3*image->columns))
+                            ThrowReaderException(CorruptImageError,
+                              "NotEnoughPixelData");
                           q->opacity=(Quantum) (QuantumRange-
                             ScaleCharToQuantum(*p));
                           q->red=ScaleCharToQuantum(*(p+tile_image->columns));
@@ -1200,7 +1217,11 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 break;
               if ((tile_image->storage_class == DirectClass) &&
                   (pixmap.bits_per_pixel != 16))
-                p+=(pixmap.component_count-1)*tile_image->columns;
+                {
+                  p+=(pixmap.component_count-1)*tile_image->columns;
+                  if (p < pixels)
+                    break;
+                }
               if (destination.bottom == (long) image->rows)
                 if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                     (QuantumTick(y,tile_image->rows) != MagickFalse))
@@ -1345,7 +1366,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         length=ReadBlobMSBLong(image);
         for (i=0; i < 6; i++)
           (void) ReadBlobMSBLong(image);
-        ReadRectangle(frame);
+        ReadRectangle(image,frame);
         for (i=0; i < 122; i++)
           (void) ReadBlobByte(image);
         for (i=0; i < (long) (length-154); i++)
@@ -1931,7 +1952,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
     (void) WriteBlobByte(image,'\0');
   (void) WriteBlobMSBShort(image,PictEndOfPictureOp);
   offset=TellBlob(image);
-  (void) SeekBlob(image,512,SEEK_SET);
+  offset=SeekBlob(image,512,SEEK_SET);
   (void) WriteBlobMSBShort(image,(unsigned short) offset);
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   packed_scanline=(unsigned char *) RelinquishMagickMemory(packed_scanline);
