@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -132,7 +132,7 @@ static MagickBooleanType IsPNM(const unsigned char *magick,const size_t length)
 static inline long ConstrainPixel(Image *image,const long offset,
   const unsigned long extent)
 {
-  if (offset > (long) extent)
+  if ((offset < 0) || (offset > (long) extent))
     {
       (void) ThrowMagickException(&image->exception,GetMagickModule(),
         CorruptImageError,"InvalidPixel","`%s'",image->filename);
