@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -195,7 +195,6 @@ static MagickBooleanType InvokePostscriptDelegate(
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsPS(const unsigned char *magick,const size_t length)
 {
@@ -239,20 +238,23 @@ static inline int ProfileInteger(Image *image,short int *hex_digits)
 {
   int
     c,
+    l,
     value;
 
   register long
     i;
 
+  l=0;
   value=0;
   for (i=0; i < 2; )
   {
     c=ReadBlobByte(image);
-    if (c == EOF)
+    if ((c == EOF) || ((c == '%') && (l == '%')))
       {
         value=(-1);
         break;
       }
+    l=c;
     c&=0xff;
     if (isxdigit(c) == MagickFalse)
       continue;
@@ -266,6 +268,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
 #define BoundingBox  "BoundingBox:"
 #define BeginDocument  "BeginDocument:"
+#define ICCProfile "BeginICCProfile:"
 #define CMYKCustomColor  "CMYKCustomColor:"
 #define DocumentMedia  "DocumentMedia:"
 #define DocumentCustomColors  "DocumentCustomColors:"
@@ -345,10 +348,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   StringInfo
+    *option,
     *profile;
 
   unsigned long
     columns,
+    extent,
     language_level,
     pages,
     rows,
@@ -383,6 +388,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Initialize hex values.
   */
+  (void) ResetMagickMemory(hex_digits,0,sizeof(hex_digits));
   hex_digits[(int) '0']=0;
   hex_digits[(int) '1']=1;
   hex_digits[(int) '2']=2;
@@ -429,6 +435,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ResetMagickMemory(command,0,sizeof(command));
   columns=0;
   rows=0;
+  extent=0;
   spotcolor=0;
   language_level=1;
   skip=MagickFalse;
@@ -460,7 +467,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (LocaleNCompare(PostscriptLevel,command,strlen(PostscriptLevel)) == 0)
       {
         (void) SetImageProperty(image,"ps:Level",command+4);
-        if (GlobExpression(command,"*EPSF-*") != MagickFalse)
+        if (GlobExpression(command,"*EPSF-*",MagickTrue) != MagickFalse)
           pages=1;
       }
     if (LocaleNCompare(LanguageLevel,command,strlen(LanguageLevel)) == 0)
@@ -469,16 +476,32 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) sscanf(command,Pages " %lu",&pages);
     if (LocaleNCompare(ImageData,command,strlen(Pages)) == 0)
       (void) sscanf(command,ImageData " %lu %lu",&columns,&rows);
+    if (LocaleNCompare(ICCProfile,command,strlen(PhotoshopProfile)) == 0)
+      {
+        unsigned char
+          *datum;
+
+        /*
+          Read ICC profile.
+        */
+        profile=AcquireStringInfo(65536);
+        for (i=0; (c=ProfileInteger(image,hex_digits)) != EOF; i++)
+        {
+          SetStringInfoLength(profile,i+1);
+          datum=GetStringInfoDatum(profile);
+          datum[i]=c;
+        }
+        (void) SetImageProfile(image,"icc",profile);
+        profile=DestroyStringInfo(profile);
+        continue;
+      }
     if (LocaleNCompare(PhotoshopProfile,command,strlen(PhotoshopProfile)) == 0)
       {
-        unsigned long
-          extent;
-
         unsigned char
           *p;
 
         /*
-          Read image profile.
+          Read Photoshop profile.
         */
         count=(ssize_t) sscanf(command,PhotoshopProfile " %lu",&extent);
         if (count != 1)
@@ -497,11 +520,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         unsigned char
           *p;
 
-        unsigned long
-          extent;
-
         /*
-          Read image profile.
+          Read XML profile.
         */
         count=(ssize_t) sscanf(command,XMLProfile " %lu",&extent);
         if (count != 1)
@@ -572,7 +592,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         &bounds.y2)+2;
     if (count != 4)
       continue;
-    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
+    if (((unsigned long) (bounds.x2-bounds.x1+0.5) > page.width) ||
+        ((unsigned long) (bounds.y2-bounds.y1+0.5) > page.height))
       {
         /*
           Set Postscript render geometry.
@@ -600,11 +621,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       return((Image *) NULL);
     }
   (void) CopyMagickString(command,"/setpagedevice {pop} bind 1 index where {"
-    "dup wcheck {3 1 roll put} {pop def} ifelse} {def} ifelse\n",MaxTextExtent);
+    "dup wcheck {3 1 roll put} {pop def} ifelse} {def} ifelse\n"
+    "<</UseCIEColor true>>setpagedevice\n",MaxTextExtent);
   (void) write(file,command,(unsigned int) strlen(command));
   (void) FormatMagickString(translate_geometry,MaxTextExtent,
     "%g %g translate\n",-bounds.x1,-bounds.y1);
-  (void) write(file,translate_geometry,(unsigned int) strlen(translate_geometry));
+  (void) write(file,translate_geometry,strlen(translate_geometry));
   file=close(file)-1;
   /*
     Render Postscript with the Ghostscript delegate.
@@ -649,6 +671,11 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (read_info->scenes != (char *) NULL)
         *read_info->scenes='\0';
     }
+  option=GetImageOption(image_info,"ps:use-cropbox");
+  if ((option != (const char *) NULL) && (IsMagickTrue(option) != MagickFalse))
+    (void) ConcatenateMagickString(options,"-dEPSCrop ",MaxTextExtent);
+  if (cmyk != MagickFalse)
+    (void) ConcatenateMagickString(options,"-dUseCIEColor ",MaxTextExtent);
   (void) CopyMagickString(filename,read_info->filename,MaxTextExtent);
   (void) AcquireUniqueFilename(read_info->filename);
   (void) FormatMagickString(command,MaxTextExtent,
