@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -357,6 +357,9 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
+  MagickOffsetType
+    offset;
+
   MagickSizeType
     number_pixels;
 
@@ -1043,12 +1046,14 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
     (void) WriteBlobByte(image,'\n');
     length=(size_t) (TellBlob(image)-stop);
     stop=TellBlob(image);
-    (void) SeekBlob(image,start,SEEK_SET);
+    offset=SeekBlob(image,start,SEEK_SET);
+    if (offset < 0)
+      ThrowWriterException(CorruptImageError,"ImproperImageHeader");
     (void) FormatMagickString(buffer,MaxTextExtent,
       "%%%%BeginData:%13ld %s Bytes\n",(long) length,
       compression == NoCompression ? "ASCII" : "Binary");
     (void) WriteBlobString(image,buffer);
-    (void) SeekBlob(image,stop,SEEK_SET);
+    offset=SeekBlob(image,stop,SEEK_SET);
     (void) WriteBlobString(image,"%%EndData\n");
     if (LocaleCompare(image_info->magick,"PS2") != 0)
       (void) WriteBlobString(image,"end\n");
