@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -184,7 +184,6 @@ ModuleExport void UnregisterPS3Image(void)
 %
 %    o image: The image.
 %
-%
 */
 
 static MagickBooleanType SerializeImage(const ImageInfo *image_info,
@@ -288,8 +287,8 @@ static MagickBooleanType SerializeImageChannel(const ImageInfo *image_info,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=MagickTrue;
-  pack=(unsigned long)
-    (IsMonochromeImage(image,&image->exception) != MagickFalse ? 8 : 1);
+  pack=(unsigned long) (IsMonochromeImage(image,&image->exception) !=
+    MagickFalse ? 8 : 1);
   padded_columns=((image->columns+pack-1)/pack)*pack;
   *length=(size_t) padded_columns*image->rows/pack;
   *pixels=(unsigned char *) AcquireMagickMemory(*length);
@@ -407,6 +406,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
     status;
 
   MagickOffsetType
+    offset,
     start,
     stop;
 
@@ -498,6 +498,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
       return(MagickFalse);
     }
   (void) SetImageType(mask_image,BilevelType);
+  (void) SetImageType(mask_image,PaletteType);
   mask_image->matte=MagickFalse;
   pixels=(unsigned char *) NULL;
   length=0;
@@ -563,12 +564,16 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
   (void) WriteBlobByte(image,'\n');
   length=(size_t) (TellBlob(image)-stop);
   stop=TellBlob(image);
-  (void) SeekBlob(image,start,SEEK_SET);
+  offset=SeekBlob(image,start,SEEK_SET);
+  if (offset < 0)
+    ThrowWriterException(CorruptImageError,"ImproperImageHeader");
   (void) FormatMagickString(buffer,MaxTextExtent,
     "%%%%BeginData:%13ld %s Bytes\n",(long) length,
     compression == NoCompression ? "ASCII" : "BINARY");
   (void) WriteBlobString(image,buffer);
-  (void) SeekBlob(image,stop,SEEK_SET);
+  offset=SeekBlob(image,stop,SEEK_SET);
+  if (offset < 0)
+    ThrowWriterException(CorruptImageError,"ImproperImageHeader");
   (void) WriteBlobString(image,"%%EndData\n");
   (void) WriteBlobString(image, "/mask_stream exch def\n");
   return(status);
@@ -795,6 +800,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     status;
 
   MagickOffsetType
+    offset,
     scene,
     start,
     stop;
@@ -1270,50 +1276,50 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         else
           if ((compression == FaxCompression) ||
               (compression == Group4Compression))
-           {
-             if (LocaleCompare(CCITTParam,"0") == 0)
-               status=HuffmanEncodeImage(image_info,image);
-             else
-               status=Huffman2DEncodeImage(image_info,image);
-           }
-        else
-          {
-            status=SerializeImageChannel(image_info,image,&pixels,&length);
-            if (status == MagickFalse)
-              {
-                CloseBlob(image);
-                return(MagickFalse);
-              }
-            switch (compression)
             {
-              case NoCompression:
-              default:
+              if (LocaleCompare(CCITTParam,"0") == 0)
+                status=HuffmanEncodeImage(image_info,image);
+              else
+                status=Huffman2DEncodeImage(image_info,image);
+            }
+          else
+            {
+              status=SerializeImageChannel(image_info,image,&pixels,&length);
+              if (status == MagickFalse)
+                {
+                  CloseBlob(image);
+                  return(MagickFalse);
+                }
+              switch (compression)
               {
-                Ascii85Initialize(image);
-                for (i=0; i < (long) length; i++)
-                  Ascii85Encode(image,pixels[i]);
-                Ascii85Flush(image);
-                status=MagickTrue;
-                break;
+                case NoCompression:
+                default:
+                {
+                  Ascii85Initialize(image);
+                  for (i=0; i < (long) length; i++)
+                    Ascii85Encode(image,pixels[i]);
+                  Ascii85Flush(image);
+                  status=MagickTrue;
+                  break;
+                }
+                case LZWCompression:
+                {
+                  status=LZWEncodeImage(image,length,pixels);
+                  break;
+                }
+                case RLECompression:
+                {
+                  status=PackbitsEncodeImage(image,length,pixels);
+                  break;
+                }
+                case ZipCompression:
+                {
+                  status=ZLIBEncodeImage(image,length,pixels);
+                  break;
+                }
               }
-              case LZWCompression:
-              {
-                status=LZWEncodeImage(image,length,pixels);
-                break;
-              }
-              case RLECompression:
-              {
-                status=PackbitsEncodeImage(image,length,pixels);
-                break;
-              }
-              case ZipCompression:
-              {
-                status=ZLIBEncodeImage(image,length,pixels);
-                break;
-              }
+              pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             }
-            pixels=(unsigned char *) RelinquishMagickMemory(pixels);
-          }
       }
     else
       if ((image->storage_class == DirectClass) || (image->colors > 256) ||
@@ -1521,12 +1527,14 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     */
     length=(size_t) (TellBlob(image)-stop);
     stop=TellBlob(image);
-    (void) SeekBlob(image,start,SEEK_SET);
+    offset=SeekBlob(image,start,SEEK_SET);
+    if (offset < 0)
+      ThrowWriterException(CorruptImageError,"ImproperImageHeader");
     (void) FormatMagickString(buffer,MaxTextExtent,
       "%%%%BeginData:%13ld %s Bytes\n",(long) length,
       compression == NoCompression ? "ASCII" : "BINARY");
     (void) WriteBlobString(image,buffer);
-    (void) SeekBlob(image,stop,SEEK_SET);
+    offset=SeekBlob(image,stop,SEEK_SET);
     (void) WriteBlobString(image,"%%EndData\n");
     /*
       End private dictionary if this is an EPS.
