@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -115,7 +115,6 @@ static MagickBooleanType IsSCT(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -193,10 +192,10 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read paramter block.
   */
-  units=ReadBlobByte(image);
+  units=1UL*ReadBlobByte(image);
   if (units == 0)
     image->units=PixelsPerCentimeterResolution;
-  separations=ReadBlobByte(image);
+  separations=1UL*ReadBlobByte(image);
   separations_mask=ReadBlobMSBShort(image);
   count=ReadBlob(image,14,buffer);
   buffer[14]='\0';
@@ -205,15 +204,15 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   width=atof((char *) buffer);
   count=ReadBlob(image,12,buffer);
   buffer[12]='\0';
-  image->rows=atol((char *) buffer);
+  image->rows=1UL*atol((char *) buffer);
   count=ReadBlob(image,12,buffer);
-  image->columns=atol((char *) buffer);
+  image->columns=1UL*atol((char *) buffer);
   count=ReadBlob(image,200,buffer);
   count=ReadBlob(image,768,buffer);
   if (separations_mask == 0x0f)
     image->colorspace=CMYKColorspace;
-  image->x_resolution=image->columns/width;
-  image->y_resolution=image->rows/height;
+  image->x_resolution=1.0*image->columns/width;
+  image->y_resolution=1.0*image->rows/height;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
@@ -224,14 +223,16 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   for (y=0; y < (long) image->rows; y++)
   {
-    q=SetImagePixels(image,0,y,image->columns,1);
+    q=GetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
     for (x=0; x < (long) image->columns; x++)
     {
-      q->red=(Quantum) (QuantumRange-ScaleCharToQuantum(ReadBlobByte(image)));
+      q->red=(Quantum) ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
       q++;
     }
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
     if ((image->columns % 2) != 0)
       (void) ReadBlobByte(image);  /* pad */
     q=GetImagePixels(image,0,y,image->columns,1);
@@ -239,20 +240,24 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       break;
     for (x=0; x < (long) image->columns; x++)
     {
-      q->green=(Quantum) (QuantumRange-ScaleCharToQuantum(ReadBlobByte(image)));
+      q->green=(Quantum) ScaleCharToQuantum((unsigned char)
+        ReadBlobByte(image));
       q++;
     }
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
     if ((image->columns % 2) != 0)
       (void) ReadBlobByte(image);  /* pad */
     q=GetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      q->blue=(Quantum) (QuantumRange-ScaleCharToQuantum(ReadBlobByte(image)));
+      q->blue=(Quantum) ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
       q++;
     }
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
     if ((image->columns % 2) != 0)
       (void) ReadBlobByte(image);  /* pad */
     if (image->colorspace == CMYKColorspace)
@@ -260,10 +265,14 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         q=GetImagePixels(image,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
+        indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          indexes[x]=(IndexPacket) (QuantumRange-
-            ScaleCharToQuantum(ReadBlobByte(image)));
+          q->red=QuantumRange-q->red;
+          q->green=QuantumRange-q->green;
+          q->blue=QuantumRange-q->blue;
+          indexes[x]=(IndexPacket) (QuantumRange-ScaleCharToQuantum(
+            (unsigned char) ReadBlobByte(image)));
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
