@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -411,7 +411,7 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
         if (!height || !sun_info.width || !sun_info.depth ||
             bytes_per_line/sun_info.depth != sun_info.width)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        if ((ULONG_MAX-bytes_per_line) < 15)
+        if (((~0UL)-bytes_per_line) < 15)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         bytes_per_line+=15;
         bytes_per_line<<=1;
