@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -467,6 +467,21 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_MINSAMPLEVALUE,&min_sample_value);
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_MAXSAMPLEVALUE,&max_sample_value);
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_PHOTOMETRIC,&photometric);
+    switch (photometric)
+    {
+      case PHOTOMETRIC_MINISBLACK:
+      {
+        quantum_info.polarity=0;
+        break;
+      }
+      case PHOTOMETRIC_MINISWHITE:
+      {
+        quantum_info.polarity=1;
+        break;
+      }
+      default:
+        break;
+    }
     if (image->debug != MagickFalse)
       {
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),"Geometry: %ux%u",
@@ -485,12 +500,14 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           {
             (void) LogMagickEvent(CoderEvent,GetMagickModule(),
               "Photometric: MINISBLACK");
+            quantum_info.polarity=0;
             break;
           }
           case PHOTOMETRIC_MINISWHITE:
           {
             (void) LogMagickEvent(CoderEvent,GetMagickModule(),
               "Photometric: MINISWHITE");
+            quantum_info.polarity=1;
             break;
           }
           case PHOTOMETRIC_PALETTE:
@@ -658,25 +675,25 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_PAGENUMBER,&value,&pages);
     image->scene=value;
     if (TIFFGetField(tiff,TIFFTAG_ARTIST,&text) == 1)
-      (void) SetImageProperty(image,"Artist",text);
+      (void) SetImageProperty(image,"artist",text);
     if (TIFFGetField(tiff,TIFFTAG_DATETIME,&text) == 1)
-      (void) SetImageProperty(image,"Timestamp",text);
+      (void) SetImageProperty(image,"timestamp",text);
     if (TIFFGetField(tiff,TIFFTAG_SOFTWARE,&text) == 1)
-      (void) SetImageProperty(image,"Software",text);
+      (void) SetImageProperty(image,"software",text);
     if (TIFFGetField(tiff,TIFFTAG_HOSTCOMPUTER,&text) == 1)
-      (void) SetImageProperty(image,"HostComputer",text);
+      (void) SetImageProperty(image,"hostcomputer",text);
     if (TIFFGetField(tiff,TIFFTAG_DOCUMENTNAME,&text) == 1)
-      (void) SetImageProperty(image,"Document",text);
+      (void) SetImageProperty(image,"document",text);
     if (TIFFGetField(tiff,TIFFTAG_MAKE,&text) == 1)
-      (void) SetImageProperty(image,"Make",text);
+      (void) SetImageProperty(image,"make",text);
     if (TIFFGetField(tiff,TIFFTAG_MODEL,&text) == 1)
-      (void) SetImageProperty(image,"Model",text);
+      (void) SetImageProperty(image,"model",text);
     if (TIFFGetField(tiff,33432,&text) == 1)
-      (void) SetImageProperty(image,"Copyright",text);
+      (void) SetImageProperty(image,"copyright",text);
     if (TIFFGetField(tiff,TIFFTAG_PAGENAME,&text) == 1)
-      (void) SetImageProperty(image,"Label",text);
+      (void) SetImageProperty(image,"label",text);
     if (TIFFGetField(tiff,TIFFTAG_IMAGEDESCRIPTION,&text) == 1)
-      (void) SetImageProperty(image,"Comment",text);
+      (void) SetImageProperty(image,"comment",text);
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
@@ -1666,13 +1683,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
 #if !defined(HasJPEG) || !defined(YCBCR_SUPPORT)
         compression=RLECompression;
 #else
+        (void) SetImageStorageClass(image,DirectClass);
         (void) SetImageDepth(image,8);
-        (void) TIFFSetField(tiff,TIFFTAG_JPEGQUALITY,
-          image->quality == UndefinedCompressionQuality ? 75 : image->quality);
-        if (image->colorspace == RGBColorspace)
-          (void) TIFFSetField(tiff,TIFFTAG_JPEGCOLORMODE,JPEGCOLORMODE_RGB);
-        if (bits_per_sample == 12)
-          (void) TIFFSetField(tiff,TIFFTAG_JPEGTABLESMODE,JPEGTABLESMODE_QUANT);
 #endif
         break;
       }
@@ -1764,13 +1776,12 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
             if ((image_info->type != PaletteType) &&
                 (IsGrayImage(image,&image->exception) != MagickFalse))
               {
+                photometric=quantum_info.polarity != 0 ?
+                  PHOTOMETRIC_MINISWHITE : PHOTOMETRIC_MINISBLACK;
                 (void) TIFFSetField(tiff,TIFFTAG_SAMPLESPERPIXEL,1);
-                photometric=PHOTOMETRIC_MINISBLACK;
                 if ((image_info->depth == 0) &&
                     (IsMonochromeImage(image,&image->exception) != MagickFalse))
                   image->depth=1;
-                if (quantum_info.polarity != 0)
-                  photometric=PHOTOMETRIC_MINISWHITE;
               }
             else
               if (image->storage_class == PseudoClass)
@@ -1875,6 +1886,12 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       {
         (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,
           rows_per_strip+(16-(rows_per_strip % 16)));
+        (void) TIFFSetField(tiff,TIFFTAG_JPEGQUALITY,image_info->quality ==
+          UndefinedCompressionQuality ? image->quality : image_info->quality);
+        if (image->colorspace == RGBColorspace)
+          (void) TIFFSetField(tiff,TIFFTAG_JPEGCOLORMODE,JPEGCOLORMODE_RGB);
+        if (bits_per_sample == 12)
+          (void) TIFFSetField(tiff,TIFFTAG_JPEGTABLESMODE,JPEGTABLESMODE_QUANT);
         break;
       }
       case COMPRESSION_ADOBE_DEFLATE:
@@ -1887,7 +1904,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
             ((bits_per_sample == 8) || (bits_per_sample == 16)))
           (void) TIFFSetField(tiff,TIFFTAG_PREDICTOR,2);
         (void) TIFFSetField(tiff,TIFFTAG_ZIPQUALITY,image_info->quality ==
-          UndefinedCompressionQuality ? 7 : MagickMin(image_info->quality/10,9));
+          UndefinedCompressionQuality ? 7 : MagickMin(image_info->quality/10,
+          9));
         break;
       }
       case COMPRESSION_CCITTFAX4:
@@ -2090,7 +2108,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               else
                 (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,
                   tiff_info.scanline);
-              if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
+              if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
                 break;
               if (image->previous == (Image *) NULL)
                 if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -2118,7 +2136,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 break;
               (void) ImportQuantumPixels(image,&quantum_info,RedQuantum,
                 tiff_info.scanline);
-              if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
+              if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
                 break;
             }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2136,7 +2154,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 break;
               (void) ImportQuantumPixels(image,&quantum_info,GreenQuantum,
                 tiff_info.scanline);
-              if (TIFFWritePixels(tiff,&tiff_info,y,1,image) < 0)
+              if (TIFFWritePixels(tiff,&tiff_info,y,1,image) == -1)
                 break;
             }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2154,7 +2172,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 break;
               (void) ImportQuantumPixels(image,&quantum_info,BlueQuantum,
                 tiff_info.scanline);
-              if (TIFFWritePixels(tiff,&tiff_info,y,2,image) < 0)
+              if (TIFFWritePixels(tiff,&tiff_info,y,2,image) == -1)
                 break;
             }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2173,7 +2191,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                   break;
                 (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
                   tiff_info.scanline);
-                if (TIFFWritePixels(tiff,&tiff_info,y,3,image) < 0)
+                if (TIFFWritePixels(tiff,&tiff_info,y,3,image) == -1)
                   break;
               }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2206,7 +2224,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
           else
             (void) ImportQuantumPixels(image,&quantum_info,CMYKAQuantum,
               tiff_info.scanline);
-          if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
+          if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
             break;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -2279,7 +2297,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
              else
                (void) ImportQuantumPixels(image,&quantum_info,IndexQuantum,
                  tiff_info.scanline);
-          if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
+          if (TIFFWritePixels(tiff,&tiff_info,y,0,image) == -1)
             break;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
