@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -669,7 +669,7 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,"%ld,%ld: ",x,y);
         (void) WriteBlobString(image,buffer);
-        SetMagickPixelPacket(p,indexes+x,&pixel);
+        SetMagickPixelPacket(image,p,indexes+x,&pixel);
         (void) CopyMagickString(tuple,"(",MaxTextExtent);
         ConcatenateColorComponent(&pixel,RedChannel,tuple);
         (void) ConcatenateMagickString(tuple,",",MaxTextExtent);
