@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -291,7 +291,7 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
     /*
       Define UIL color.
     */
-    SetMagickPixelPacket(image->colormap+i,(IndexPacket *) NULL,&pixel);
+    SetMagickPixelPacket(image,image->colormap+i,(IndexPacket *) NULL,&pixel);
     pixel.colorspace=RGBColorspace;
     pixel.depth=8;
     pixel.opacity=(MagickRealType) OpaqueOpacity;
