@@ -17,7 +17,7 @@
 %                               January 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -200,7 +200,7 @@ static Image *ReadWBMPImage(const ImageInfo *image_info,
           if (byte == EOF)
             ThrowReaderException(CorruptImageError,"CorruptImage");
         }
-      indexes[x]=(byte & (0x01 << (7-bit))) ? 1 : 0;
+      indexes[x]=(IndexPacket) ((byte & (0x01 << (7-bit))) ? 1 : 0);
       bit++;
       if (bit == 8)
         bit=0;
@@ -343,15 +343,12 @@ static void WBMPWriteInteger(Image *image,const unsigned long value)
     buffer[4-i]=octet | (i && (flag || octet))*(0x01 << 7);
     bits-=7;
   }
-  (void) WriteBlob(image,n,buffer+5-n);
+  (void) WriteBlob(image,(size_t) n,buffer+5-n);
 }
 
 static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
   Image *image)
 {
-  IndexPacket
-    polarity;
-
   long
     y;
 
@@ -388,13 +385,7 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
   /*
     Convert image to a bi-level image.
   */
-  (void) SetImageType(image,PaletteType);
   (void) SetImageType(image,BilevelType);
-  polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-    (QuantumRange/2) ? 1 : 0);
-  if (image->colors == 2)
-    polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-      PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
   (void) WriteBlobMSBShort(image,0);
   WBMPWriteInteger(image,image->columns);
   WBMPWriteInteger(image,image->rows);
@@ -408,7 +399,7 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
     byte=0;
     for (x=0; x < (long) image->columns; x++)
     {
-      if (indexes[x] == polarity)
+      if (PixelIntensity(p) >= (QuantumRange/2.0))
         byte|=0x1 << (7-bit);
       bit++;
       if (bit == 8)
