@@ -17,7 +17,7 @@
 %                               November 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -281,6 +281,9 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
   int
     c;
 
+  MagickOffsetType
+    offset;
+
   register long
     i;
 
@@ -292,8 +295,8 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
   assert(max != 0);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  length = ReadBlobMSBLong(image);
-  for (i=0; i < (long) MagickMin(length, max-1); i++)
+  length=ReadBlobMSBLong(image);
+  for (i=0; i < (long) MagickMin(length,max-1); i++)
   {
     c=ReadBlobByte(image);
     if (c == EOF)
@@ -301,7 +304,10 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
     string[i]=(char) c;
   }
   string[i]='\0';
-  (void) SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
+  offset=SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
+  if (offset < 0)
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),
+      CorruptImageError,"InvalidImageHeader","`%s'",image->filename);
   return(string);
 }
 
@@ -318,6 +324,8 @@ static int load_tile (Image* image, Image* tile_image, XCFDocInfo* inDocInfo,
   xcfdata = xcfodata = (XCFPixelPacket *) AcquireMagickMemory(data_length);
   graydata = (unsigned char *)xcfdata;  /* used by gray and indexed */
   nmemb_read_successfully = ReadBlob(image, data_length, (unsigned char *) xcfdata);
+  if (nmemb_read_successfully > (ssize_t) (tile_image->columns*tile_image->rows))
+    ThrowBinaryException(CorruptImageError,"NotEnoughPixelData",image->filename);
 
   q=SetImagePixels(tile_image,0,0,tile_image->columns,tile_image->rows);
 
@@ -565,7 +573,7 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
                          than we need to allow */
 
       /* seek to the tile offset */
-      (void) SeekBlob(image, offset, SEEK_SET);
+      offset=SeekBlob(image, offset, SEEK_SET);
 
       /* allocate the image for the tile
         NOTE: the last tile in a row or column may not be a full tile!
@@ -618,7 +626,7 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
       /* restore the saved position so we'll be ready to
        *  read the next offset.
        */
-      (void) SeekBlob(image, saved_pos, SEEK_SET);
+      offset=SeekBlob(image, saved_pos, SEEK_SET);
 
       /* read in the offset of the next tile */
       offset = (MagickOffsetType) ReadBlobMSBLong(image);
@@ -668,7 +676,7 @@ static int load_hierarchy (Image *image, XCFDocInfo* inDocInfo, XCFLayerInfo*
   saved_pos = TellBlob(image);
 
   /* seek to the level offset */
-  (void) SeekBlob(image, offset, SEEK_SET);
+  offset=SeekBlob(image, offset, SEEK_SET);
 
   /* read in the level */
   if (load_level (image, inDocInfo, inLayer) == 0)
@@ -677,7 +685,7 @@ static int load_hierarchy (Image *image, XCFDocInfo* inDocInfo, XCFLayerInfo*
   /* restore the saved position so we'll be ready to
    *  read the next offset.
    */
-  (void) SeekBlob(image, saved_pos, SEEK_SET);
+  offset=SeekBlob(image, saved_pos, SEEK_SET);
 
   return 1;
 }
@@ -689,6 +697,9 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   long
     i;
 
+  MagickOffsetType
+    offset;
+
   unsigned int
     foundPropEnd = 0;
 
@@ -822,14 +833,17 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   layer_mask_offset = ReadBlobMSBLong(image);
 
   /* read in the hierarchy */
-  (void) SeekBlob(image, (MagickOffsetType) hierarchy_offset, SEEK_SET);
+  offset=SeekBlob(image, (MagickOffsetType) hierarchy_offset, SEEK_SET);
+  if (offset < 0)
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),
+      CorruptImageError,"InvalidImageHeader","`%s'",image->filename);
   if (load_hierarchy (image, inDocInfo, outLayer) == 0)
     return(MagickFalse);
 
   /* read in the layer mask */
   if (layer_mask_offset != 0)
     {
-      (void) SeekBlob(image, (MagickOffsetType) layer_mask_offset, SEEK_SET);
+      offset=SeekBlob(image, (MagickOffsetType) layer_mask_offset, SEEK_SET);
 
 #if 0  /* BOGUS: support layer masks! */
       layer_mask = xcf_load_layer_mask (info, gimage);
@@ -903,6 +917,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
+  MagickOffsetType
+    offset;
+
   register long
     i;
 
@@ -1163,7 +1180,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       else
         number_layers++;
     } while (foundAllLayers  == MagickFalse);
-    (void) SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
+    offset=SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
+    if (offset < 0)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
 
     /* allocate our array of layer info blocks */
@@ -1196,7 +1215,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       saved_pos = TellBlob(image);
 
       /* seek to the layer offset */
-      (void) SeekBlob(image, offset, SEEK_SET);
+      offset=SeekBlob(image, offset, SEEK_SET);
 
       /* read in the layer */
       layer_ok = ReadOneLayer( image, &doc_info, &layer_info[current_layer] );
@@ -1210,7 +1229,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /* restore the saved position so we'll be ready to
       *  read the next offset.
       */
-      (void) SeekBlob(image, saved_pos, SEEK_SET);
+      offset=SeekBlob(image, saved_pos, SEEK_SET);
 
       current_layer++;
     }
