@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -162,6 +162,13 @@ static char *NextXPMLine(char *p)
   return(p);
 }
 
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static char *ParseXPMColor(char *color)
 {
 #define NumberTargets  6
@@ -184,6 +191,8 @@ static char *ParseXPMColor(char *color)
     p=color;
     for (q=targets[i]; *p != '\0'; p++)
     {
+      if (*p == '\n')
+        break;
       if (*p != *q)
         continue;
       if (isspace((int) ((unsigned char) (*(p-1)))) == 0)
@@ -340,7 +349,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   {
     p=next;
     next=NextXPMLine(p);
-    (void) CopyXPMColor(key,p,(size_t) width);
+    (void) CopyXPMColor(key,p,MagickMin((size_t) width,MaxTextExtent));
     status=AddValueToSplayTree(xpm_colors,ConstantString(key),(void *) j);
     /*
       Parse color.
@@ -352,7 +361,8 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         while ((isspace((int) ((unsigned char) *q)) == 0) && (*q != '\0'))
           q++;
         if (next != (char *) NULL)
-          (void) CopyXPMColor(target,q,(size_t) (next-q));
+          (void) CopyXPMColor(target,q,MagickMin((size_t) (next-q),
+            MaxTextExtent));
         else
           (void) CopyMagickString(target,q,MaxTextExtent);
         q=ParseXPMColor(target);
@@ -717,7 +727,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
     /*
       Define XPM color.
     */
-    SetMagickPixelPacket(picon->colormap+i,(IndexPacket *) NULL,&pixel);
+    SetMagickPixelPacket(image,picon->colormap+i,(IndexPacket *) NULL,&pixel);
     pixel.colorspace=RGBColorspace;
     pixel.depth=8;
     pixel.opacity=(MagickRealType) OpaqueOpacity;
@@ -957,7 +967,7 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
     /*
       Define XPM color.
     */
-    SetMagickPixelPacket(image->colormap+i,(IndexPacket *) NULL,&pixel);
+    SetMagickPixelPacket(image,image->colormap+i,(IndexPacket *) NULL,&pixel);
     pixel.colorspace=RGBColorspace;
     pixel.depth=8;
     pixel.opacity=(MagickRealType) OpaqueOpacity;
