@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 */
 
 #if HAVE_CONFIG_H
-#  include <magick/magick-config.h>
+#  include "../magick/magick-config.h"
 #endif
 
 #if HAVE_UNISTD_H
@@ -3203,9 +3203,10 @@ try_dlopen (phandle, filename)
 	    }
 #endif
 	}
-      if (!file)
+	if (!file)
 	{
-	  file = fopen (filename, LT_READTEXT_MODE);
+	  if(strstr(filename,"/") || strcmp((filename + strlen(filename) - 3), ".la") != 0)
+	    file = fopen (filename, LT_READTEXT_MODE);
 	}
 
       /* If we didn't find the file by now, it really isn't there.  Set
