@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1470,6 +1470,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   	  if (image->matte == MagickFalse)
         (void) SetImageOpacity(image,OpaqueOpacity);
     }
+  point.x=0.0;
+  point.y=0.0;
   for (i=0; i < (long) length; i++)
   {
     glyph.id=FT_Get_Char_Index(face,text[i]);
@@ -1587,8 +1589,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         }
         image_view=CloseCacheView(image_view);
       }
-    if ((point.x+bitmap->bitmap.width-offset->x) > metrics->width)
-      metrics->width=point.x+bitmap->bitmap.width-offset->x;
+    if ((bitmap->left+bitmap->bitmap.width) > metrics->width)
+      metrics->width=bitmap->left+bitmap->bitmap.width;
     origin.x+=face->glyph->advance.x;
     metrics->origin.x=origin.x;
     metrics->origin.y=origin.y;
@@ -1596,14 +1598,6 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       FT_Done_Glyph(last_glyph.image);
     last_glyph=glyph;
   }
-  metrics->width-=metrics->bounds.x1/64.0;
-  metrics->width+=1.0;
-  metrics->bounds.x1/=64.0;
-  metrics->bounds.y1/=64.0;
-  metrics->bounds.x2/=64.0;
-  metrics->bounds.y2/=64.0;
-  metrics->origin.x/=64.0;
-  metrics->origin.y/=64.0;
   if ((draw_info->stroke.opacity != TransparentOpacity) ||
       (draw_info->stroke_pattern != (Image *) NULL))
     {
@@ -1620,6 +1614,38 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       }
   if (glyph.id != 0)
     FT_Done_Glyph(glyph.image);
+  /*
+    Determine font metrics.
+  */
+  glyph.id=0;
+  glyph.origin=origin;
+  status=FT_Load_Glyph(face,glyph.id,FT_LOAD_NO_BITMAP);
+  if (status == 0)
+    {
+      status=FT_Get_Glyph(face->glyph,&glyph.image);
+      if (status == 0)
+        {
+          status=FT_Outline_Get_BBox(&((FT_OutlineGlyph) glyph.image)->
+            outline,&bounds);
+          if (status == 0)
+            {
+              FT_Vector_Transform(&glyph.origin,&affine);
+              (void) FT_Glyph_Transform(glyph.image,&affine,&glyph.origin);
+              status=FT_Glyph_To_Bitmap(&glyph.image,ft_render_mode_normal,
+                (FT_Vector *) NULL,MagickTrue);
+              bitmap=(FT_BitmapGlyph) glyph.image;
+              if (bitmap->left > metrics->width)
+                metrics->width=bitmap->left;
+            }
+        }
+    }
+  metrics->width-=metrics->bounds.x1/64.0;
+  metrics->bounds.x1/=64.0;
+  metrics->bounds.y1/=64.0;
+  metrics->bounds.x2/=64.0;
+  metrics->bounds.y2/=64.0;
+  metrics->origin.x/=64.0;
+  metrics->origin.y/=64.0;
   /*
     Free resources.
   */
