@@ -17,7 +17,7 @@
 %                                 May 2001                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -124,6 +124,7 @@ static const char
     "  <coder magick=\"MNG\" name=\"PNG\" />"
     "  <coder magick=\"MPG\" name=\"MPEG\" />"
     "  <coder magick=\"MPRI\" name=\"MPR\" />"
+    "  <coder magick=\"MSVG\" name=\"SVG\" />"
     "  <coder magick=\"NETSCAPE\" name=\"MAGICK\" />"
     "  <coder magick=\"O\" name=\"GRAY\" />"
     "  <coder magick=\"OTF\" name=\"TTF\" />"
@@ -335,7 +336,7 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
   for (i=0; p != (const CoderInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       coder_map[i++]=p;
     p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
   }
@@ -420,7 +421,7 @@ MagickExport char **GetCoderList(const char *pattern,
   for (i=0; p != (const CoderInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       coder_map[i++]=ConstantString(p->name);
     p=(const CoderInfo *) GetNextValueInSplayTree(coder_list);
   }
@@ -653,8 +654,11 @@ static MagickBooleanType LoadCoderList(const char *xml,const char *filename,
                 MaxTextExtent);
             (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
             xml=FileToString(path,~0,exception);
-            status=LoadCoderList(xml,path,depth+1,exception);
-            xml=DestroyString(xml);
+            if (xml != (char *) NULL)
+              {
+                status=LoadCoderList(xml,path,depth+1,exception);
+                xml=DestroyString(xml);
+              }
           }
       }
     include=GetNextXMLTreeTag(include);
