@@ -17,7 +17,7 @@
 %                               December 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -223,14 +223,14 @@ MagickExport Image *CompareImageChannels(Image *image,
           (image->colorspace == CMYKColorspace))
         if (indexes[x] != reconstruct_indexes[x])
           difference=MagickTrue;
-      SetMagickPixelPacket(q,reconstruct_indexes+x,&source);
+      SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,&source);
       if (difference != MagickFalse)
         MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&red,
           (MagickRealType) red.opacity,&composite);
       else
         MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&white,
           (MagickRealType) white.opacity,&composite);
-      SetPixelPacket(&composite,r,difference_indexes+x);
+      SetPixelPacket(difference_image,&composite,r,difference_indexes+x);
       p++;
       q++;
       r++;
@@ -341,8 +341,9 @@ static MagickRealType GetAbsoluteError(const Image *image,
     reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
-      SetMagickPixelPacket(p,indexes+x,&image_pixel);
-      SetMagickPixelPacket(q,reconstruct_indexes+x,&reconstruct_pixel);
+      SetMagickPixelPacket(image,p,indexes+x,&image_pixel);
+      SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,
+        &reconstruct_pixel);
       if (IsMagickColorSimilar(&image_pixel,&reconstruct_pixel) == MagickFalse)
         distortion++;
       p++;
