@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1023,6 +1023,9 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   threshold=0.05f;
   switch (compose)
   {
+    /*
+      These operators modify destination outside the overlaid region.
+    */
     case ClearCompositeOp:
     case SrcCompositeOp:
     case SrcInCompositeOp:
@@ -1032,13 +1035,15 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     case DstInCompositeOp:
     case DstAtopCompositeOp:
     {
-      /*
-        These operators modify destination outside the overlaid region.
-      */
       modify_outside_overlay=MagickTrue;
       break;
     }
+    /*
+      These operators modify destination outside the overlaid region.
+      and require an alpha channel to exist, to add transparency.
+    */
     case CopyOpacityCompositeOp:
+    case ChangeMaskCompositeOp:
     {
       if (image->matte == MagickFalse)
         (void) SetImageOpacity(image,OpaqueOpacity);
@@ -1130,7 +1135,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           pixel=InterpolatePixelColor(image,image_view,image->interpolate,
             (double) (x_offset+x+x_displace),(double) (y_offset+y+y_displace),
             &image->exception);
-          SetPixelPacket(&pixel,r,displace_indexes+x);
+          SetPixelPacket(displace_image,&pixel,r,displace_indexes+x);
           p++;
           q++;
           r++;
@@ -1326,6 +1331,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             case DstInCompositeOp:
             case DstAtopCompositeOp:
             case CopyOpacityCompositeOp:
+            case ChangeMaskCompositeOp:
             {
               composite.opacity=(MagickRealType) TransparentOpacity;
               break;
@@ -1381,6 +1387,15 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           composite=source;
           break;
         }
+        case ChangeMaskCompositeOp:
+        {
+          if ((composite.opacity > ((MagickRealType) QuantumRange/2.0)) ||
+              IsMagickColorSimilar(&source,&destination))
+            composite.opacity=(MagickRealType) TransparentOpacity;
+          else
+            composite.opacity=(MagickRealType) OpaqueOpacity;
+          break;
+        }
         case DstCompositeOp:
           break;
         case OverCompositeOp:
