@@ -17,7 +17,7 @@
 %                                 July 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -317,7 +317,7 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
   for (i=0; p != (const ConfigureInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       options[i++]=p;
     p=(const ConfigureInfo *) GetNextValueInLinkedList(configure_list);
   }
@@ -410,7 +410,7 @@ MagickExport char **GetConfigureList(const char *pattern,
   for (i=0; p != (const ConfigureInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       options[i++]=ConstantString(p->name);
     p=(const ConfigureInfo *) GetNextValueInLinkedList(configure_list);
   }
@@ -965,8 +965,11 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
                 MaxTextExtent);
             (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
             xml=FileToString(path,~0,exception);
-            status=LoadConfigureList(xml,path,depth+1,exception);
-            xml=DestroyString(xml);
+            if (xml != (char *) NULL)
+              {
+                status=LoadConfigureList(xml,path,depth+1,exception);
+                xml=DestroyString(xml);
+              }
           }
       }
     include=GetNextXMLTreeTag(include);
