@@ -17,7 +17,7 @@
 %                                   July 1992                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -232,13 +232,16 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     Initialize 3D effects color.
   */
   GetMagickPixelPacket(frame_image,&interior);
-  SetMagickPixelPacket(&image->border_color,(IndexPacket *) NULL,&interior);
+  SetMagickPixelPacket(frame_image,&image->border_color,(IndexPacket *) NULL,
+    &interior);
   GetMagickPixelPacket(frame_image,&matte);
   matte.colorspace=RGBColorspace;
-  SetMagickPixelPacket(&image->matte_color,(IndexPacket *) NULL,&matte);
+  SetMagickPixelPacket(frame_image,&image->matte_color,(IndexPacket *) NULL,
+    &matte);
   GetMagickPixelPacket(frame_image,&border);
   border.colorspace=RGBColorspace;
-  SetMagickPixelPacket(&image->border_color,(IndexPacket *) NULL,&border);
+  SetMagickPixelPacket(frame_image,&image->border_color,(IndexPacket *) NULL,
+    &border);
   GetMagickPixelPacket(frame_image,&accentuate);
   accentuate.red=QuantumScale*((QuantumRange-AccentuateModulate)*matte.red+
     (QuantumRange*AccentuateModulate));
@@ -289,15 +292,15 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
         for (x=0; x < (long) (frame_image->columns-y); x++)
         {
           if (x < y)
-            SetPixelPacket(&highlight,q,frame_indexes);
+            SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           else
-            SetPixelPacket(&accentuate,q,frame_indexes);
+            SetPixelPacket(frame_image,&accentuate,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for ( ; x < (long) frame_image->columns; x++)
         {
-          SetPixelPacket(&shadow,q,frame_indexes);
+          SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           q++;
           frame_indexes++;
         }
@@ -306,20 +309,20 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
       {
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&highlight,q,frame_indexes);
+          SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         width=frame_image->columns-2*frame_info->outer_bevel;
         for (x=0; x < (long) width; x++)
         {
-          SetPixelPacket(&matte,q,frame_indexes);
+          SetPixelPacket(frame_image,&matte,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&shadow,q,frame_indexes);
+          SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           q++;
           frame_indexes++;
         }
@@ -328,13 +331,13 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
       {
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&highlight,q,frame_indexes);
+          SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < (long) (frame_info->x-bevel_width); x++)
         {
-          SetPixelPacket(&matte,q,frame_indexes);
+          SetPixelPacket(frame_image,&matte,q,frame_indexes);
           q++;
           frame_indexes++;
         }
@@ -342,28 +345,28 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
         for (x=0; x < (long) width; x++)
         {
           if (x < y)
-            SetPixelPacket(&shadow,q,frame_indexes);
+            SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           else
-            SetPixelPacket(&trough,q,frame_indexes);
+            SetPixelPacket(frame_image,&trough,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for ( ; x < (long) (image->columns+2*frame_info->inner_bevel); x++)
         {
-          SetPixelPacket(&highlight,q,frame_indexes);
+          SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         width=frame_info->width-frame_info->x-image->columns-bevel_width;
         for (x=0; x < (long) width; x++)
         {
-          SetPixelPacket(&matte,q,frame_indexes);
+          SetPixelPacket(frame_image,&matte,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&shadow,q,frame_indexes);
+          SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           q++;
           frame_indexes++;
         }
@@ -384,19 +387,19 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     frame_indexes=GetIndexes(frame_image);
     for (x=0; x < (long) frame_info->outer_bevel; x++)
     {
-      SetPixelPacket(&highlight,q,frame_indexes);
+      SetPixelPacket(frame_image,&highlight,q,frame_indexes);
       q++;
       frame_indexes++;
     }
     for (x=0; x < (long) (frame_info->x-bevel_width); x++)
     {
-      SetPixelPacket(&matte,q,frame_indexes);
+      SetPixelPacket(frame_image,&matte,q,frame_indexes);
       q++;
       frame_indexes++;
     }
     for (x=0; x < (long) frame_info->inner_bevel; x++)
     {
-      SetPixelPacket(&shadow,q,frame_indexes);
+      SetPixelPacket(frame_image,&shadow,q,frame_indexes);
       q++;
       frame_indexes++;
     }
@@ -405,26 +408,26 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     */
     for (x=0; x < (long) image->columns; x++)
     {
-      SetPixelPacket(&interior,q,frame_indexes);
+      SetPixelPacket(frame_image,&interior,q,frame_indexes);
       q++;
       frame_indexes++;
     }
     for (x=0; x < (long) frame_info->inner_bevel; x++)
     {
-      SetPixelPacket(&highlight,q,frame_indexes);
+      SetPixelPacket(frame_image,&highlight,q,frame_indexes);
       q++;
       frame_indexes++;
     }
     width=frame_info->width-frame_info->x-image->columns-bevel_width;
     for (x=0; x < (long) width; x++)
     {
-      SetPixelPacket(&matte,q,frame_indexes);
+      SetPixelPacket(frame_image,&matte,q,frame_indexes);
       q++;
       frame_indexes++;
     }
     for (x=0; x < (long) frame_info->outer_bevel; x++)
     {
-      SetPixelPacket(&shadow,q,frame_indexes);
+      SetPixelPacket(frame_image,&shadow,q,frame_indexes);
       q++;
       frame_indexes++;
     }
@@ -453,41 +456,41 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
       {
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&highlight,q,frame_indexes);
+          SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < (long) (frame_info->x-bevel_width); x++)
         {
-          SetPixelPacket(&matte,q,frame_indexes);
+          SetPixelPacket(frame_image,&matte,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < y; x++)
         {
-          SetPixelPacket(&shadow,q,frame_indexes);
+          SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for ( ; x < (long) (image->columns+2*frame_info->inner_bevel); x++)
         {
           if (x >= (long) (image->columns+2*frame_info->inner_bevel-y))
-            SetPixelPacket(&highlight,q,frame_indexes);
+            SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           else
-            SetPixelPacket(&accentuate,q,frame_indexes);
+            SetPixelPacket(frame_image,&accentuate,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         width=frame_info->width-frame_info->x-image->columns-bevel_width;
         for (x=0; x < (long) width; x++)
         {
-          SetPixelPacket(&matte,q,frame_indexes);
+          SetPixelPacket(frame_image,&matte,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&shadow,q,frame_indexes);
+          SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           q++;
           frame_indexes++;
         }
@@ -497,20 +500,20 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
       {
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&highlight,q,frame_indexes);
+          SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         width=frame_image->columns-2*frame_info->outer_bevel;
         for (x=0; x < (long) width; x++)
         {
-          SetPixelPacket(&matte,q,frame_indexes);
+          SetPixelPacket(frame_image,&matte,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for (x=0; x < (long) frame_info->outer_bevel; x++)
         {
-          SetPixelPacket(&shadow,q,frame_indexes);
+          SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           q++;
           frame_indexes++;
         }
@@ -519,16 +522,16 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
       {
         for (x=0; x < y; x++)
         {
-          SetPixelPacket(&highlight,q,frame_indexes);
+          SetPixelPacket(frame_image,&highlight,q,frame_indexes);
           q++;
           frame_indexes++;
         }
         for ( ; x < (long) frame_image->columns; x++)
         {
           if (x >= (long) (frame_image->columns-y))
-            SetPixelPacket(&shadow,q,frame_indexes);
+            SetPixelPacket(frame_image,&shadow,q,frame_indexes);
           else
-            SetPixelPacket(&trough,q,frame_indexes);
+            SetPixelPacket(frame_image,&trough,q,frame_indexes);
           q++;
           frame_indexes++;
         }
