@@ -16,7 +16,7 @@
 %                               October 1998                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -133,7 +133,7 @@ static const char
     "  <delegate decode=\"shtml\" command='\"html2ps\" -U -o \"%o\" \"%i\"' />"
     "  <delegate decode=\"txt\" encode=\"ps\" mode=\"bi\" command='\"enscript\" -o \"%o\" \"%i\"' />"
     "  <delegate decode=\"wmf\" command='\"wmf2eps\" -o \"%o\" \"%i\"' />"
-    "  <delegate encode=\"show\" stealth=\"True\" spawn=\"True\" command='\"display\" -immutable -delay 0 -window_group %g -title \"%l of %f\" \"tmp:%i\"' />"
+    "  <delegate encode=\"show\" stealth=\"True\" spawn=\"True\" command='\"display\" -immutable -delay 0 -window-group %g -title \"%l of %f\" \"tmp:%i\"' />"
     "</delegatemap>";
 
 /*
@@ -494,8 +494,8 @@ MagickExport const DelegateInfo **GetDelegateInfoList(const char *pattern,
   for (i=0; p != (const DelegateInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        ((GlobExpression(p->decode,pattern) != MagickFalse) ||
-         (GlobExpression(p->encode,pattern) != MagickFalse)))
+        ((GlobExpression(p->decode,pattern,MagickFalse) != MagickFalse) ||
+         (GlobExpression(p->encode,pattern,MagickFalse) != MagickFalse)))
       delegates[i++]=p;
     p=(const DelegateInfo *) GetNextValueInLinkedList(delegate_list);
   }
@@ -587,10 +587,10 @@ MagickExport char **GetDelegateList(const char *pattern,
   for (i=0; p != (const DelegateInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->decode,pattern) != MagickFalse))
+        (GlobExpression(p->decode,pattern,MagickFalse) != MagickFalse))
       delegates[i++]=ConstantString(p->decode);
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->encode,pattern) != MagickFalse))
+        (GlobExpression(p->encode,pattern,MagickFalse) != MagickFalse))
       delegates[i++]=ConstantString(p->encode);
     p=(const DelegateInfo *) GetNextValueInLinkedList(delegate_list);
   }
@@ -984,6 +984,8 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
       (void) ConcatenateString(&command," &");
     status=SystemCommand(image_info->verbose,command) != 0 ?  MagickTrue :
       MagickFalse;
+    if (delegate_info->spawn != MagickFalse)
+      (void) sleep(2);
     command=DestroyString(command);
     (void) RelinquishUniqueFileResource(image->filename);
     (void) RelinquishUniqueFileResource(image_info->unique);
@@ -1090,11 +1092,11 @@ MagickExport MagickBooleanType ListDelegateInfo(FILE *file,
       delegate_info[i]->decode : "",delegate_info[i]->mode <= 0 ? '<' : ' ',
       delegate_info[i]->mode >= 0 ? '>' : ' ',delegate);
     StripString(commands[0]);
-    (void) fprintf(file,"%s\n",commands[0]);
+    (void) fprintf(file,"\"%s\"\n",commands[0]);
     for (j=1; commands[j] != (char *) NULL; j++)
     {
       StripString(commands[j]);
-      (void) fprintf(file,"                     %s\n",commands[j]);
+      (void) fprintf(file,"                     \"%s\"\n",commands[j]);
     }
     for (j=0; commands[j] != (char *) NULL; j++)
       commands[j]=DestroyString(commands[j]);
@@ -1198,8 +1200,11 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
                 MaxTextExtent);
             (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
             xml=FileToString(path,~0,exception);
-            status=LoadDelegateList(xml,path,depth+1,exception);
-            xml=DestroyString(xml);
+            if (xml != (char *) NULL)
+              {
+                status=LoadDelegateList(xml,path,depth+1,exception);
+                xml=DestroyString(xml);
+              }
           }
       }
     include=GetNextXMLTreeTag(include);
