@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@
 extern "C" {
 #endif
 
+#include "magick/cache.h"
 #include "magick/image.h"
 #include "magick/memory_.h"
 
@@ -34,11 +35,16 @@ static inline PixelPacket GetFillColor(const DrawInfo *draw_info,
   PixelPacket
     fill_color;
 
+  VirtualPixelMethod
+    method;
+
   pattern=draw_info->fill_pattern;
   if (pattern == (Image *) NULL)
     return(draw_info->fill);
-  fill_color=AcquireOnePixel(pattern,x+pattern->origin.x,
-    y+pattern->origin.y,&pattern->exception);
+  method=SetImageVirtualPixelMethod(pattern,TileVirtualPixelMethod);
+  fill_color=AcquireOnePixel(pattern,x+pattern->origin.x,y+pattern->origin.y,
+    &pattern->exception);
+  (void) SetImageVirtualPixelMethod(pattern,method);
   if (pattern->matte == MagickFalse)
     fill_color.opacity=OpaqueOpacity;
   return(fill_color);
@@ -53,11 +59,16 @@ static inline PixelPacket GetStrokeColor(const DrawInfo *draw_info,
   PixelPacket
     stroke_color;
 
+  VirtualPixelMethod
+    method;
+
   pattern=draw_info->stroke_pattern;
   if (pattern == (Image *) NULL)
     return(draw_info->stroke);
+  method=SetImageVirtualPixelMethod(pattern,TileVirtualPixelMethod);
   stroke_color=AcquireOnePixel(pattern,x+pattern->origin.x,y+pattern->origin.y,
     &pattern->exception);
+  (void) SetImageVirtualPixelMethod(pattern,method);
   if (pattern->matte == MagickFalse)
     stroke_color.opacity=OpaqueOpacity;
   return(stroke_color);
