@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ extern "C" {
 #endif
 
 #include "magick/type.h"
+#include "magick/pixel.h"
 
 typedef enum
 {
@@ -120,23 +121,35 @@ typedef enum
 {
   UndefinedSpread,
   PadSpread,
-  ReflectSpead,
+  ReflectSpread,
   RepeatSpread
 } SpreadMethod;
 
+typedef struct _StopInfo
+{
+  MagickPixelPacket
+    color;
+
+  MagickRealType
+    offset;
+} StopInfo;
+
 typedef struct _GradientInfo
 {
   GradientType
     type;
 
-  PixelPacket
-    color;
+  RectangleInfo
+    bounding_box;
 
   SegmentInfo
-    stop;
+    gradient_vector;
+
+  StopInfo
+    *stops;
 
   unsigned long
-    length;
+    number_stops;
 
   SpreadMethod
     spread;
@@ -146,10 +159,6 @@ typedef struct _GradientInfo
 
   unsigned long
     signature;
-
-  struct _GradientInfo
-    *previous,
-    *next;
 } GradientInfo;
 
 typedef struct _ElementReference
@@ -269,7 +278,7 @@ typedef struct _DrawInfo
     *dash_pattern;
 
   char
-    *clip_path;
+    *clip_mask;
 
   SegmentInfo
     bounds;
@@ -334,15 +343,20 @@ typedef struct _TypeMetric
 
   SegmentInfo
     bounds;
+
+  PointInfo
+    origin;
 } TypeMetric;
 
 extern MagickExport DrawInfo
+  *AcquireDrawInfo(void),
   *CloneDrawInfo(const ImageInfo *,const DrawInfo *),
   *DestroyDrawInfo(DrawInfo *);
 
 extern MagickExport MagickBooleanType
   DrawAffineImage(Image *,const Image *,const AffineMatrix *),
   DrawClipPath(Image *,const DrawInfo *,const char *),
+  DrawGradientImage(Image *,const DrawInfo *),
   DrawImage(Image *,const DrawInfo *),
   DrawPatternPath(Image *,const DrawInfo *,const char *,Image **),
   DrawPrimitive(Image *,const DrawInfo *,const PrimitiveInfo *);
