@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -41,7 +41,6 @@ extern MagickExport Image
      ExceptionInfo *),
   *AdaptiveSharpenImageChannel(const Image *,const ChannelType,const double,
     const double,ExceptionInfo *),
-  *AdaptiveThresholdImage(const Image *,const unsigned long,const unsigned long,    const long,ExceptionInfo *),
   *AddNoiseImage(const Image *,const NoiseType,ExceptionInfo *),
   *AddNoiseImageChannel(const Image *,const ChannelType,const NoiseType,
     ExceptionInfo *),
@@ -73,15 +72,6 @@ extern MagickExport Image
   *UnsharpMaskImageChannel(const Image *,const ChannelType,const double,
     const double,const double,const double,ExceptionInfo *);
 
-extern MagickExport MagickBooleanType
-  BlackThresholdImage(Image *,const char *),
-  BilevelImage(Image *,const double),
-  BilevelImageChannel(Image *,const ChannelType,const double),
-  RandomThresholdImage(Image *,const char *,ExceptionInfo *),
-  RandomThresholdImageChannel(Image *,const ChannelType,const char *,
-    ExceptionInfo *),
-  WhiteThresholdImage(Image *,const char *);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
