@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -230,7 +230,7 @@ MagickExport MagickBooleanType ContrastStretchImage(Image *image,
 MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
   const ChannelType channel,const double black_point,const double white_point)
 {
-#define MaxRange(color)  ((MagickRealType) ScaleQuantumToMap(color))
+#define MaxRange(color)  ((MagickRealType) ScaleQuantumToMap((Quantum) (color)))
 #define NormalizeImageTag  "Normalize/Image"
 
   double
@@ -1385,7 +1385,7 @@ MagickExport MagickBooleanType LinearStretchImage(Image *image,
   /*
     Form histogram.
   */
-  ResetMagickMemory(histogram,0,(MaxMap+1)*sizeof(*histogram));
+  (void) ResetMagickMemory(histogram,0,(MaxMap+1)*sizeof(*histogram));
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -1657,11 +1657,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               (image->colormap[i].green != image->colormap[i].blue))
             continue;
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=QuantumRange-image->colormap[i].red;
+          image->colormap[i].red=(Quantum) QuantumRange-image->colormap[i].red;
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=QuantumRange-image->colormap[i].green;
+          image->colormap[i].green=(Quantum) QuantumRange-
+            image->colormap[i].green;
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=QuantumRange-image->colormap[i].blue;
+          image->colormap[i].blue=(Quantum) QuantumRange-
+            image->colormap[i].blue;
       }
     }
   /*
@@ -1683,17 +1685,17 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               continue;
             }
           if ((channel & RedChannel) != 0)
-            q->red=QuantumRange-q->red;
+            q->red=(Quantum) QuantumRange-q->red;
           if ((channel & GreenChannel) != 0)
-            q->green=QuantumRange-q->green;
+            q->green=(Quantum) QuantumRange-q->green;
           if ((channel & BlueChannel) != 0)
-            q->blue=QuantumRange-q->blue;
+            q->blue=(Quantum) QuantumRange-q->blue;
           if (((channel & OpacityChannel) != 0) &&
               (image->matte != MagickFalse))
-            q->opacity=QuantumRange-q->opacity;
+            q->opacity=(Quantum) QuantumRange-q->opacity;
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
-            indexes[x]=QuantumRange-indexes[x];
+            indexes[x]=(IndexPacket) QuantumRange-indexes[x];
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -1721,16 +1723,16 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=QuantumRange-q->red;
+        q->red=(Quantum) QuantumRange-q->red;
       if ((channel & GreenChannel) != 0)
-        q->green=QuantumRange-q->green;
+        q->green=(Quantum) QuantumRange-q->green;
       if ((channel & BlueChannel) != 0)
-        q->blue=QuantumRange-q->blue;
+        q->blue=(Quantum) QuantumRange-q->blue;
       if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=QuantumRange-q->opacity;
+        q->opacity=(Quantum) QuantumRange-q->opacity;
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
-        indexes[x]=QuantumRange-indexes[x];
+        indexes[x]=(IndexPacket) QuantumRange-indexes[x];
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1852,9 +1854,9 @@ MagickExport MagickBooleanType SigmoidalContrastImage(Image *image,
 
   flags=ParseGeometry(levels,&geometry_info);
   if ((flags & SigmaValue) == 0)
-    geometry_info.sigma=QuantumRange/2.0;
+    geometry_info.sigma=1.0*QuantumRange/2.0;
   if ((flags & PercentValue) != 0)
-    geometry_info.sigma=QuantumRange*geometry_info.sigma/100.0;
+    geometry_info.sigma=1.0*QuantumRange*geometry_info.sigma/100.0;
   status=SigmoidalContrastImageChannel(image,DefaultChannels,sharpen,
     geometry_info.rho,geometry_info.sigma);
   return(status);
