@@ -17,7 +17,7 @@
 %                                 August 1996                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -753,7 +753,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
       for (i=0; i < 16L; i++)
       {
         GetMagickPixelPacket(image,pixels+i);
-        SetMagickPixelPacket(p,indexes+i,pixels+i);
+        SetMagickPixelPacket(image,p,indexes+i,pixels+i);
         alpha[i]=1.0;
         if (image->matte != MagickFalse)
           {
@@ -803,7 +803,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         for (j=(-1); j < 3L; j++)
         {
           GetMagickPixelPacket(image,pixels+n);
-          SetMagickPixelPacket(p,indexes+n,pixels+n);
+          SetMagickPixelPacket(image,p,indexes+n,pixels+n);
           alpha[n]=1.0;
           if (image->matte != MagickFalse)
             {
@@ -841,7 +841,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
       for (i=0; i < 4L; i++)
       {
         GetMagickPixelPacket(image,pixels+i);
-        SetMagickPixelPacket(p,indexes+i,pixels+i);
+        SetMagickPixelPacket(image,p,indexes+i,pixels+i);
         alpha[i]=1.0;
         if (image->matte != MagickFalse)
           {
@@ -906,19 +906,19 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         }
       indexes=GetIndexes(zoom_image);
       GetMagickPixelPacket(image,pixels);
-      SetMagickPixelPacket(p,indexes,&pixel);
+      SetMagickPixelPacket(image,p,indexes,&pixel);
       zoom_image=DestroyImage(zoom_image);
       break;
     }
     case IntegerInterpolatePixel:
     {
-      p=AcquireCacheView(image_view,(long) floor(x+0.5),(long) floor(y+0.5),1,1,
+      p=AcquireCacheView(image_view,(long) floor(x),(long) floor(y),1,1,
         exception);
       if (p == (const PixelPacket *) NULL)
         return(pixel);
       indexes=GetCacheViewIndexes(image_view);
       GetMagickPixelPacket(image,pixels);
-      SetMagickPixelPacket(p,indexes,&pixel);
+      SetMagickPixelPacket(image,p,indexes,&pixel);
       break;
     }
     case MeshInterpolatePixel:
@@ -934,7 +934,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
       for (i=0; i < 4L; i++)
       {
         GetMagickPixelPacket(image,pixels+i);
-        SetMagickPixelPacket(p,indexes+i,pixels+i);
+        SetMagickPixelPacket(image,p,indexes+i,pixels+i);
         alpha[i]=1.0;
         if (image->matte != MagickFalse)
           {
@@ -1057,7 +1057,7 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
         return(pixel);
       indexes=GetCacheViewIndexes(image_view);
       GetMagickPixelPacket(image,pixels);
-      SetMagickPixelPacket(p,indexes,&pixel);
+      SetMagickPixelPacket(image,p,indexes,&pixel);
       break;
     }
   }
