@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -76,6 +76,7 @@ extern MagickExport MagickBooleanType
 extern MagickExport MagickStatusType
   GetGeometry(const char *,long *,long *,unsigned long *,unsigned long *),
   ParseAbsoluteGeometry(const char *,RectangleInfo *),
+  ParseAffineGeometry(const char *,AffineMatrix *),
   ParseGeometry(const char *,GeometryInfo *),
   ParseGravityGeometry(Image *,const char *,RectangleInfo *),
   ParseMetaGeometry(const char *,long *,long *,unsigned long *,unsigned long *),
@@ -83,6 +84,8 @@ extern MagickExport MagickStatusType
   ParseSizeGeometry(Image *,const char *,RectangleInfo *);
 
 extern MagickExport void
+  GravityAdjustGeometry(const unsigned long,const unsigned long,
+    const GravityType,RectangleInfo *),
   SetGeometry(const Image *,RectangleInfo *),
   SetGeometryInfo(GeometryInfo *);
 
