@@ -482,16 +482,17 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
                 pixel;
 
               GetMagickPixelPacket(image,&pixel);
-              SetMagickPixelPacket(p,indexes+x,&pixel);
-              (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickFalse,
-                tuple,&image->exception);
+              SetMagickPixelPacket(image,p,indexes+x,&pixel);
+              (void) QueryMagickColorname(image,&pixel,SVGCompliance,
+                MagickFalse,tuple,&image->exception);
               (void) fprintf(file,"  Alpha: %s  ",tuple);
               (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickTrue,
                 tuple,&image->exception);
               (void) fprintf(file,"  %s\n",tuple);
             }
         }
-      image->total_colors=GetNumberColors(image,(FILE *) NULL,&image->exception);
+      image->total_colors=GetNumberColors(image,(FILE *) NULL,
+        &image->exception);
       (void) fprintf(file,"  Colors: %lu\n",image->total_colors);
       if ((ping == MagickFalse) && (image->total_colors <= 1024))
         {
@@ -518,7 +519,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           p=image->colormap;
           for (i=0; i < (long) image->colors; i++)
           {
-            SetMagickPixelPacket(p,(IndexPacket *) NULL,&pixel);
+            SetMagickPixelPacket(image,p,(IndexPacket *) NULL,&pixel);
             (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickFalse,
               color,&image->exception);
             (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickTrue,
@@ -722,7 +723,6 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           continue;
         (void) fprintf(file,"  Profile-%s: %lu bytes\n",name,(unsigned long)
           GetStringInfoLength(profile));
-        PrintStringInfo(file,name,profile);
         if (LocaleCompare(name,"iptc") == 0)
           {
             char
@@ -836,6 +836,8 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
                 }
             }
           }
+        if (image->debug != MagickFalse)
+          PrintStringInfo(file,name,profile);
         name=GetNextImageProfile(image);
       }
     }
