@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/www/Copyright.html
+    http://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -13,17 +13,17 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick identify command method.
+  MagickCore image identify method.
 */
-#ifndef _MAGICK_IDENTIFY_H
-#define _MAGICK_IDENTIFY_H
+#ifndef _MAGICKCORE_IDENTIFY_H
+#define _MAGICKCORE_IDENTIFY_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
 #endif
 
 extern MagickExport MagickBooleanType
-  IdentifyImageCommand(ImageInfo *,int,char **,char **,ExceptionInfo *);
+  IdentifyImage(Image *,FILE *,const MagickBooleanType);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
