@@ -17,7 +17,7 @@
 %                               December 2002                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -60,7 +60,8 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  AppendImageToList() appends an image to the end of the list.
+%  AppendImageToList() appends the second image list to the end of the first
+%  list.  The given image list pointer is left unchanged, unless it was empty.
 %
 %  The format of the AppendImageToList method is:
 %
@@ -68,16 +69,16 @@
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
-%
-%    o image: The image.
+%    o images: The image list to be appended to.
 %
+%    o image: The appended image or image list.
 %
 */
 MagickExport void AppendImageToList(Image **images,const Image *image)
 {
   register Image
-    *p;
+    *p,
+    *q;
 
   assert(images != (Image **) NULL);
   if (image == (Image *) NULL)
@@ -91,9 +92,10 @@ MagickExport void AppendImageToList(Image **images,const Image *image)
       return;
     }
   assert((*images)->signature == MagickSignature);
-  for (p=(*images); p->next != (Image *) NULL; p=p->next);
-  p->next=(Image *) image;
-  p->next->previous=p;
+  p=GetLastImageInList(*images);
+  q=GetFirstImageInList(image);
+  p->next=q;
+  q->previous=p;
   SyncImageList(*images);
 }
 
@@ -120,7 +122,6 @@ MagickExport void AppendImageToList(Image **images,const Image *image)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *CloneImageList(const Image *images,ExceptionInfo *exception)
 {
@@ -170,7 +171,16 @@ MagickExport Image *CloneImageList(const Image *images,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  CloneImages() clones one or more images from an image sequence.
+%  CloneImages() clones one or more images from an image sequence, using a
+%  comma separated list of image numbers or ranges.
+%
+%  The numbers start at 0 for the first image in the list, while negative
+%  numbers refer to images starting counting from the end of the range. Images
+%  may be refered to multiple times to clone them multiple times. Images
+%  refered beyond the available number of images in list are ignored.
+%
+%  Images referenced may be reversed, and results in a clone of those images
+%  also being made with a reversed order.
 %
 %  The format of the CloneImages method is:
 %
@@ -182,7 +192,7 @@ MagickExport Image *CloneImageList(const Image *images,ExceptionInfo *exception)
 %    o images: The image sequence.
 %
 %    o scenes: This character string specifies which scenes to clone
-%      (e.g. 1,3-5,7-6,2).
+%      (e.g. 1,3-5,7-3,2).
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -191,7 +201,7 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
   ExceptionInfo *exception)
 {
   char
-    *q;
+    *p;
 
   const Image
     *next;
@@ -201,12 +211,10 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
     *image;
 
   long
+    length,
     first,
     last,
-    quantum;
-
-  register const char
-    *p;
+    step;
 
   register long
     i;
@@ -219,30 +227,29 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   clone_images=NewImageList();
-  p=scenes;
-  for (q=(char *) scenes; *q != '\0'; p++)
+  images=GetFirstImageInList(images);
+  length=GetImageListLength(images);
+  for (p=(char *) scenes; *p != '\0';)
   {
     while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
       p++;
-    first=strtol(p,&q,10);
-    if (first < 0)
-      first+=GetImageListLength(images);
+    first=strtol(p,&p,10);
+    if (first < 0) first+=length;
     last=first;
-    while (isspace((int) ((unsigned char) *q)) != 0)
-      q++;
-    if (*q == '-')
+    while (isspace((int) ((unsigned char) *p)) != 0)
+      p++;
+    if (*p == '-')
       {
-        last=strtol(q+1,&q,10);
+        last=strtol(p+1,&p,10);
         if (last < 0)
-          last+=GetImageListLength(images);
+          last+=length;
       }
-    quantum=first > last ? -1 : 1;
-    for (p=q; first != (last+quantum); first+=quantum)
+    for (step=first > last ? -1 : 1; first != (last+step); first+=step)
     {
       i=0;
       for (next=images; next != (Image *) NULL; next=GetNextImageInList(next))
       {
-        if (i == (long) first)
+        if (i == first)
           {
             image=CloneImage(next,0,0,MagickTrue,exception);
             if (image == (Image *) NULL)
@@ -253,8 +260,6 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
       }
     }
   }
-  if (clone_images == (Image *) NULL)
-    return((Image *) NULL);
   return(GetFirstImageInList(clone_images));
 }
 
@@ -269,7 +274,8 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DeleteImageFromList() deletes an image from the list.
+%  DeleteImageFromList() deletes an image from the list. List pointer
+%  is moved to the next image, if one is present. See RemoveImageFromList().
 %
 %  The format of the DeleteImageFromList method is:
 %
@@ -279,37 +285,15 @@ MagickExport Image *CloneImages(const Image *images,const char *scenes,
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport void DeleteImageFromList(Image **images)
 {
-  register Image
-    *p;
+  Image
+    *image;
 
-  assert(images != (Image **) NULL);
-  if ((*images) == (Image *) NULL)
-    return;
-  assert((*images)->signature == MagickSignature);
-  if ((*images)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      (*images)->filename);
-  p=(*images);
-  if ((p->previous == (Image *) NULL) && (p->next == (Image *) NULL))
-    *images=(Image *) NULL;
-  else
-    {
-      if (p->previous != (Image *) NULL)
-        {
-          p->previous->next=p->next;
-          *images=p->previous;
-        }
-      if (p->next != (Image *) NULL)
-        {
-          p->next->previous=p->previous;
-          *images=p->next;
-        }
-    }
-  p=DestroyImage(p);
+  image=RemoveImageFromList(images);
+  if (image != (Image *) NULL)
+    (void) DestroyImage(image);
 }
 
 /*
@@ -323,7 +307,16 @@ MagickExport void DeleteImageFromList(Image **images)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DeleteImages() deletes one or more images from an image sequence.
+%  DeleteImages() deletes one or more images from an image sequence, using a
+%  comma separated list of image numbers or ranges.
+%
+%  The numbers start at 0 for the first image, while negative numbers refer to
+%  images starting counting from the end of the range. Images may be refered to
+%  multiple times without problems. Image refered beyond the available number
+%  of images in list are ignored.
+%
+%  If the referenced images are in the reverse order, that range will be
+%  completely ignored.  Unlike CloneImages().
 %
 %  The format of the DeleteImages method is:
 %
@@ -334,7 +327,7 @@ MagickExport void DeleteImageFromList(Image **images)
 %    o images: The image sequence.
 %
 %    o scenes: This character string specifies which scenes to delete
-%      (e.g. 1,3-5,7-6,2).
+%      (e.g. 1,3-5,-2-6,2).
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -343,20 +336,18 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
   ExceptionInfo *exception)
 {
   char
-    *q;
+    *p;
 
   Image
-    **delete_images,
     *image;
 
   long
     first,
-    j,
     last,
-    quantum;
+    length;
 
-  register const char
-    *p;
+  MagickBooleanType
+    *delete_list;
 
   register long
     i;
@@ -369,57 +360,58 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
       (*images)->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  delete_images=ImageListToArray(*images,exception);
-  if (delete_images == (Image **) NULL)
-    return;
-  j=0;
-  p=scenes;
-  for (q=(char *) scenes; *q != '\0'; p++)
-  {
-    while ((isspace((int) ((unsigned char) *p)) != 0) || (*p == ','))
-      p++;
-    first=strtol(p,&q,10);
-    if (first < 0)
-      first+=GetImageListLength(*images);
-    last=first;
-    while (isspace((int) ((unsigned char) *q)) != 0)
-      q++;
-    if (*q == '-')
-      {
-        last=strtol(q+1,&q,10);
-        if (last < 0)
-          last+=GetImageListLength(*images);
-      }
-    quantum=first > last ? -1 : 1;
-    for (p=q; first != (last+quantum); first+=quantum)
+  *images=GetFirstImageInList(*images);
+  length=GetImageListLength(*images);
+  delete_list=(MagickBooleanType *) AcquireMagickMemory(length*
+    sizeof(*delete_list));
+  if (delete_list == (MagickBooleanType *) NULL)
     {
-      i=0;
-      image=(*images);
-      for ( ; image != (Image *) NULL; image=GetNextImageInList(image))
-      {
-        if (i == (long) first)
-          {
-            delete_images[j]=image;
-            j++;
-          }
-        i++;
-      }
+      (void) ThrowMagickException(exception,GetMagickModule(),
+        ResourceLimitError,"MemoryAllocationFailed","`%s'",(*images)->filename);
+      return;
     }
+  image=(*images);
+  for (i=0; i < length; i++)
+    delete_list[i]=MagickFalse;
+  /*
+    Note which images will be deleted, avoid duplicate deleted
+  */
+  for (p=(char *) scenes; *p != '\0';)
+  {
+    while ((isspace((int)*p) != 0) || (*p == ','))
+      p++;
+    first=strtol(p,&p,10);
+    if (first < 0)
+      first+=length;
+    last=first;
+    while (isspace((int) ((unsigned char) *p)) != 0)
+      p++;
+    if (*p == '-')
+      {
+        last=strtol(p+1,&p,10);
+        if (last < 0)
+          last+=length;
+      }
+    if (first > last)
+      continue;
+    for (i=first; i <= last; i++)
+      if ((i >= 0) && (i < length))
+        delete_list[i]=MagickTrue;
   }
   /*
-    Delete images from image list.
+    Delete images marked for deletion, once only
   */
-  for (i=0; i < j; i++)
+  image=(*images);
+  for (i=0; i < length; i++)
   {
-    for ( ; *images != (Image *) NULL; *images=GetNextImageInList(*images))
-      if (*images == delete_images[i])
-        {
-          DeleteImageFromList(images);
-          break;
-        }
-    *images=GetFirstImageInList(*images);
+    *images=image;
+    image=GetNextImageInList(image);
+    if (delete_list[i] != MagickFalse)
+      DeleteImageFromList(images);
+
   }
-  delete_images=(Image **) RelinquishMagickMemory(delete_images);
+  (void) RelinquishMagickMemory(delete_list);
+  *images=GetFirstImageInList(*images);
 }
 
 /*
@@ -443,27 +435,16 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
 %
 %    o image: The image sequence.
 %
-%
 */
 MagickExport Image *DestroyImageList(Image *images)
 {
-  register Image
-    *p;
-
   if (images == (Image *) NULL)
     return((Image *) NULL);
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
-  for (p=images; p->previous != (Image *) NULL; p=p->previous);
-  for (images=p; p != (Image *) NULL; images=p)
-  {
-    p=p->next;
-    if (p != (Image *) NULL)
-      p->previous=(Image *) NULL;
-    images->next=(Image *) NULL;
-    images=DestroyImage(images);
-  }
+  while (images != (Image *) NULL)
+    DeleteImageFromList(&images);
   return((Image *) NULL);
 }
 
@@ -524,7 +505,6 @@ MagickExport Image *GetFirstImageInList(const Image *images)
 %
 %    o index: The position within the list.
 %
-%
 */
 MagickExport Image *GetImageFromList(const Image *images,const long index)
 {
@@ -569,7 +549,6 @@ MagickExport Image *GetImageFromList(const Image *images,const long index)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport long GetImageIndexInList(const Image *images)
 {
@@ -606,7 +585,6 @@ MagickExport long GetImageIndexInList(const Image *images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport unsigned long GetImageListLength(const Image *images)
 {
@@ -680,7 +658,6 @@ MagickExport Image *GetLastImageInList(const Image *images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *GetNextImageInList(const Image *images)
 {
@@ -713,7 +690,6 @@ MagickExport Image *GetNextImageInList(const Image *images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *GetPreviousImageInList(const Image *images)
 {
@@ -737,8 +713,10 @@ MagickExport Image *GetPreviousImageInList(const Image *images)
 %  a sequential array.  For example,
 %
 %    group = ImageListToArray(images, exception);
-%    for (i = 0; i < n; i++)
-%      puts(group[i]->filename);
+%    while (i = 0; group[i] != (Image *) NULL; i++)
+%      printf("%s\n", group[i]->filename);
+%    printf("%d images\n", i);
+%    group = RelinquishMagickMemory(group);
 %
 %  The format of the ImageListToArray method is:
 %
@@ -750,7 +728,6 @@ MagickExport Image *GetPreviousImageInList(const Image *images)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image **ImageListToArray(const Image *images,
   ExceptionInfo *exception)
@@ -793,7 +770,9 @@ MagickExport Image **ImageListToArray(const Image *images,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  InsertImageInList() inserts an image in the list.
+%  InsertImageInList() inserts the second image or image list into the first
+%  image list immediatally after the image pointed to.  The given image list
+%  pointer is unchanged unless previously empty.
 %
 %  The format of the InsertImageInList method is:
 %
@@ -801,10 +780,9 @@ MagickExport Image **ImageListToArray(const Image *images,
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list.
-%
-%    o image: The image.
+%    o images: The image list to insert into.
 %
+%    o image: The image list to insert.
 %
 */
 MagickExport void InsertImageInList(Image **images,Image *image)
@@ -821,8 +799,6 @@ MagickExport void InsertImageInList(Image **images,Image *image)
     return;
   assert((*images)->signature == MagickSignature);
   split=SplitImageList(*images);
-  if (split == (Image *) NULL)
-    return;
   AppendImageToList(images,image);
   AppendImageToList(images,split);
 }
@@ -873,7 +849,6 @@ MagickExport Image *NewImageList(void)
 %
 %    o image: The image.
 %
-%
 */
 MagickExport void PrependImageToList(Image **images,Image *image)
 {
@@ -891,7 +866,11 @@ MagickExport void PrependImageToList(Image **images,Image *image)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveImageFromList() removes an image from the list.
+%  RemoveImageFromList() removes and returns the image pointed to.
+%
+%  The given image list pointer is set to point to the next image in list
+%  if it exists, otherwise it is set to the previous image, or NULL if list
+%  was emptied.
 %
 %  The format of the RemoveImageFromList method is:
 %
@@ -901,7 +880,6 @@ MagickExport void PrependImageToList(Image **images,Image *image)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *RemoveImageFromList(Image **images)
 {
@@ -930,6 +908,8 @@ MagickExport Image *RemoveImageFromList(Image **images)
           p->next->previous=p->previous;
           *images=p->next;
         }
+      p->previous=(Image *) NULL;
+      p->next=(Image *) NULL;
     }
   return(p);
 }
@@ -945,7 +925,11 @@ MagickExport Image *RemoveImageFromList(Image **images)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveFirstImageFromList() removes the first image in the list.
+%  RemoveFirstImageFromList() removes and returns the first image in the list.
+%
+%  If the given image list pointer pointed to the removed first image, it is
+%  set to the new first image of list, or NULL if list was emptied, otherwise
+%  it is left as is.
 %
 %  The format of the RemoveFirstImageFromList method is:
 %
@@ -955,7 +939,6 @@ MagickExport Image *RemoveImageFromList(Image **images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *RemoveFirstImageFromList(Image **images)
 {
@@ -993,7 +976,11 @@ MagickExport Image *RemoveFirstImageFromList(Image **images)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RemoveLastImageFromList() removes the last image from the list.
+%  RemoveLastImageFromList() removes and returns the last image from the list.
+%
+%  If the given image list pointer pointed to the removed last image, it is
+%  set to the new last image of list, or NULL if list was emptied, otherwise
+%  it is left as is.
 %
 %  The format of the RemoveLastImageFromList method is:
 %
@@ -1003,7 +990,6 @@ MagickExport Image *RemoveFirstImageFromList(Image **images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *RemoveLastImageFromList(Image **images)
 {
@@ -1041,7 +1027,8 @@ MagickExport Image *RemoveLastImageFromList(Image **images)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ReplaceImageInList() replaces an image in the list.
+%  ReplaceImageInList() replaces an image in the list. Old image is destroyed.
+%  The given image list pointer is set to point to the just inserted image.
 %
 %  The format of the ReplaceImageInList method is:
 %
@@ -1053,7 +1040,6 @@ MagickExport Image *RemoveLastImageFromList(Image **images)
 %
 %    o image: The image.
 %
-%
 */
 MagickExport void ReplaceImageInList(Image **images,Image *image)
 {
@@ -1071,7 +1057,7 @@ MagickExport void ReplaceImageInList(Image **images,Image *image)
   image->previous=(*images)->previous;
   if (image->previous != (Image *) NULL)
     image->previous->next=image;
-  *images=DestroyImage(*images);
+  (void) DestroyImage(*images);
   (*images)=image;
 }
 
@@ -1086,17 +1072,17 @@ MagickExport void ReplaceImageInList(Image **images,Image *image)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ReverseImageList() reverses the image list.
+%  ReverseImageList() reverses the order of an image list.
+%  The list pointer is reset to that start of the re-ordered list.
 %
 %  The format of the ReverseImageList method is:
 %
-%       ReverseImageList(const Image **images)
+%      void ReverseImageList(Image **images)
 %
 %  A description of each parameter follows:
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport void ReverseImageList(Image **images)
 {
@@ -1135,7 +1121,7 @@ MagickExport void ReverseImageList(Image **images)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  SpliceImageIntoList() removes 'length' images from the list and replaces
-%  them with the specified splice.
+%  them with the specified splice. Removed images are returned.
 %
 %  The format of the SpliceImageIntoList method is:
 %
@@ -1150,33 +1136,33 @@ MagickExport void ReverseImageList(Image **images)
 %
 %    o splice: Replace the removed image list with this list.
 %
-%
 */
-MagickExport void SpliceImageIntoList(Image **images,const unsigned long length,
-  const Image *splice)
+MagickExport Image *SpliceImageIntoList(Image **images,
+  const unsigned long length,const Image *splice)
 {
   Image
+    *image,
     *split;
 
-  register long
+  register unsigned long
     i;
 
   assert(images != (Image **) NULL);
   assert(splice != (Image *) NULL);
   assert(splice->signature == MagickSignature);
   if ((*images) == (Image *) NULL)
-    return;
+    return((Image *) NULL);
   assert((*images)->signature == MagickSignature);
   if ((*images)->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       (*images)->filename);
   split=SplitImageList(*images);
-  if (split == (Image *) NULL)
-    return;
   AppendImageToList(images,splice);
-  for (i=0; (i < (long) length) && (split != (Image *) NULL); i++)
-    (void) RemoveImageFromList(&split);
+  image=(Image *) NULL;
+  for (i=0; (i < length) && (split != (Image *) NULL); i++)
+    AppendImageToList(&image,RemoveImageFromList(&split));
   AppendImageToList(images,split);
+  return(image);
 }
 
 /*
@@ -1190,7 +1176,8 @@ MagickExport void SpliceImageIntoList(Image **images,const unsigned long length,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  SplitImageList() splits an image into two lists.
+%  SplitImageList() splits an image into two lists, after given image
+%  The list that was split off is returned, which may be empty.
 %
 %  The format of the SplitImageList method is:
 %
@@ -1200,7 +1187,6 @@ MagickExport void SpliceImageIntoList(Image **images,const unsigned long length,
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *SplitImageList(Image *images)
 {
@@ -1223,7 +1209,7 @@ MagickExport Image *SplitImageList(Image *images)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  SyncImageList() synchronizes the scenes in an image list.
+%  SyncImageList() synchronizes the scene numbers in an image list.
 %
 %  The format of the SyncImageList method is:
 %
@@ -1233,7 +1219,6 @@ MagickExport Image *SplitImageList(Image *images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport void SyncImageList(Image *images)
 {
@@ -1280,7 +1265,6 @@ MagickExport void SyncImageList(Image *images)
 %
 %    o images: The image list.
 %
-%
 */
 MagickExport Image *SyncNextImageInList(const Image *images)
 {
