@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -44,28 +44,28 @@ typedef enum
 
 #if (QuantumDepth == 8)
 #define MagickEpsilon  1.0e-6
-#define MaxColormapSize  256
+#define MaxColormapSize  256UL
 #define MaxMap  255UL
 #define QuantumFormat  "%u"
-#define QuantumRange  (255UL)
+#define QuantumRange  255UL
 
 typedef float MagickRealType;
 typedef unsigned char Quantum;
 #elif (QuantumDepth == 16)
 #define MagickEpsilon  1.0e-10
-#define MaxColormapSize  65536
+#define MaxColormapSize  65536UL
 #define MaxMap  65535UL
 #define QuantumFormat  "%u"
-#define QuantumRange  (65535UL)
+#define QuantumRange  65535UL
 
 typedef double MagickRealType;
 typedef unsigned short Quantum;
 #elif (QuantumDepth == 32)
 #define MagickEpsilon  1.0e-10
-#define MaxColormapSize  65536
+#define MaxColormapSize  65536UL
 #define MaxMap  65535UL
-#define QuantumFormat  "%u"
-#define QuantumRange  (4294967295UL)
+#define QuantumFormat  "%g"
+#define QuantumRange  4294967295UL
 
 #if defined(HAVE_LONG_DOUBLE)
 typedef long double MagickRealType;
@@ -75,10 +75,10 @@ typedef double MagickRealType;
 typedef unsigned int Quantum;
 #elif (QuantumDepth == 64) && defined(HAVE_LONG_DOUBLE)
 #define MagickEpsilon  1.0e-10
-#define MaxColormapSize  65536
+#define MaxColormapSize  65536UL
 #define MaxMap  65535UL
 #define QuantumFormat  "%llu"
-#define QuantumRange  (MagickULLConstant(18446744073709551615))
+#define QuantumRange  ((Quantum) MagickULLConstant(18446744073709551615))
 
 typedef long double MagickRealType;
 typedef unsigned long long Quantum;
@@ -173,6 +173,7 @@ typedef enum
   AtopCompositeOp,
   BlendCompositeOp,
   BumpmapCompositeOp,
+  ChangeMaskCompositeOp,
   ClearCompositeOp,
   ColorBurnCompositeOp,
   ColorDodgeCompositeOp,
@@ -599,7 +600,8 @@ typedef enum
   MirrorVirtualPixelMethod,
   RandomVirtualPixelMethod,
   TileVirtualPixelMethod,
-  TransparentVirtualPixelMethod
+  TransparentVirtualPixelMethod,
+  MaskVirtualPixelMethod
 } VirtualPixelMethod;
 
 typedef struct _ChromaticityInfo
