@@ -18,7 +18,7 @@
 %                             November 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -595,7 +595,7 @@ MagickExport const MagickInfo **GetMagickInfoList(const char *pattern,
   for (i=0; p != (const MagickInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       formats[i++]=p;
     p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
   }
@@ -685,7 +685,7 @@ MagickExport char **GetMagickList(const char *pattern,
   for (i=0; p != (const MagickInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       formats[i++]=ConstantString(p->name);
     p=(const MagickInfo *) GetNextValueInSplayTree(magick_list);
   }
