@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -39,21 +39,29 @@ extern "C" {
 
 #define AcquireCacheNexus  PrependMagickMethod(AcquireCacheNexus)
 #define AcquireCacheView  PrependMagickMethod(AcquireCacheView)
+#define AcquireDrawInfo  PrependMagickMethod(AcquireDrawInfo)
 #define AcquireExceptionInfo  PrependMagickMethod(AcquireExceptionInfo)
+#define AcquireFxInfo  PrependMagickMethod(AcquireFxInfo)
+#define AcquireImageInfo  PrependMagickMethod(AcquireImageInfo)
 #define AcquireImagePixels  PrependMagickMethod(AcquireImagePixels)
 #define AcquireMagickMemory  PrependMagickMethod(AcquireMagickMemory)
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
+#define AcquireQuantizeInfo  PrependMagickMethod(AcquireQuantizeInfo)
 #define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
 #define AcquireSemaphoreInfo  PrependMagickMethod(AcquireSemaphoreInfo)
 #define AcquireStreamInfo  PrependMagickMethod(AcquireStreamInfo)
 #define AcquireStringInfo  PrependMagickMethod(AcquireStringInfo)
 #define AcquireString  PrependMagickMethod(AcquireString)
+#define AcquireTokenInfo  PrependMagickMethod(AcquireTokenInfo)
 #define AcquireUniqueFilename  PrependMagickMethod(AcquireUniqueFilename)
 #define AcquireUniqueFileResource  PrependMagickMethod(AcquireUniqueFileResource)
 #define AcquireUniqueSymbolicLink  PrependMagickMethod(AcquireUniqueSymbolicLink)
+#define AdaptiveBlurImageChannel  PrependMagickMethod(AdaptiveBlurImageChannel)
+#define AdaptiveBlurImage  PrependMagickMethod(AdaptiveBlurImage)
+#define AdaptiveResizeImage  PrependMagickMethod(AdaptiveResizeImage)
 #define AdaptiveSharpenImageChannel  PrependMagickMethod(AdaptiveSharpenImageChannel)
 #define AdaptiveSharpenImage  PrependMagickMethod(AdaptiveSharpenImage)
 #define AdaptiveThresholdImage  PrependMagickMethod(AdaptiveThresholdImage)
@@ -68,7 +76,6 @@ extern "C" {
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
 #define AllocateSemaphoreInfo  PrependMagickMethod(AllocateSemaphoreInfo)
 #define AllocateString  PrependMagickMethod(AllocateString)
-#define AnalyzeImage  PrependMagickMethod(AnalyzeImage)
 #define AnimateImages  PrependMagickMethod(AnimateImages)
 #define AnnotateImage  PrependMagickMethod(AnnotateImage)
 #define AppendImageFormat  PrependMagickMethod(AppendImageFormat)
@@ -112,6 +119,7 @@ extern "C" {
 #define CloneImageOptions  PrependMagickMethod(CloneImageOptions)
 #define CloneImage  PrependMagickMethod(CloneImage)
 #define CloneImageProfiles  PrependMagickMethod(CloneImageProfiles)
+#define CloneImageProperties  PrependMagickMethod(CloneImageProperties)
 #define CloneImages  PrependMagickMethod(CloneImages)
 #define CloneMemory  PrependMagickMethod(CloneMemory)
 #define CloneMontageInfo  PrependMagickMethod(CloneMontageInfo)
@@ -151,14 +159,16 @@ extern "C" {
 #define ConvolveImage  PrependMagickMethod(ConvolveImage)
 #define CopyMagickMemory  PrependMagickMethod(CopyMagickMemory)
 #define CopyMagickString  PrependMagickMethod(CopyMagickString)
+#define CreatesRGBImageProfile  PrependMagickMethod(CreatesRGBImageProfile)
 #define CropImage  PrependMagickMethod(CropImage)
 #define CycleColormapImage  PrependMagickMethod(CycleColormapImage)
 #define DeconstructImages  PrependMagickMethod(DeconstructImages)
 #define DefineImageOption  PrependMagickMethod(DefineImageOption)
+#define DefineImageProperty  PrependMagickMethod(DefineImageProperty)
 #define DeleteImageAttribute  PrependMagickMethod(DeleteImageAttribute)
 #define DeleteImageFromList  PrependMagickMethod(DeleteImageFromList)
-#define DeleteImageList  PrependMagickMethod(DeleteImageList)
 #define DeleteImageOption  PrependMagickMethod(DeleteImageOption)
+#define DeleteImageProperty  PrependMagickMethod(DeleteImageProperty)
 #define DeleteImages  PrependMagickMethod(DeleteImages)
 #define DeleteMagickRegistry  PrependMagickMethod(DeleteMagickRegistry)
 #define DescribeImage  PrependMagickMethod(DescribeImage)
@@ -175,6 +185,7 @@ extern "C" {
 #define DestroyDelegateList  PrependMagickMethod(DestroyDelegateList)
 #define DestroyDrawInfo  PrependMagickMethod(DestroyDrawInfo)
 #define DestroyExceptionInfo  PrependMagickMethod(DestroyExceptionInfo)
+#define DestroyFxInfo  PrependMagickMethod(DestroyFxInfo)
 #define DestroyHashmap  PrependMagickMethod(DestroyHashmap)
 #define DestroyImageAttributes  PrependMagickMethod(DestroyImageAttributes)
 #define DestroyImageInfo  PrependMagickMethod(DestroyImageInfo)
@@ -183,6 +194,7 @@ extern "C" {
 #define DestroyImagePixels  PrependMagickMethod(DestroyImagePixels)
 #define DestroyImage  PrependMagickMethod(DestroyImage)
 #define DestroyImageProfiles  PrependMagickMethod(DestroyImageProfiles)
+#define DestroyImageProperties  PrependMagickMethod(DestroyImageProperties)
 #define DestroyImages  PrependMagickMethod(DestroyImages)
 #define DestroyLinkedList  PrependMagickMethod(DestroyLinkedList)
 #define DestroyLocaleList  PrependMagickMethod(DestroyLocaleList)
@@ -194,6 +206,7 @@ extern "C" {
 #define DestroyMagickRegistry  PrependMagickMethod(DestroyMagickRegistry)
 #define DestroyMagickResources  PrependMagickMethod(DestroyMagickResources)
 #define DestroyMagicList  PrependMagickMethod(DestroyMagicList)
+#define DestroyMimeList  PrependMagickMethod(DestroyMimeList)
 #define DestroyMontageInfo  PrependMagickMethod(DestroyMontageInfo)
 #define DestroyQuantizeInfo  PrependMagickMethod(DestroyQuantizeInfo)
 #define DestroyQuantumInfo  PrependMagickMethod(DestroyQuantumInfo)
@@ -205,6 +218,8 @@ extern "C" {
 #define DestroyStringInfo  PrependMagickMethod(DestroyStringInfo)
 #define DestroyStringList  PrependMagickMethod(DestroyStringList)
 #define DestroyString  PrependMagickMethod(DestroyString)
+#define DestroyThresholdMap  PrependMagickMethod(DestroyThresholdMap)
+#define DestroyTokenInfo  PrependMagickMethod(DestroyTokenInfo)
 #define DestroyTypeList  PrependMagickMethod(DestroyTypeList)
 #define DestroyXMLTree  PrependMagickMethod(DestroyXMLTree)
 #define DestroyXResources  PrependMagickMethod(DestroyXResources)
@@ -216,6 +231,7 @@ extern "C" {
 #define DistillRandomEvent  PrependMagickMethod(DistillRandomEvent)
 #define DrawAffineImage  PrependMagickMethod(DrawAffineImage)
 #define DrawClipPath  PrependMagickMethod(DrawClipPath)
+#define DrawGradientImage  PrependMagickMethod(DrawGradientImage)
 #define DrawImage  PrependMagickMethod(DrawImage)
 #define DrawPatternPath  PrependMagickMethod(DrawPatternPath)
 #define DrawPrimitive  PrependMagickMethod(DrawPrimitive)
@@ -233,6 +249,7 @@ extern "C" {
 #define ExpandFilenames  PrependMagickMethod(ExpandFilenames)
 #define ExportImagePixels  PrependMagickMethod(ExportImagePixels)
 #define ExportQuantumPixels  PrependMagickMethod(ExportQuantumPixels)
+#define ExtentImage  PrependMagickMethod(ExtentImage)
 #define FileToBlob  PrependMagickMethod(FileToBlob)
 #define FileToStringInfo  PrependMagickMethod(FileToStringInfo)
 #define FileToString  PrependMagickMethod(FileToString)
@@ -242,6 +259,9 @@ extern "C" {
 #define FlopImage  PrependMagickMethod(FlopImage)
 #define FormatImageAttributeList  PrependMagickMethod(FormatImageAttributeList)
 #define FormatImageAttribute  PrependMagickMethod(FormatImageAttribute)
+#define FormatImagePropertyList  PrependMagickMethod(FormatImagePropertyList)
+#define FormatImageProperty  PrependMagickMethod(FormatImageProperty)
+#define FormatMagickCaption  PrependMagickMethod(FormatMagickCaption)
 #define FormatMagickSize  PrependMagickMethod(FormatMagickSize)
 #define FormatMagickStringList  PrependMagickMethod(FormatMagickStringList)
 #define FormatMagickString  PrependMagickMethod(FormatMagickString)
@@ -252,6 +272,8 @@ extern "C" {
 #define FuzzyColorCompare  PrependMagickMethod(FuzzyColorCompare)
 #define FuzzyColorMatch  PrependMagickMethod(FuzzyColorMatch)
 #define FuzzyOpacityCompare  PrependMagickMethod(FuzzyOpacityCompare)
+#define FxEvaluateChannelExpression  PrependMagickMethod(FxEvaluateChannelExpression)
+#define FxEvaluateExpression  PrependMagickMethod(FxEvaluateExpression)
 #define FxImageChannel  PrependMagickMethod(FxImageChannel)
 #define FxImage  PrependMagickMethod(FxImage)
 #define GammaImageChannel  PrependMagickMethod(GammaImageChannel)
@@ -265,10 +287,10 @@ extern "C" {
 #define GetBlobSize  PrependMagickMethod(GetBlobSize)
 #define GetBlobStreamData  PrependMagickMethod(GetBlobStreamData)
 #define GetBlobStreamHandler  PrependMagickMethod(GetBlobStreamHandler)
-#define GetCacheMethods  PrependMagickMethod(GetCacheMethods)
 #define GetCacheClass  PrependMagickMethod(GetCacheClass)
 #define GetCacheColorspace  PrependMagickMethod(GetCacheColorspace)
 #define GetCacheInfo  PrependMagickMethod(GetCacheInfo)
+#define GetCacheMethods  PrependMagickMethod(GetCacheMethods)
 #define GetCacheNexus  PrependMagickMethod(GetCacheNexus)
 #define GetCacheViewColorspace  PrependMagickMethod(GetCacheViewColorspace)
 #define GetCacheViewException  PrependMagickMethod(GetCacheViewException)
@@ -298,6 +320,7 @@ extern "C" {
 #define GetDelegateInfo  PrependMagickMethod(GetDelegateInfo)
 #define GetDelegateList  PrependMagickMethod(GetDelegateList)
 #define GetDelegateMode  PrependMagickMethod(GetDelegateMode)
+#define GetDelegateThreadSupport  PrependMagickMethod(GetDelegateThreadSupport)
 #define GetDrawInfo  PrependMagickMethod(GetDrawInfo)
 #define GetElapsedTime  PrependMagickMethod(GetElapsedTime)
 #define GetEnvironmentValue  PrependMagickMethod(GetEnvironmentValue)
@@ -325,17 +348,18 @@ extern "C" {
 #define GetImageGeometry  PrependMagickMethod(GetImageGeometry)
 #define GetImageHistogram  PrependMagickMethod(GetImageHistogram)
 #define GetImageIndexInList  PrependMagickMethod(GetImageIndexInList)
-#define GetImageInfoAttribute  PrependMagickMethod(GetImageInfoAttribute)
 #define GetImageInfo  PrependMagickMethod(GetImageInfo)
 #define GetImageListIndex  PrependMagickMethod(GetImageListIndex)
 #define GetImageListLength  PrependMagickMethod(GetImageListLength)
 #define GetImageList  PrependMagickMethod(GetImageList)
 #define GetImageListSize  PrependMagickMethod(GetImageListSize)
 #define GetImageMagick  PrependMagickMethod(GetImageMagick)
+#define GetImageMask  PrependMagickMethod(GetImageMask)
 #define GetImageMean  PrependMagickMethod(GetImageMean)
 #define GetImageOption  PrependMagickMethod(GetImageOption)
 #define GetImagePixels  PrependMagickMethod(GetImagePixels)
 #define GetImageProfile  PrependMagickMethod(GetImageProfile)
+#define GetImageProperty  PrependMagickMethod(GetImageProperty)
 #define GetImageQuantizeError  PrependMagickMethod(GetImageQuantizeError)
 #define GetImageQuantumDepth  PrependMagickMethod(GetImageQuantumDepth)
 #define GetImageTotalInkDensity  PrependMagickMethod(GetImageTotalInkDensity)
@@ -349,9 +373,7 @@ extern "C" {
 #define GetLocaleInfo_  PrependMagickMethod(GetLocaleInfo_)
 #define GetLocaleList  PrependMagickMethod(GetLocaleList)
 #define GetLocaleMessage  PrependMagickMethod(GetLocaleMessage)
-#define GetLocaleMonitorMessage  PrependMagickMethod(GetLocaleMonitorMessage)
 #define GetLocaleOptions  PrependMagickMethod(GetLocaleOptions)
-#define GetLocaleValue  PrependMagickMethod(GetLocaleValue)
 #define GetLogInfoList  PrependMagickMethod(GetLogInfoList)
 #define GetLogInfo  PrependMagickMethod(GetLogInfo)
 #define GetLogList  PrependMagickMethod(GetLogList)
@@ -385,6 +407,11 @@ extern "C" {
 #define GetMagickVersion  PrependMagickMethod(GetMagickVersion)
 #define GetMagicList  PrependMagickMethod(GetMagicList)
 #define GetMagicName  PrependMagickMethod(GetMagicName)
+#define GetMimeDescription  PrependMagickMethod(GetMimeDescription)
+#define GetMimeInfoList  PrependMagickMethod(GetMimeInfoList)
+#define GetMimeInfo  PrependMagickMethod(GetMimeInfo)
+#define GetMimeList  PrependMagickMethod(GetMimeList)
+#define GetMimeType  PrependMagickMethod(GetMimeType)
 #define GetMonitorHandler  PrependMagickMethod(GetMonitorHandler)
 #define GetMontageInfo  PrependMagickMethod(GetMontageInfo)
 #define GetMultilineTypeMetrics  PrependMagickMethod(GetMultilineTypeMetrics)
@@ -393,6 +420,7 @@ extern "C" {
 #define GetNextImageOption  PrependMagickMethod(GetNextImageOption)
 #define GetNextImage  PrependMagickMethod(GetNextImage)
 #define GetNextImageProfile  PrependMagickMethod(GetNextImageProfile)
+#define GetNextImageProperty  PrependMagickMethod(GetNextImageProperty)
 #define GetNextKeyInHashmap  PrependMagickMethod(GetNextKeyInHashmap)
 #define GetNextKeyInSplayTree  PrependMagickMethod(GetNextKeyInSplayTree)
 #define GetNextValueInHashmap  PrependMagickMethod(GetNextValueInHashmap)
@@ -424,6 +452,7 @@ extern "C" {
 #define GetRandomKey  PrependMagickMethod(GetRandomKey)
 #define GetRandomValue  PrependMagickMethod(GetRandomValue)
 #define GetSignatureInfo  PrependMagickMethod(GetSignatureInfo)
+#define GetThresholdMap  PrependMagickMethod(GetThresholdMap)
 #define GetTimerInfo  PrependMagickMethod(GetTimerInfo)
 #define GetTypeInfoByFamily  PrependMagickMethod(GetTypeInfoByFamily)
 #define GetTypeInfoList  PrependMagickMethod(GetTypeInfoList)
@@ -467,12 +496,15 @@ extern "C" {
 #define InitializeMagick  PrependMagickMethod(InitializeMagick)
 #define InitializeMagickResources  PrependMagickMethod(InitializeMagickResources)
 #define InitializeSemaphore  PrependMagickMethod(InitializeSemaphore)
+#define InjectImageBlob  PrependMagickMethod(InjectImageBlob)
 #define InsertImageInList  PrependMagickMethod(InsertImageInList)
 #define InsertTagIntoXMLTree  PrependMagickMethod(InsertTagIntoXMLTree)
 #define InsertValueInLinkedList  PrependMagickMethod(InsertValueInLinkedList)
 #define InsertValueInSortedLinkedList  PrependMagickMethod(InsertValueInSortedLinkedList)
+#define InterpolatePixelColor  PrependMagickMethod(InterpolatePixelColor)
 #define InterpretImageAttributes  PrependMagickMethod(InterpretImageAttributes)
 #define InterpretImageFilename  PrependMagickMethod(InterpretImageFilename)
+#define InterpretImageProperties  PrependMagickMethod(InterpretImageProperties)
 #define InvokeDelegate  PrependMagickMethod(InvokeDelegate)
 #define IsAccessible  PrependMagickMethod(IsAccessible)
 #define IsBlobExempt  PrependMagickMethod(IsBlobExempt)
@@ -485,6 +517,7 @@ extern "C" {
 #define IsGrayImage  PrependMagickMethod(IsGrayImage)
 #define IsHashmapEmpty  PrependMagickMethod(IsHashmapEmpty)
 #define IsImagesEqual  PrependMagickMethod(IsImagesEqual)
+#define IsImageSimilar  PrependMagickMethod(IsImageSimilar)
 #define IsLinkedListEmpty  PrependMagickMethod(IsLinkedListEmpty)
 #define IsMagickColorSimilar  PrependMagickMethod(IsMagickColorSimilar)
 #define IsMagickConflict  PrependMagickMethod(IsMagickConflict)
@@ -498,12 +531,11 @@ extern "C" {
 #define IsSceneGeometry  PrependMagickMethod(IsSceneGeometry)
 #define IsSubimage  PrependMagickMethod(IsSubimage)
 #define IsTaintImage  PrependMagickMethod(IsTaintImage)
-#define JP2EncodeImage  PrependMagickMethod(JP2EncodeImage)
-#define JPEGEncodeImage  PrependMagickMethod(JPEGEncodeImage)
 #define LevelImageChannel  PrependMagickMethod(LevelImageChannel)
 #define LevelImage  PrependMagickMethod(LevelImage)
 #define LiberateMemory  PrependMagickMethod(LiberateMemory)
 #define LiberateSemaphoreInfo  PrependMagickMethod(LiberateSemaphoreInfo)
+#define LinearStretchImage  PrependMagickMethod(LinearStretchImage)
 #define LinkedListToArray  PrependMagickMethod(LinkedListToArray)
 #define ListCoderInfo  PrependMagickMethod(ListCoderInfo)
 #define ListColorInfo  PrependMagickMethod(ListColorInfo)
@@ -514,11 +546,13 @@ extern "C" {
 #define ListLogInfo  PrependMagickMethod(ListLogInfo)
 #define ListMagicInfo  PrependMagickMethod(ListMagicInfo)
 #define ListMagickInfo  PrependMagickMethod(ListMagickInfo)
+#define ListMagickOptionInfo  PrependMagickMethod(ListMagickOptionInfo)
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
+#define ListMimeInfo  PrependMagickMethod(ListMimeInfo)
 #define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
+#define ListThresholdMaps  PrependMagickMethod(ListThresholdMaps)
 #define ListTypeInfo  PrependMagickMethod(ListTypeInfo)
-#define LoadFontConfigFonts  PrependMagickMethod(LoadFontConfigFonts)
-#define LoadWPG2Flags  PrependMagickMethod(LoadWPG2Flags)
+#define LoadMimeLists  PrependMagickMethod(LoadMimeLists)
 #define LocaleCompare  PrependMagickMethod(LocaleCompare)
 #define LocaleLower  PrependMagickMethod(LocaleLower)
 #define LocaleNCompare  PrependMagickMethod(LocaleNCompare)
@@ -529,8 +563,8 @@ extern "C" {
 #define LZWEncodeImage  PrependMagickMethod(LZWEncodeImage)
 #define MagickError  PrependMagickMethod(MagickError)
 #define MagickFatalError  PrependMagickMethod(MagickFatalError)
-#define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
+#define MagickOpenStream  PrependMagickMethod(MagickOpenStream)
 #define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
 #define MagickToMime  PrependMagickMethod(MagickToMime)
 #define MagickWarning  PrependMagickMethod(MagickWarning)
@@ -572,14 +606,17 @@ extern "C" {
 #define OpenStream  PrependMagickMethod(OpenStream)
 #define OptimizeImageLayers  PrependMagickMethod(OptimizeImageLayers)
 #define OptimizePlusImageLayers  PrependMagickMethod(OptimizePlusImageLayers)
+#define OrderedDitherImageChannel  PrependMagickMethod(OrderedDitherImageChannel)
 #define OrderedDitherImage  PrependMagickMethod(OrderedDitherImage)
+#define OrderedPosterizeImageChannel  PrependMagickMethod(OrderedPosterizeImageChannel)
+#define OrderedPosterizeImage  PrependMagickMethod(OrderedPosterizeImage)
 #define PackbitsEncodeImage  PrependMagickMethod(PackbitsEncodeImage)
 #define PaintOpaqueImageChannel  PrependMagickMethod(PaintOpaqueImageChannel)
 #define PaintOpaqueImage  PrependMagickMethod(PaintOpaqueImage)
 #define PaintTransparentImage  PrependMagickMethod(PaintTransparentImage)
 #define ParseAbsoluteGeometry  PrependMagickMethod(ParseAbsoluteGeometry)
+#define ParseAffineGeometry  PrependMagickMethod(ParseAffineGeometry)
 #define ParseChannelOption  PrependMagickMethod(ParseChannelOption)
-#define ParseCharacterContent  PrependMagickMethod(ParseCharacterContent)
 #define ParseGeometry  PrependMagickMethod(ParseGeometry)
 #define ParseGravityGeometry  PrependMagickMethod(ParseGravityGeometry)
 #define ParseImageGeometry  PrependMagickMethod(ParseImageGeometry)
@@ -591,6 +628,7 @@ extern "C" {
 #define PingBlob  PrependMagickMethod(PingBlob)
 #define PingImage  PrependMagickMethod(PingImage)
 #define PlasmaImage  PrependMagickMethod(PlasmaImage)
+#define PolaroidImage  PrependMagickMethod(PolaroidImage)
 #define PopImageList  PrependMagickMethod(PopImageList)
 #define PopImagePixels  PrependMagickMethod(PopImagePixels)
 #define PosterizeImage  PrependMagickMethod(PosterizeImage)
@@ -599,7 +637,6 @@ extern "C" {
 #define PreviewImage  PrependMagickMethod(PreviewImage)
 #define PrintStringInfo  PrependMagickMethod(PrintStringInfo)
 #define ProfileImage  PrependMagickMethod(ProfileImage)
-#define PruneTagFromXMLTree  PrependMagickMethod(PruneTagFromXMLTree)
 #define PushImageList  PrependMagickMethod(PushImageList)
 #define PushImagePixels  PrependMagickMethod(PushImagePixels)
 #define PutEntryInHashmap  PrependMagickMethod(PutEntryInHashmap)
@@ -608,6 +645,7 @@ extern "C" {
 #define QuantizeImages  PrependMagickMethod(QuantizeImages)
 #define QueryColorDatabase  PrependMagickMethod(QueryColorDatabase)
 #define QueryColorname  PrependMagickMethod(QueryColorname)
+#define QueryMagickColorname  PrependMagickMethod(QueryMagickColorname)
 #define QueryMagickColor  PrependMagickMethod(QueryMagickColor)
 #define RadialBlurImageChannel  PrependMagickMethod(RadialBlurImageChannel)
 #define RadialBlurImage  PrependMagickMethod(RadialBlurImage)
@@ -629,6 +667,7 @@ extern "C" {
 #define ReadImage  PrependMagickMethod(ReadImage)
 #define ReadInlineImage  PrependMagickMethod(ReadInlineImage)
 #define ReadStream  PrependMagickMethod(ReadStream)
+#define RecolorImage  PrependMagickMethod(RecolorImage)
 #define ReduceNoiseImage  PrependMagickMethod(ReduceNoiseImage)
 #define ReferenceBlob  PrependMagickMethod(ReferenceBlob)
 #define ReferenceCache  PrependMagickMethod(ReferenceCache)
@@ -645,7 +684,6 @@ extern "C" {
 #define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
 #define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
 #define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
-#define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
 #define RegisterEPTImage  PrependMagickMethod(RegisterEPTImage)
@@ -707,6 +745,7 @@ extern "C" {
 #define RegisterSUNImage  PrependMagickMethod(RegisterSUNImage)
 #define RegisterSVGImage  PrependMagickMethod(RegisterSVGImage)
 #define RegisterTGAImage  PrependMagickMethod(RegisterTGAImage)
+#define RegisterTHUMBNAILImage  PrependMagickMethod(RegisterTHUMBNAILImage)
 #define RegisterTIFFImage  PrependMagickMethod(RegisterTIFFImage)
 #define RegisterTILEImage  PrependMagickMethod(RegisterTILEImage)
 #define RegisterTIMImage  PrependMagickMethod(RegisterTIMImage)
@@ -741,6 +780,7 @@ extern "C" {
 #define RemoveImageFromList  PrependMagickMethod(RemoveImageFromList)
 #define RemoveImageOption  PrependMagickMethod(RemoveImageOption)
 #define RemoveImageProfile  PrependMagickMethod(RemoveImageProfile)
+#define RemoveImageProperty  PrependMagickMethod(RemoveImageProperty)
 #define RemoveLastElementFromLinkedList  PrependMagickMethod(RemoveLastElementFromLinkedList)
 #define RemoveLastImageFromList  PrependMagickMethod(RemoveLastImageFromList)
 #define RemoveNodeByValueFromSplayTree  PrependMagickMethod(RemoveNodeByValueFromSplayTree)
@@ -750,6 +790,7 @@ extern "C" {
 #define ResetImageAttributeIterator  PrependMagickMethod(ResetImageAttributeIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
 #define ResetImageProfileIterator  PrependMagickMethod(ResetImageProfileIterator)
+#define ResetImagePropertyIterator  PrependMagickMethod(ResetImagePropertyIterator)
 #define ResetLinkedListIterator  PrependMagickMethod(ResetLinkedListIterator)
 #define ResetMagickMemory  PrependMagickMethod(ResetMagickMemory)
 #define ResetSplayTreeIterator  PrependMagickMethod(ResetSplayTreeIterator)
@@ -766,6 +807,7 @@ extern "C" {
 #define SeekBlob  PrependMagickMethod(SeekBlob)
 #define SegmentImage  PrependMagickMethod(SegmentImage)
 #define SeparateImageChannel  PrependMagickMethod(SeparateImageChannel)
+#define SeparateImages  PrependMagickMethod(SeparateImages)
 #define SepiaToneImage  PrependMagickMethod(SepiaToneImage)
 #define SetBlobExempt  PrependMagickMethod(SetBlobExempt)
 #define SetCacheMethods  PrependMagickMethod(SetCacheMethods)
@@ -792,12 +834,14 @@ extern "C" {
 #define SetImageInfo  PrependMagickMethod(SetImageInfo)
 #define SetImageInfoProgressMonitor  PrependMagickMethod(SetImageInfoProgressMonitor)
 #define SetImageList  PrependMagickMethod(SetImageList)
+#define SetImageMask  PrependMagickMethod(SetImageMask)
 #define SetImageOpacity  PrependMagickMethod(SetImageOpacity)
 #define SetImageOption  PrependMagickMethod(SetImageOption)
 #define SetImagePixels  PrependMagickMethod(SetImagePixels)
 #define SetImage  PrependMagickMethod(SetImage)
 #define SetImageProfile  PrependMagickMethod(SetImageProfile)
 #define SetImageProgressMonitor  PrependMagickMethod(SetImageProgressMonitor)
+#define SetImageProperty  PrependMagickMethod(SetImageProperty)
 #define SetImageStorageClass  PrependMagickMethod(SetImageStorageClass)
 #define SetImageType  PrependMagickMethod(SetImageType)
 #define SetImageVirtualPixelMethod  PrependMagickMethod(SetImageVirtualPixelMethod)
@@ -827,6 +871,7 @@ extern "C" {
 #define SigmoidalContrastImage  PrependMagickMethod(SigmoidalContrastImage)
 #define SignatureImage  PrependMagickMethod(SignatureImage)
 #define SizeBlob  PrependMagickMethod(SizeBlob)
+#define SketchImage  PrependMagickMethod(SketchImage)
 #define SolarizeImage  PrependMagickMethod(SolarizeImage)
 #define SortColormapByIntensity  PrependMagickMethod(SortColormapByIntensity)
 #define SpliceImageIntoList  PrependMagickMethod(SpliceImageIntoList)
@@ -842,6 +887,7 @@ extern "C" {
 #define StringInfoToString  PrependMagickMethod(StringInfoToString)
 #define StringToArgv  PrependMagickMethod(StringToArgv)
 #define StringToDouble  PrependMagickMethod(StringToDouble)
+#define StringToken  PrependMagickMethod(StringToken)
 #define StringToList  PrependMagickMethod(StringToList)
 #define StringToStringInfo  PrependMagickMethod(StringToStringInfo)
 #define StripImage  PrependMagickMethod(StripImage)
@@ -856,6 +902,7 @@ extern "C" {
 #define SyncImageOptions  PrependMagickMethod(SyncImageOptions)
 #define SyncImagePixels  PrependMagickMethod(SyncImagePixels)
 #define SyncImage  PrependMagickMethod(SyncImage)
+#define SyncImageProfiles  PrependMagickMethod(SyncImageProfiles)
 #define SyncNextImageInList  PrependMagickMethod(SyncNextImageInList)
 #define SystemCommand  PrependMagickMethod(SystemCommand)
 #define TellBlob  PrependMagickMethod(TellBlob)
@@ -881,6 +928,7 @@ extern "C" {
 #define TransposeImage  PrependMagickMethod(TransposeImage)
 #define TransverseImage  PrependMagickMethod(TransverseImage)
 #define TrimImage  PrependMagickMethod(TrimImage)
+#define UniqueImageColors  PrependMagickMethod(UniqueImageColors)
 #define UnlockSemaphoreInfo  PrependMagickMethod(UnlockSemaphoreInfo)
 #define UnmapBlob  PrependMagickMethod(UnmapBlob)
 #define UnregisterARTImage  PrependMagickMethod(UnregisterARTImage)
@@ -895,7 +943,6 @@ extern "C" {
 #define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
 #define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
 #define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
-#define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
 #define UnregisterEPTImage  PrependMagickMethod(UnregisterEPTImage)
@@ -957,6 +1004,7 @@ extern "C" {
 #define UnregisterSUNImage  PrependMagickMethod(UnregisterSUNImage)
 #define UnregisterSVGImage  PrependMagickMethod(UnregisterSVGImage)
 #define UnregisterTGAImage  PrependMagickMethod(UnregisterTGAImage)
+#define UnregisterTHUMBNAILImage  PrependMagickMethod(UnregisterTHUMBNAILImage)
 #define UnregisterTIFFImage  PrependMagickMethod(UnregisterTIFFImage)
 #define UnregisterTILEImage  PrependMagickMethod(UnregisterTILEImage)
 #define UnregisterTIMImage  PrependMagickMethod(UnregisterTIMImage)
