@@ -263,7 +263,7 @@ MagickExport const MimeInfo *GetMimeInfo(const char *filename,
         }
     if ((p->pattern != (char *) NULL) && (filename != (char *) NULL))
       {
-        if (GlobExpression(filename,p->pattern) != MagickFalse)
+        if (GlobExpression(filename,p->pattern,MagickFalse) != MagickFalse)
           mime_info=p;
         p=(const MimeInfo *) GetNextValueInLinkedList(mime_list);
         continue;
@@ -460,7 +460,7 @@ MagickExport const MimeInfo **GetMimeInfoList(const char *pattern,
   for (i=0; p != (const MimeInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->type,pattern) != MagickFalse))
+        (GlobExpression(p->type,pattern,MagickFalse) != MagickFalse))
       aliases[i++]=p;
     p=(const MimeInfo *) GetNextValueInLinkedList(mime_list);
   }
@@ -552,7 +552,7 @@ MagickExport char **GetMimeList(const char *pattern,
   for (i=0; p != (const MimeInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->type,pattern) != MagickFalse))
+        (GlobExpression(p->type,pattern,MagickFalse) != MagickFalse))
       aliases[i++]=ConstantString(p->type);
     p=(const MimeInfo *) GetNextValueInLinkedList(mime_list);
   }
@@ -837,8 +837,11 @@ static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
                 MaxTextExtent);
             (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
             xml=FileToString(path,~0,exception);
-            status=LoadMimeList(xml,path,depth+1,exception);
-            xml=DestroyString(xml);
+            if (xml != (char *) NULL)
+              {
+                status=LoadMimeList(xml,path,depth+1,exception);
+                xml=DestroyString(xml);
+              }
           }
       }
     include=GetNextXMLTreeTag(include);
@@ -1060,6 +1063,7 @@ MagickExport char *MagickToMime(const char *magick)
     *exception;
 
   (void) FormatMagickString(filename,MaxTextExtent,"file.%s",magick);
+  LocaleLower(filename);
   exception=AcquireExceptionInfo();
   mime_info=GetMimeInfo(filename,(unsigned char *) " ",1,exception);
   exception=DestroyExceptionInfo(exception);
