@@ -17,7 +17,7 @@
 %                                March 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -389,7 +389,7 @@ MagickExport const ModuleInfo **GetModuleInfoList(const char *pattern,
   for (i=0; p != (const ModuleInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->tag,pattern) != MagickFalse))
+        (GlobExpression(p->tag,pattern,MagickFalse) != MagickFalse))
       modules[i++]=p;
     p=(const ModuleInfo *) GetNextValueInSplayTree(module_list);
   }
@@ -495,12 +495,12 @@ MagickExport char **GetModuleList(const char *pattern,
   entry=readdir(directory);
   while (entry != (struct dirent *) NULL)
   {
-    if (GlobExpression(entry->d_name,ModuleGlobExpression) == MagickFalse)
+    if (GlobExpression(entry->d_name,ModuleGlobExpression,MagickFalse) == MagickFalse)
       {
         entry=readdir(directory);
         continue;
       }
-    if (GlobExpression(entry->d_name,pattern) == MagickFalse)
+    if (GlobExpression(entry->d_name,pattern,MagickFalse) == MagickFalse)
       continue;
     if (i >= (long) max_entries)
       {
