@@ -377,7 +377,6 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     status;
 
   MagickOffsetType
-    count,
     tiles;
 
   MagickStatusType
@@ -394,6 +393,9 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     geometry,
     extract_info;
 
+  size_t
+    extent;
+
   TypeMetric
     metrics;
 
@@ -647,10 +649,15 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       Set montage geometry.
     */
     montage->montage=AcquireString((char *) NULL);
-    count=1;
-    for (tile=0; tile < MagickMin((long) tiles_per_page,(long) number_images); tile++)
-      count+=strlen(image_list[tile]->filename)+1;
-    montage->directory=(char *) AcquireMagickMemory((size_t) count);
+    tile=0;
+    extent=1;
+    while (tile < MagickMin((long) tiles_per_page,(long) number_images))
+    {
+      extent+=strlen(image_list[tile]->filename)+1;
+      tile++;
+    }
+    montage->directory=(char *) AcquireMagickMemory(extent*
+      sizeof(*montage->directory));
     if ((montage->montage == (char *) NULL) ||
         (montage->directory == (char *) NULL))
       ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
@@ -666,11 +673,13 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       (metrics.ascent-metrics.descent+4)*number_lines+
       (montage_info->shadow != MagickFalse ? 4 : 0)),x_offset,y_offset);
     *montage->directory='\0';
-    for (tile=0; tile < MagickMin((long) tiles_per_page,(long) number_images); tile++)
+    tile=0;
+    while (tile < MagickMin((long) tiles_per_page,(long) number_images))
     {
       (void) ConcatenateMagickString(montage->directory,
-        image_list[tile]->filename,MaxTextExtent);
-      (void) ConcatenateMagickString(montage->directory,"\n",MaxTextExtent);
+        image_list[tile]->filename,extent);
+      (void) ConcatenateMagickString(montage->directory,"\n",extent);
+      tile++;
     }
     progress_monitor=SetImageProgressMonitor(montage,
       (MagickProgressMonitor) NULL,montage->client_data);
