@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -440,6 +440,8 @@ static const OptionInfo
     { "-resample", 1L },
     { "+resize", 0L },
     { "-resize", 1L },
+    { "+reverse", 0L },
+    { "-reverse", 0L },
     { "+roll", 0L },
     { "-roll", 1L },
     { "+rotate", 0L },
@@ -599,6 +601,7 @@ static const OptionInfo
     { "Atop", (long) AtopCompositeOp },
     { "Blend", (long) BlendCompositeOp },
     { "Bumpmap", (long) BumpmapCompositeOp },
+    { "ChangeMask", (long) ChangeMaskCompositeOp },
     { "Clear", (long) ClearCompositeOp },
     { "ColorBurn", (long) ColorBurnCompositeOp },
     { "ColorDodge", (long) ColorDodgeCompositeOp },
@@ -847,7 +850,12 @@ static const OptionInfo
     { "CompareOverlay", (long) CompareOverlayLayer },
     { "Dispose", (long) DisposeLayer },
     { "Optimize", (long) OptimizeLayer },
+    { "OptimizeFrame", (long) OptimizeImageLayer },
     { "OptimizePlus", (long) OptimizePlusLayer },
+    { "OptimizeTransparency", (long) OptimizeTransLayer },
+    { "RemoveDups", (long) RemoveDupsLayer },
+    { "RemoveZero", (long) RemoveZeroLayer },
+    { "Composite", (long) CompositeLayer },
     { (char *) NULL, (long) UndefinedLayer }
   },
   LineCapOptions[] =
@@ -984,16 +992,19 @@ static const OptionInfo
     { "combine", MagickTrue },
     { "composite", MagickTrue },
     { "crop", MagickTrue },
+    { "debug", MagickTrue },
     { "deconstruct", MagickTrue },
     { "delete", MagickTrue },
     { "flatten", MagickTrue },
     { "fx", MagickTrue },
     { "insert", MagickTrue },
+    { "limit", MagickTrue },
     { "map", MagickTrue },
     { "morph", MagickTrue },
     { "mosaic", MagickTrue },
     { "optimize", MagickTrue },
     { "process", MagickTrue },
+    { "quiet", MagickTrue },
     { "separate", MagickTrue },
     { "scene", MagickTrue },
     { "swap", MagickTrue },
