@@ -16,7 +16,7 @@
 %                                 July 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -114,7 +114,6 @@
 %
 %    o method: Choose either FloodfillMethod or FillToBorderMethod.
 %
-%
 */
 MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
   const DrawInfo *draw_info,const PixelPacket target,const long x_offset,
@@ -176,8 +175,8 @@ MagickExport MagickBooleanType ColorFloodfillImage(Image *image,
   /*
     Set floodfill color.
   */
-  segment_stack=(SegmentInfo *)
-    AcquireMagickMemory(MaxStacksize*sizeof(*segment_stack));
+  segment_stack=(SegmentInfo *) AcquireMagickMemory(MaxStacksize*
+    sizeof(*segment_stack));
   if (segment_stack == (SegmentInfo *) NULL)
     {
       floodplane_image=DestroyImage(floodplane_image);
@@ -667,7 +666,7 @@ MagickExport MagickBooleanType PaintOpaqueImageChannel(Image *image,
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      SetMagickPixelPacket(q,indexes+x,&pixel);
+      SetMagickPixelPacket(image,q,indexes+x,&pixel);
       if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
         {
           if ((channel & RedChannel) != 0)
@@ -777,7 +776,7 @@ MagickExport MagickBooleanType PaintTransparentImage(Image *image,
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      SetMagickPixelPacket(q,indexes+x,&pixel);
+      SetMagickPixelPacket(image,q,indexes+x,&pixel);
       if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
         q->opacity=opacity;
       q++;
