@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick image constitute methods.
+  MagickCore image constitute methods.
 */
-#ifndef _MAGICK_PIXEL_H
-#define _MAGICK_PIXEL_H
+#ifndef _MAGICKCORE_PIXEL_H
+#define _MAGICKCORE_PIXEL_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -24,31 +24,6 @@ extern "C" {
 
 #include <magick/constitute.h>
 
-typedef enum
-{
-  UndefinedQuantum,
-  AlphaQuantum,
-  BlackQuantum,
-  BlueQuantum,
-  CMYKAQuantum,
-  CMYKQuantum,
-  CyanQuantum,
-  GrayAlphaQuantum,
-  GrayQuantum,
-  GreenQuantum,
-  IndexAlphaQuantum,
-  IndexQuantum,
-  MagentaQuantum,
-  OpacityQuantum,
-  RedQuantum,
-  RGBAQuantum,
-  RGBOQuantum,
-  RGBQuantum,
-  YellowQuantum,
-  GrayPadQuantum,
-  RGBPadQuantum
-} QuantumType;
-
 typedef struct _LongPixelPacket
 {
   unsigned long
@@ -61,6 +36,9 @@ typedef struct _LongPixelPacket
 
 typedef struct _MagickPixelPacket
 {
+  ClassType
+    storage_class;
+
   ColorspaceType
     colorspace;
 
@@ -84,11 +62,8 @@ typedef struct _MagickPixelPacket
 extern MagickExport MagickBooleanType
   ExportImagePixels(const Image *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,void *,ExceptionInfo *),
-  ExportQuantumPixels(Image *,const QuantumType,const size_t,
-    const unsigned char *),
   ImportImagePixels(Image *,const long,const long,const unsigned long,
-    const unsigned long,const char *,const StorageType,const void *),
-  ImportQuantumPixels(Image *,const QuantumType,const size_t,unsigned char *);
+    const unsigned long,const char *,const StorageType,const void *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
