@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -121,24 +121,224 @@ MagickExport MagickBooleanType CloneImageProfiles(Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   C r e a t e s R G B I m a g e P r o f i l e                               %
+%   D e s t r o y I m a g e P r o f i l e s                                   %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  CreatesRGBImageProfile() adds a sRGB profile to the image.
+%  DestroyImageProfiles() releases memory associated with an image profile map.
 %
-%  The format of the CreatesRGBImageProfile method is:
+%  The format of the DestroyProfiles method is:
 %
-%      MagickBooleanType CreatesRGBImageProfile(Image *image)
+%      void DestroyImageProfiles(Image *image)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
 */
-MagickExport MagickBooleanType CreatesRGBImageProfile(Image *image)
+MagickExport void DestroyImageProfiles(Image *image)
+{
+  if (image->profiles != (SplayTreeInfo *) NULL)
+    image->profiles=DestroySplayTree((SplayTreeInfo *) image->profiles);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   G e t I m a g e P r o f i l e                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetImageProfile() gets a profile associated with an image by name.
+%
+%  The format of the GetImageProfile method is:
+%
+%      const StringInfo *GetImageProfile(const Image *image,const char *name)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o name: The profile name.
+%
+*/
+MagickExport const StringInfo *GetImageProfile(const Image *image,
+  const char *name)
+{
+  char
+    key[MaxTextExtent];
+
+  const StringInfo
+    *profile;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  if (image->profiles == (SplayTreeInfo *) NULL)
+    return((StringInfo *) NULL);
+  (void) CopyMagickString(key,name,MaxTextExtent);
+  profile=(const StringInfo *) GetValueFromSplayTree((SplayTreeInfo *)
+    image->profiles,key);
+  return(profile);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   G e t N e x t I m a g e P r o f i l e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetNextImageProfile() gets the next profile name for an image.
+%
+%  The format of the GetNextImageProfile method is:
+%
+%      char *GetNextImageProfile(const Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o hash_info: The hash info.
+%
+*/
+MagickExport char *GetNextImageProfile(const Image *image)
+{
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  if (image->profiles == (SplayTreeInfo *) NULL)
+    return((char *) NULL);
+  return((char *) GetNextKeyInSplayTree((SplayTreeInfo *) image->profiles));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   P r o f i l e I m a g e                                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ProfileImage() associates, applies, or removes an ICM, IPTC, or generic
+%  profile with/to/from an image.  If the profile is NULL, it is removed from
+%  the image otherwise added or applied.  Use a name of '*' and a profile of
+%  NULL to remove all profiles from the image.
+%
+%  ICC and ICM profiles are are handled as follows: If the image does not
+%  have an associated color profile, the one you provide is associated with the
+%  image and the image pixels are not transformed.  Otherwise, the colorspace
+%  transform defined by the existing and new profile are applied to the image
+%  pixels and the new profile is associated with the image.
+%
+%  The format of the ProfileImage method is:
+%
+%      MagickBooleanType ProfileImage(Image *image,const char *name,
+%        const void *datum,const size_t length,const MagickBooleanType clone)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o name: Name of profile to add or remove: ICC, IPTC, or generic profile.
+%
+%    o datum: The profile data.
+%
+%    o length: The length of the profile.
+%
+%    o clone: should be MagickFalse.
+%
+*/
+
+static MagickBooleanType SetAdobeRGB1998ImageProfile(Image *image)
+{
+  static unsigned char
+    AdobeRGB1998Profile[] =
+    {
+      0x00, 0x00, 0x02, 0x30, 0x41, 0x44, 0x42, 0x45, 0x02, 0x10, 0x00,
+      0x00, 0x6d, 0x6e, 0x74, 0x72, 0x52, 0x47, 0x42, 0x20, 0x58, 0x59,
+      0x5a, 0x20, 0x07, 0xd0, 0x00, 0x08, 0x00, 0x0b, 0x00, 0x13, 0x00,
+      0x33, 0x00, 0x3b, 0x61, 0x63, 0x73, 0x70, 0x41, 0x50, 0x50, 0x4c,
+      0x00, 0x00, 0x00, 0x00, 0x6e, 0x6f, 0x6e, 0x65, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0xf6, 0xd6, 0x00, 0x01, 0x00, 0x00, 0x00,
+      0x00, 0xd3, 0x2d, 0x41, 0x44, 0x42, 0x45, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0a,
+      0x63, 0x70, 0x72, 0x74, 0x00, 0x00, 0x00, 0xfc, 0x00, 0x00, 0x00,
+      0x32, 0x64, 0x65, 0x73, 0x63, 0x00, 0x00, 0x01, 0x30, 0x00, 0x00,
+      0x00, 0x6b, 0x77, 0x74, 0x70, 0x74, 0x00, 0x00, 0x01, 0x9c, 0x00,
+      0x00, 0x00, 0x14, 0x62, 0x6b, 0x70, 0x74, 0x00, 0x00, 0x01, 0xb0,
+      0x00, 0x00, 0x00, 0x14, 0x72, 0x54, 0x52, 0x43, 0x00, 0x00, 0x01,
+      0xc4, 0x00, 0x00, 0x00, 0x0e, 0x67, 0x54, 0x52, 0x43, 0x00, 0x00,
+      0x01, 0xd4, 0x00, 0x00, 0x00, 0x0e, 0x62, 0x54, 0x52, 0x43, 0x00,
+      0x00, 0x01, 0xe4, 0x00, 0x00, 0x00, 0x0e, 0x72, 0x58, 0x59, 0x5a,
+      0x00, 0x00, 0x01, 0xf4, 0x00, 0x00, 0x00, 0x14, 0x67, 0x58, 0x59,
+      0x5a, 0x00, 0x00, 0x02, 0x08, 0x00, 0x00, 0x00, 0x14, 0x62, 0x58,
+      0x59, 0x5a, 0x00, 0x00, 0x02, 0x1c, 0x00, 0x00, 0x00, 0x14, 0x74,
+      0x65, 0x78, 0x74, 0x00, 0x00, 0x00, 0x00, 0x43, 0x6f, 0x70, 0x79,
+      0x72, 0x69, 0x67, 0x68, 0x74, 0x20, 0x32, 0x30, 0x30, 0x30, 0x20,
+      0x41, 0x64, 0x6f, 0x62, 0x65, 0x20, 0x53, 0x79, 0x73, 0x74, 0x65,
+      0x6d, 0x73, 0x20, 0x49, 0x6e, 0x63, 0x6f, 0x72, 0x70, 0x6f, 0x72,
+      0x61, 0x74, 0x65, 0x64, 0x00, 0x00, 0x00, 0x64, 0x65, 0x73, 0x63,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x11, 0x41, 0x64, 0x6f,
+      0x62, 0x65, 0x20, 0x52, 0x47, 0x42, 0x20, 0x28, 0x31, 0x39, 0x39,
+      0x38, 0x29, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x58, 0x59, 0x5a, 0x20, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0xf3, 0x51, 0x00, 0x01, 0x00, 0x00, 0x00,
+      0x01, 0x16, 0xcc, 0x58, 0x59, 0x5a, 0x20, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x63, 0x75, 0x72, 0x76, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x01, 0x02, 0x33, 0x00, 0x00, 0x63, 0x75, 0x72, 0x76, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x02, 0x33, 0x00, 0x00,
+      0x63, 0x75, 0x72, 0x76, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x01, 0x02, 0x33, 0x00, 0x00, 0x58, 0x59, 0x5a, 0x20, 0x00, 0x00,
+      0x00, 0x00, 0x00, 0x00, 0x9c, 0x18, 0x00, 0x00, 0x4f, 0xa5, 0x00,
+      0x00, 0x04, 0xfc, 0x58, 0x59, 0x5a, 0x20, 0x00, 0x00, 0x00, 0x00,
+      0x00, 0x00, 0x34, 0x8d, 0x00, 0x00, 0xa0, 0x2c, 0x00, 0x00, 0x0f,
+      0x95, 0x58, 0x59, 0x5a, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+      0x26, 0x31, 0x00, 0x00, 0x10, 0x2f, 0x00, 0x00, 0xbe, 0x9c
+    };
+
+  StringInfo
+    *profile;
+
+  MagickBooleanType
+    status;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (GetImageProfile(image,"icm") != (const StringInfo *) NULL)
+    return(MagickFalse);
+  profile=AcquireStringInfo(sizeof(AdobeRGB1998Profile));
+  SetStringInfoDatum(profile,AdobeRGB1998Profile);
+  status=SetImageProfile(image,"icm",profile);
+  profile=DestroyStringInfo(profile);
+  return(status);
+}
+
+static MagickBooleanType SetsRGBImageProfile(Image *image)
 {
   static unsigned char
     sRGBProfile[] =
@@ -447,155 +647,6 @@ MagickExport MagickBooleanType CreatesRGBImageProfile(Image *image)
   profile=DestroyStringInfo(profile);
   return(status);
 }
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   D e s t r o y I m a g e P r o f i l e s                                   %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  DestroyImageProfiles() releases memory associated with an image profile map.
-%
-%  The format of the DestroyProfiles method is:
-%
-%      void DestroyImageProfiles(Image *image)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-*/
-MagickExport void DestroyImageProfiles(Image *image)
-{
-  if (image->profiles != (SplayTreeInfo *) NULL)
-    image->profiles=DestroySplayTree((SplayTreeInfo *) image->profiles);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   G e t I m a g e P r o f i l e                                             %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  GetImageProfile() gets a profile associated with an image by name.
-%
-%  The format of the GetImageProfile method is:
-%
-%      const StringInfo *GetImageProfile(const Image *image,const char *name)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o name: The profile name.
-%
-*/
-MagickExport const StringInfo *GetImageProfile(const Image *image,
-  const char *name)
-{
-  char
-    key[MaxTextExtent];
-
-  const StringInfo
-    *profile;
-
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if (image->profiles == (SplayTreeInfo *) NULL)
-    return((StringInfo *) NULL);
-  (void) CopyMagickString(key,name,MaxTextExtent);
-  LocaleLower(key);
-  profile=(const StringInfo *) GetValueFromSplayTree((SplayTreeInfo *)
-    image->profiles,key);
-  return(profile);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   G e t N e x t I m a g e P r o f i l e                                     %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  GetNextImageProfile() gets the next profile name for an image.
-%
-%  The format of the GetNextImageProfile method is:
-%
-%      char *GetNextImageProfile(const Image *image)
-%
-%  A description of each parameter follows:
-%
-%    o hash_info: The hash info.
-%
-*/
-MagickExport char *GetNextImageProfile(const Image *image)
-{
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  if (image->profiles == (SplayTreeInfo *) NULL)
-    return((char *) NULL);
-  return((char *) GetNextKeyInSplayTree((SplayTreeInfo *) image->profiles));
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   P r o f i l e I m a g e                                                   %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  ProfileImage() associates, applies, or removes an ICM, IPTC, or generic
-%  profile with/to/from an image.  If the profile is NULL, it is removed from
-%  the image otherwise added or applied.  Use a name of '*' and a profile of
-%  NULL to remove all profiles from the image.
-%
-%  ICC and ICM profiles are are handled as follows: If the image does not
-%  have an associated color profile, the one you provide is associated with the
-%  image and the image pixels are not transformed.  Otherwise, the colorspace
-%  transform defined by the existing and new profile are applied to the image
-%  pixels and the new profile is associated with the image.
-%
-%  The format of the ProfileImage method is:
-%
-%      MagickBooleanType ProfileImage(Image *image,const char *name,
-%        const void *datum,const size_t length,const MagickBooleanType clone)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-%    o name: Name of profile to add or remove: ICC, IPTC, or generic profile.
-%
-%    o datum: The profile data.
-%
-%    o length: The length of the profile.
-%
-%    o clone: should be MagickFalse.
-%
-*/
-
 #if defined(HasLCMS)
 #if defined(LCMS_VERSION) && (LCMS_VERSION > 1010)
 static int LCMSErrorHandler(int severity,const char *context)
@@ -657,16 +708,13 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
 
           value=GetImageProperty(image,"EXIF:ColorSpace");
           if (LocaleCompare(value,"1") != 0)
-            {
-              (void) CreatesRGBImageProfile(image);
-              (void) DeleteImageProperty(image,"EXIF:ColorSpace");
-            }
+            (void) SetsRGBImageProfile(image);
           value=GetImageProperty(image,"EXIF:InteroperabilityIndex");
           if (LocaleCompare(value,"R98.") != 0)
-            {
-              (void) CreatesRGBImageProfile(image);
-              (void) DeleteImageProperty(image,"EXIF:InteroperabilityIndex");
-            }
+            (void) SetsRGBImageProfile(image);
+          value=GetImageProperty(image,"EXIF:InteroperabilityIndex");
+          if (LocaleCompare(value,"R03.") != 0)
+            (void) SetAdobeRGB1998ImageProfile(image);
           icc_profile=GetImageProfile(image,"icc");
         }
       if ((icc_profile != (const StringInfo *) NULL) &&
@@ -1097,7 +1145,6 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
     image->profiles=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
       DestroyProfile);
   (void) CopyMagickString(key,name,MaxTextExtent);
-  LocaleLower(key);
   status=AddValueToSplayTree((SplayTreeInfo *) image->profiles,
     ConstantString(key),CloneStringInfo(profile));
   if ((status != MagickFalse) &&
