@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -408,6 +408,8 @@ static MagickBooleanType GetIPTCProperty(const Image *image,const char *key)
     length;
 
   profile=GetImageProfile(image,"iptc");
+  if (profile == (StringInfo *) NULL)
+    profile=GetImageProfile(image,"8bim");
   if (profile == (StringInfo *) NULL)
     return(MagickFalse);
   count=sscanf(key,"IPTC:%ld:%ld",&dataset,&record);
@@ -2564,7 +2566,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
       case '[':
       {
         char
-          property[MaxTextExtent];
+          pattern[MaxTextExtent];
 
         const char
           *key,
@@ -2588,10 +2590,10 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             depth--;
           if (depth <= 0)
             break;
-          property[i]=(*p++);
+          pattern[i]=(*p++);
         }
-        property[i]='\0';
-        value=GetImageProperty(image,property);
+        pattern[i]='\0';
+        value=GetImageProperty(image,pattern);
         if (value != (const char *) NULL)
           {
             length=strlen(value);
@@ -2609,7 +2611,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             break;
           }
         else
-          if (IsGlob(property) != MagickFalse)
+          if (IsGlob(pattern) != MagickFalse)
             {
               /*
                 Iterate over image properties.
@@ -2618,7 +2620,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
               key=GetNextImageProperty(image);
               while (key != (const char *) NULL)
               {
-                if (GlobExpression(property,key) != MagickFalse)
+                if (GlobExpression(key,pattern,MagickTrue) != MagickFalse)
                   {
                     value=GetImageProperty(image,key);
                     if (value != (const char *) NULL)
@@ -2640,7 +2642,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
                 key=GetNextImageProperty(image);
               }
             }
-        value=GetMagickProperty(text_info,image,property);
+        value=GetMagickProperty(text_info,image,pattern);
         if (value != (const char *) NULL)
           {
             length=strlen(value);
@@ -2658,7 +2660,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           }
         if (image_info == (ImageInfo *) NULL)
           break;
-        value=GetImageOption(image_info,property);
+        value=GetImageOption(image_info,pattern);
         if (value != (char *) NULL)
           {
             length=strlen(value);
