@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1585,8 +1585,7 @@ static CubeInfo *GetCubeInfo(const Image *image,
   /*
     Initialize dither resources.
   */
-  length=(size_t) (1 << ((IsAssociatedAlpha(image,cube_info) == MagickFalse ?
-    3 : 4)*(8-CacheShift)));
+  length=(size_t) (1UL << (4*(8-CacheShift)));
   cube_info->cache=(long *) AcquireMagickMemory(length*
     sizeof(*cube_info->cache));
   if (cube_info->cache == (long *) NULL)
@@ -2213,7 +2212,7 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
   if (posterize_image == (Image *) NULL)
     return(MagickFalse);
   l=1;
-  while ((l*l*l) < MagickMin((long) levels*levels*levels,MaxColormapSize+1))
+  while ((l*l*l) < MagickMin((long) levels*levels*levels,(long) MaxColormapSize+1))
     l++;
   status=SetImageExtent(posterize_image,(unsigned long) (l*l*l),1);
   if (status == MagickFalse)
