@@ -16,7 +16,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -177,7 +177,7 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
       offset.x=(MagickRealType) x*image->columns/resize_image->columns;
       pixel=InterpolatePixelColor(image,image_view,image->interpolate,
         offset.x-0.5,offset.y-0.5,exception);
-      SetPixelPacket(&pixel,q,resize_indexes+x);
+      SetPixelPacket(resize_image,&pixel,q,resize_indexes+x);
       q++;
     }
     if (SyncCacheView(resize_view) == MagickFalse)
@@ -1268,7 +1268,6 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
   const unsigned long rows,ExceptionInfo *exception)
