@@ -17,7 +17,7 @@
 %                                April 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -644,7 +644,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
 
 static inline long MagickAbsoluteValue(const long x)
 {
-  if (x < 0.0)
+  if (x < 0)
     return(-x);
   return(x);
 }
