@@ -17,7 +17,7 @@
 %                                  July 1992                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -46,6 +46,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/colorspace-private.h"
 #include "magick/composite.h"
 #include "magick/composite-private.h"
 #include "magick/decorate.h"
@@ -58,6 +59,7 @@
 #include "magick/memory_.h"
 #include "magick/list.h"
 #include "magick/monitor.h"
+#include "magick/pixel-private.h"
 #include "magick/quantum.h"
 #include "magick/shear.h"
 #include "magick/transform.h"
@@ -211,7 +213,6 @@ MagickExport Image *AffineTransformImage(const Image *image,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static inline void CropToFitImage(Image **image,const MagickRealType x_shear,
   const MagickRealType y_shear,const MagickRealType width,
@@ -324,6 +325,9 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
   MagickBooleanType
     status;
 
+  MagickPixelPacket
+    pixel;
+
   RectangleInfo
     page;
 
@@ -357,6 +361,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
   /*
     Integral rotate the image.
   */
+  GetMagickPixelPacket(image,&pixel);
   switch (rotations)
   {
     case 0:
@@ -370,13 +375,15 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
         q=SetImagePixels(rotate_image,0,y,rotate_image->columns,1);
         if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
           break;
-        (void) CopyMagickMemory(q,p,(size_t) image->columns*sizeof(*q));
         indexes=GetIndexes(image);
         rotate_indexes=GetIndexes(rotate_image);
-        if ((indexes != (IndexPacket *) NULL) &&
-            (rotate_indexes != (IndexPacket *) NULL))
-          (void) CopyMagickMemory(rotate_indexes,indexes,(size_t)
-            image->columns*sizeof(*rotate_indexes));
+        for (x=0; x < (long) image->columns; x++)
+        {
+          SetMagickPixelPacket(image,p,indexes+x,&pixel);
+          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
+          p++;
+          q++;
+        }
         if (SyncImagePixels(rotate_image) == MagickFalse)
           break;
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -402,13 +409,15 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
           rotate_image->rows);
         if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
           break;
-        (void) CopyMagickMemory(q,p,(size_t) image->columns*sizeof(*q));
         indexes=GetIndexes(image);
         rotate_indexes=GetIndexes(rotate_image);
-        if ((indexes != (IndexPacket *) NULL) &&
-            (rotate_indexes != (IndexPacket *) NULL))
-          (void) CopyMagickMemory(rotate_indexes,indexes,(size_t)
-            image->columns*sizeof(*rotate_indexes));
+        for (x=0; x < (long) image->columns; x++)
+        {
+          SetMagickPixelPacket(image,p,indexes+x,&pixel);
+          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
+          p++;
+          q++;
+        }
         if (SyncImagePixels(rotate_image) == MagickFalse)
           break;
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -441,12 +450,14 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
         q+=image->columns;
         indexes=GetIndexes(image);
         rotate_indexes=GetIndexes(rotate_image);
-        if ((indexes != (IndexPacket *) NULL) &&
-            (rotate_indexes != (IndexPacket *) NULL))
-          for (x=0; x < (long) image->columns; x++)
-            rotate_indexes[image->columns-x-1]=indexes[x];
         for (x=0; x < (long) image->columns; x++)
-          *--q=(*p++);
+        {
+          q--;
+          SetMagickPixelPacket(image,p,indexes+x,&pixel);
+          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+(image->columns-
+            x-1));
+          p++;
+        }
         if (SyncImagePixels(rotate_image) == MagickFalse)
           break;
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -476,14 +487,16 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
         if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
           break;
         q+=image->columns;
-        for (x=0; x < (long) image->columns; x++)
-          *--q=(*p++);
         indexes=GetIndexes(image);
         rotate_indexes=GetIndexes(rotate_image);
-        if ((indexes != (IndexPacket *) NULL) &&
-            (rotate_indexes != (IndexPacket *) NULL))
-          for (x=0; x < (long) image->columns; x++)
-            rotate_indexes[image->columns-x-1]=indexes[x];
+        for (x=0; x < (long) image->columns; x++)
+        {
+          q--;
+          SetMagickPixelPacket(image,p,indexes+x,&pixel);
+          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+(image->columns-
+            x-1));
+          p++;
+        }
         if (SyncImagePixels(rotate_image) == MagickFalse)
           break;
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -547,9 +560,10 @@ static inline MagickRealType Blend_(const MagickRealType p,
   return((1.0-QuantumScale*alpha)*p+(1.0-QuantumScale*beta)*q);
 }
 
-static inline void MagickCompositeBlend(const PixelPacket *p,
-  const MagickRealType alpha,const PixelPacket *q,const MagickRealType beta,
-  const MagickRealType area,PixelPacket *composite)
+static inline void MagickCompositeBlend(const MagickPixelPacket *p,
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,const MagickRealType area,
+  MagickPixelPacket *composite)
 {
   MagickRealType
     gamma;
@@ -562,20 +576,25 @@ static inline void MagickCompositeBlend(const PixelPacket *p,
   gamma=RoundToUnity((1.0-QuantumScale*(QuantumRange-(1.0-area)*
     (QuantumRange-alpha)))+(1.0-QuantumScale*(QuantumRange-area*
     (QuantumRange-beta))));
-  composite->opacity=RoundToQuantum((MagickRealType) QuantumRange*(1.0-gamma));
+  composite->opacity=(MagickRealType) QuantumRange*(1.0-gamma);
   gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
-  composite->red=RoundToQuantum(gamma*Blend_((MagickRealType) p->red,
+  composite->red=gamma*Blend_((MagickRealType) p->red,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
     (MagickRealType) q->red,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta)));
-  composite->green=RoundToQuantum(gamma*Blend_((MagickRealType) p->green,
+    beta));
+  composite->green=gamma*Blend_((MagickRealType) p->green,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
     (MagickRealType) q->green,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta)));
-  composite->blue=RoundToQuantum(gamma*Blend_((MagickRealType) p->blue,
+    beta));
+  composite->blue=gamma*Blend_((MagickRealType) p->blue,
     (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
     (MagickRealType) q->blue,(MagickRealType) QuantumRange-area*(QuantumRange-
-    beta)));
+    beta));
+  if (q->colorspace == CMYKColorspace)
+    composite->index=gamma*Blend_((MagickRealType) p->index,
+      (MagickRealType) QuantumRange-(1.0-area)*(QuantumRange-alpha),
+      (MagickRealType) q->index,(MagickRealType) QuantumRange-area*
+      (QuantumRange-beta));
 }
 
 static void XShearImage(Image *image,const MagickRealType degrees,
@@ -587,6 +606,10 @@ static void XShearImage(Image *image,const MagickRealType degrees,
   enum {LEFT, RIGHT}
     direction;
 
+  IndexPacket
+    *indexes,
+    *shear_indexes;
+
   long
     step,
     y;
@@ -594,13 +617,16 @@ static void XShearImage(Image *image,const MagickRealType degrees,
   MagickBooleanType
     status;
 
+  MagickPixelPacket
+    background,
+    pixel,
+    source,
+    destination;
+
   MagickRealType
     area,
     displacement;
 
-  PixelPacket
-    pixel;
-
   register long
     i;
 
@@ -629,7 +655,14 @@ static void XShearImage(Image *image,const MagickRealType degrees,
     step=(long) floor((double) displacement);
     area=(MagickRealType) (displacement-step);
     step++;
-    pixel=image->background_color;
+    GetMagickPixelPacket(image,&background);
+    SetMagickPixelPacket(image,&image->background_color,(IndexPacket *) NULL,
+      &background);
+    if (image->colorspace == CMYKColorspace)
+      RGBtoCMYK(&background);
+    pixel=background;
+    GetMagickPixelPacket(image,&source);
+    GetMagickPixelPacket(image,&destination);
     switch (direction)
     {
       case LEFT:
@@ -643,26 +676,30 @@ static void XShearImage(Image *image,const MagickRealType degrees,
         if (p == (PixelPacket *) NULL)
           break;
         p+=x_offset;
+        indexes=GetIndexes(image);
+        indexes+=x_offset;
         q=p-step;
+        shear_indexes=indexes-step;
         for (i=0; i < (long) width; i++)
         {
           if ((x_offset+i) < step)
             {
-              pixel=(*++p);
+              SetMagickPixelPacket(image,++p,++indexes,&pixel);
               q++;
+              shear_indexes++;
               continue;
             }
-          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
-            (MagickRealType) p->opacity,area,q);
-          q++;
-          pixel=(*p++);
+          SetMagickPixelPacket(image,p,indexes,&source);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&source,
+            (MagickRealType) p->opacity,area,&destination);
+          SetPixelPacket(image,&destination,q++,shear_indexes++);
+          SetMagickPixelPacket(image,p++,indexes++,&pixel);
         }
-        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
-          &image->background_color,(MagickRealType)
-          image->background_color.opacity,area,q);
-        q++;
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&background,
+          (MagickRealType) background.opacity,area,&destination);
+        SetPixelPacket(image,&destination,q++,shear_indexes++);
         for (i=0; i < (step-1); i++)
-          *q++=image->background_color;
+          SetPixelPacket(image,&background,q++,shear_indexes++);
         break;
       }
       case RIGHT:
@@ -674,23 +711,29 @@ static void XShearImage(Image *image,const MagickRealType degrees,
         if (p == (PixelPacket *) NULL)
           break;
         p+=x_offset+width;
+        indexes=GetIndexes(image);
+        indexes+=x_offset+width;
         q=p+step;
+        shear_indexes=indexes+step;
         for (i=0; i < (long) width; i++)
         {
           p--;
+          indexes--;
           q--;
+          shear_indexes--;
           if ((unsigned long) (x_offset+width+step-i) >= image->columns)
             continue;
-          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
-            (MagickRealType) p->opacity,area,q);
-          pixel=(*p);
+          SetMagickPixelPacket(image,p,indexes,&source);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&source,
+            (MagickRealType) p->opacity,area,&destination);
+          SetPixelPacket(image,&destination,q,shear_indexes);
+          SetMagickPixelPacket(image,p,indexes,&pixel);
         }
-        q--;
-        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
-          &image->background_color,(MagickRealType)
-          image->background_color.opacity,area,q);
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&background,
+          (MagickRealType) background.opacity,area,&destination);
+        SetPixelPacket(image,&destination,--q,--shear_indexes);
         for (i=0; i < (step-1); i++)
-          *--q=image->background_color;
+          SetPixelPacket(image,&background,--q,--shear_indexes);
         break;
       }
     }
@@ -740,7 +783,6 @@ static void XShearImage(Image *image,const MagickRealType degrees,
 %    o width, height, x_offset, y_offset: Defines a region of the image
 %      to shear.
 %
-%
 */
 static void YShearImage(Image *image,const MagickRealType degrees,
   const unsigned long width,const unsigned long height,long x_offset,
@@ -751,6 +793,10 @@ static void YShearImage(Image *image,const MagickRealType degrees,
   enum {UP, DOWN}
     direction;
 
+  IndexPacket
+    *indexes,
+    *shear_indexes;
+
   long
     step,
     y;
@@ -758,6 +804,12 @@ static void YShearImage(Image *image,const MagickRealType degrees,
   MagickBooleanType
     status;
 
+  MagickPixelPacket
+    background,
+    pixel,
+    source,
+    destination;
+
   MagickRealType
     area,
     displacement;
@@ -769,9 +821,6 @@ static void YShearImage(Image *image,const MagickRealType degrees,
   register long
     i;
 
-  PixelPacket
-    pixel;
-
   assert(image != (Image *) NULL);
   x_offset--;
   for (y=0; y < (long) width; y++)
@@ -790,7 +839,14 @@ static void YShearImage(Image *image,const MagickRealType degrees,
     step=(long) floor((double) displacement);
     area=(MagickRealType) (displacement-step);
     step++;
-    pixel=image->background_color;
+    GetMagickPixelPacket(image,&background);
+    SetMagickPixelPacket(image,&image->background_color,(IndexPacket *) NULL,
+      &background);
+    if (image->colorspace == CMYKColorspace)
+      RGBtoCMYK(&background);
+    pixel=background;
+    GetMagickPixelPacket(image,&source);
+    GetMagickPixelPacket(image,&destination);
     switch (direction)
     {
       case UP:
@@ -804,26 +860,30 @@ static void YShearImage(Image *image,const MagickRealType degrees,
         if (p == (PixelPacket *) NULL)
           break;
         p+=y_offset;
+        indexes=GetIndexes(image);
+        indexes+=y_offset;
         q=p-step;
+        shear_indexes=indexes-step;
         for (i=0; i < (long) height; i++)
         {
           if ((y_offset+i) < step)
             {
-              pixel=(*++p);
+              SetMagickPixelPacket(image,++p,++indexes,&pixel);
               q++;
+              shear_indexes++;
               continue;
             }
-          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
-            (MagickRealType) p->opacity,area,q);
-          q++;
-          pixel=(*p++);
+          SetMagickPixelPacket(image,p,indexes,&source);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&source,
+            (MagickRealType) p->opacity,area,&destination);
+          SetPixelPacket(image,&destination,q++,shear_indexes++);
+          SetMagickPixelPacket(image,p++,indexes++,&pixel);
         }
-        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
-          &image->background_color,(MagickRealType)
-          image->background_color.opacity,area,q);
-        q++;
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&background,
+          (MagickRealType) background.opacity,area,&destination);
+        SetPixelPacket(image,&destination,q++,shear_indexes++);
         for (i=0; i < (step-1); i++)
-          *q++=image->background_color;
+          SetPixelPacket(image,&background,q++,shear_indexes++);
         break;
       }
       case DOWN:
@@ -835,23 +895,29 @@ static void YShearImage(Image *image,const MagickRealType degrees,
         if (p == (PixelPacket *) NULL)
           break;
         p+=y_offset+height;
+        indexes=GetIndexes(image);
+        indexes+=y_offset+height;
         q=p+step;
+        shear_indexes=indexes+step;
         for (i=0; i < (long) height; i++)
         {
           p--;
+          indexes--;
           q--;
+          shear_indexes--;
           if ((unsigned long) (y_offset+height+step-i) >= image->rows)
             continue;
-          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,p,
-            (MagickRealType) p->opacity,area,q);
-          pixel=(*p);
+          SetMagickPixelPacket(image,p,indexes,&source);
+          MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&source,
+            (MagickRealType) p->opacity,area,&destination);
+          SetPixelPacket(image,&destination,q,shear_indexes);
+          SetMagickPixelPacket(image,p,indexes,&pixel);
         }
-        q--;
-        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,
-          &image->background_color,(MagickRealType)
-          image->background_color.opacity,area,q);
+        MagickCompositeBlend(&pixel,(MagickRealType) pixel.opacity,&background,
+          (MagickRealType) background.opacity,area,&destination);
+        SetPixelPacket(image,&destination,--q,--shear_indexes);
         for (i=0; i < (step-1); i++)
-          *--q=image->background_color;
+          SetPixelPacket(image,&background,--q,--shear_indexes);
         break;
       }
     }
@@ -984,7 +1050,7 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
     Surround image with a border.
   */
   integral_image->border_color=integral_image->background_color;
-  integral_image->compose=OverCompositeOp;
+  integral_image->compose=CopyCompositeOp;
   border_info.width=(unsigned long) x_offset;
   border_info.height=(unsigned long) y_offset;
   rotate_image=BorderImage(integral_image,&border_info,exception);
@@ -1002,6 +1068,7 @@ MagickExport Image *RotateImage(const Image *image,const double degrees,
     ((long) rotate_image->columns-y_width)/2,0);
   CropToFitImage(&rotate_image,shear.x,shear.y,(MagickRealType) width,
     (MagickRealType) height,MagickTrue,exception);
+  rotate_image->compose=image->compose;
   rotate_image->page.width=0;
   rotate_image->page.height=0;
   return(rotate_image);
@@ -1107,7 +1174,7 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
     Surround image with border.
   */
   integral_image->border_color=integral_image->background_color;
-  integral_image->compose=OverCompositeOp;
+  integral_image->compose=CopyCompositeOp;
   border_info.width=(unsigned long) x_offset;
   border_info.height=(unsigned long) y_offset;
   shear_image=BorderImage(integral_image,&border_info,exception);
@@ -1125,6 +1192,7 @@ MagickExport Image *ShearImage(const Image *image,const double x_shear,
     ((long) shear_image->columns-y_width)/2,y_offset);
   CropToFitImage(&shear_image,shear.x,shear.y,(MagickRealType) image->columns,
     (MagickRealType) image->rows,MagickFalse,exception);
+  shear_image->compose=image->compose;
   shear_image->page.width=0;
   shear_image->page.height=0;
   return(shear_image);
