@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -149,13 +149,13 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   p=AcquireImagePixels(image,0,0,1,1,exception);
   if (p == (const PixelPacket *) NULL)
     return(bounds);
-  SetMagickPixelPacket(p,GetIndexes(image),&target[0]);
+  SetMagickPixelPacket(image,p,GetIndexes(image),&target[0]);
   GetMagickPixelPacket(image,&target[1]);
   p=AcquireImagePixels(image,(long) image->columns-1,0,1,1,exception);
-  SetMagickPixelPacket(p,GetIndexes(image),&target[1]);
+  SetMagickPixelPacket(image,p,GetIndexes(image),&target[1]);
   GetMagickPixelPacket(image,&target[2]);
   p=AcquireImagePixels(image,0,(long) image->rows-1,1,1,exception);
-  SetMagickPixelPacket(p,GetIndexes(image),&target[2]);
+  SetMagickPixelPacket(image,p,GetIndexes(image),&target[2]);
   GetMagickPixelPacket(image,&pixel);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -165,7 +165,7 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      SetMagickPixelPacket(p,indexes+x,&pixel);
+      SetMagickPixelPacket(image,p,indexes+x,&pixel);
       if ((x < bounds.x) &&
           (IsMagickColorSimilar(&pixel,&target[0]) == MagickFalse))
         bounds.x=x;
