@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -402,6 +402,16 @@ static void DestroyPixelStream(Image *image)
       return;
     }
   RelinquishStreamPixels(cache_info);
+  if (cache_info->nexus_info != (NexusInfo *) NULL)
+    {
+      register long
+        id;
+
+      for (id=0; id < (long) cache_info->number_views; id++)
+        DestroyCacheNexus(cache_info,(unsigned long) id);
+      cache_info->nexus_info=(NexusInfo *) RelinquishMagickMemory(
+        cache_info->nexus_info);
+    }
   RelinquishSemaphoreInfo(cache_info->semaphore);
   cache_info->semaphore=DestroySemaphoreInfo(cache_info->semaphore);
   cache_info=(CacheInfo *) RelinquishMagickMemory(cache_info);
