@@ -112,7 +112,7 @@ static const unsigned char
 static inline size_t CheckOverflowException(const size_t length,
   const size_t extend)
 {
-  if ((length+extend) < length)
+  if (~length < extend)
     {
       char
         *message;
@@ -770,8 +770,6 @@ MagickExport size_t CopyMagickString(char *destination,const char *source,
 */
 MagickExport char *DestroyString(char *string)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
-  assert(string != (char *) NULL);
   return((char *) RelinquishMagickMemory(string));
 }
 
