@@ -17,7 +17,7 @@
 %                                 October 1996                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1097,7 +1097,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
 
     p = strchr(threshold_map,',');
     if ( p != (char *)NULL && isdigit((int) ((unsigned char) *(++p))) )
-      levels.index = strtol(p, &p, 10);
+      levels.index = 1UL*strtol(p, &p, 10);
     else
       levels.index = 2;
 
