@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -133,7 +133,7 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
       ((chop_info->y+(long) chop_info->height) < 0) ||
       (chop_info->x > (long) image->columns) ||
       (chop_info->y > (long) image->rows))
-    ThrowImageException(OptionError,"GeometryDoesNotContainImage");
+    ThrowImageException(OptionWarning,"GeometryDoesNotContainImage");
   extent=(*chop_info);
   if ((extent.x+(long) extent.width) > (long) image->columns)
     extent.width=(unsigned long) ((long) image->columns-extent.x);
@@ -1172,7 +1172,7 @@ MagickExport Image *ShaveImage(const Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (((2*shave_info->width) >= image->columns) ||
       ((2*shave_info->height) >= image->rows))
-    ThrowImageException(OptionError,"GeometryDoesNotContainImage");
+    ThrowImageException(OptionWarning,"GeometryDoesNotContainImage");
   SetGeometry(image,&geometry);
   geometry.width-=2*shave_info->width;
   geometry.height-=2*shave_info->height;
@@ -1260,7 +1260,7 @@ MagickExport Image *SpliceImage(const Image *image,
   assert(exception->signature == MagickSignature);
   if ((geometry->x < 0) || (geometry->x > (long) image->columns) ||
       (geometry->y < 0) || (geometry->y > (long) image->rows))
-     ThrowImageException(OptionError,"GeometryDoesNotContainImage");
+     ThrowImageException(OptionWarning,"GeometryDoesNotContainImage");
   splice_geometry=(*geometry);
   splice_image=CloneImage(image,image->columns+splice_geometry.width,
     image->rows+splice_geometry.height,MagickTrue,exception);
@@ -1891,6 +1891,7 @@ MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
         return((Image *) NULL);
       crop_image->background_color.opacity=TransparentOpacity;
       (void) SetImageBackgroundColor(crop_image);
+      crop_image->page=image->page;
       crop_image->page.x=(-1);
       crop_image->page.y=(-1);
       return(crop_image);
