@@ -17,7 +17,7 @@
 %                              January 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1176,7 +1176,6 @@ MagickExport MagickBooleanType IsAccessible(const char *path)
 %
 %   o  path:  The directory path.
 %
-%
 */
 static int IsDirectory(const char *path)
 {
@@ -1347,7 +1346,7 @@ MagickExport char **ListFiles(const char *directory,const char *pattern,
         continue;
       }
     if ((IsDirectory(entry->d_name) > 0) ||
-        (GlobExpression(entry->d_name,pattern) != MagickFalse))
+        (GlobExpression(entry->d_name,pattern,MagickFalse) != MagickFalse))
       {
         if (*number_entries >= max_entries)
           {
