@@ -29,7 +29,7 @@ extern "C" {
 #define MagickCopyright  "Copyright (C) 1999-2007 ImageMagick Studio LLC"
 #define MagickLibVersion  0x633
 #define MagickLibVersionText  "6.3.3"
-#define MagickLibVersionNumber  6,3,3,0
+#define MagickLibVersionNumber  6,3,3,9
 #if (QuantumDepth == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -46,10 +46,10 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "03/02/07"
+#define MagickReleaseDate  "04/20/07"
 #define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " " MagickHomeURL
-#define MagickHomeURL  "http://www.imagemagick.org"
+  MagickReleaseDate " " MagickQuantumDepth " http://www.imagemagick.org"
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.3.3/index.html"
 
 extern MagickExport char
   *GetMagickHomeURL(void);
