@@ -185,7 +185,7 @@ int main ( int argc, char **argv )
    * Read original image
    */
   GetExceptionInfo( &exception );
-  imageInfo->dither = 0;
+  imageInfo->dither = MagickFalse;
   (void) strncpy( imageInfo->filename, infile, MaxTextExtent-1 );
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                         "Reading image %s", imageInfo->filename);
@@ -246,7 +246,7 @@ int main ( int argc, char **argv )
   if (strchr(map,'c') || strchr(map,'C') || strchr(map,'m') || strchr(map,'M') ||
       strchr(map,'y') || strchr(map,'y') || strchr(map,'k') || strchr(map,'k'))
     original->colorspace=CMYKColorspace;
-  SetImageBackgroundColor(original);
+  (void) SetImageBackgroundColor(original);
 
   status = ImportImagePixels(original,0,0,columns,rows,map,storage_type,pixels);
   if ( status == MagickFalse)
@@ -281,7 +281,7 @@ int main ( int argc, char **argv )
                         "Reading image from pixel array");
   final = AllocateImage((ImageInfo *) NULL);
   SetImageExtent(final,columns,rows);
-  SetImageBackgroundColor(final);
+  (void) SetImageBackgroundColor(final);
   status = ImportImagePixels(final,0,0,columns,rows,map,storage_type,pixels);
   if ( status == MagickFalse)
     {
