@@ -94,7 +94,7 @@ int main ( int argc, char **argv )
               if (LocaleCompare("LZW",option) == 0)
                 imageInfo->compression=LZWCompression;
               if (LocaleCompare("RLE",option) == 0)
-                imageInfo->compression=RunlengthEncodedCompression;
+                imageInfo->compression=RLECompression;
               if (LocaleCompare("Zip",option) == 0)
                 imageInfo->compression=ZipCompression;
             }
@@ -190,7 +190,7 @@ int main ( int argc, char **argv )
   size[0]='\0';
   magick_info=GetMagickInfo(format,&exception);
   if (magick_info && magick_info->raw)
-    FormatString( size, "%dx%d", columns, rows );
+    FormatMagickString( size, MaxTextExtent, "%dx%d", columns, rows );
 
   /*
    * Save image to BLOB
