@@ -23,7 +23,7 @@
 #include <sys\types.h>
 #endif
 #include <time.h>
-#include <magick/ImageMagick.h>
+#include <magick/MagickCore.h>
 
 int main ( int argc, char **argv )
 {
@@ -91,7 +91,7 @@ int main ( int argc, char **argv )
               if (LocaleCompare("LZW",option) == 0)
                 imageInfo->compression=LZWCompression;
               if (LocaleCompare("RLE",option) == 0)
-                imageInfo->compression=RunlengthEncodedCompression;
+                imageInfo->compression=RLECompression;
               if (LocaleCompare("Zip",option) == 0)
                 imageInfo->compression=ZipCompression;
             }
@@ -186,7 +186,7 @@ int main ( int argc, char **argv )
   size[0] = '\0';
   magick_info=GetMagickInfo(format,&exception);
   if (magick_info && magick_info->raw)
-    FormatString( size, "%dx%d", columns, rows );
+    FormatMagickString( size, MaxTextExtent, "%dx%d", columns, rows );
 
   /*
    * Save image to file
@@ -301,7 +301,8 @@ int main ( int argc, char **argv )
      final =DestroyImage( final );
   final = (Image*)NULL;
 
-   imageInfo =DestroyImageInfo( imageInfo );
+  imageInfo =DestroyImageInfo( imageInfo );
+  DestroyExceptionInfo( &exception );
   DestroyMagick();
 
   if (pause)
