@@ -17,7 +17,7 @@
 %                                July 1992                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -117,18 +117,8 @@ int main(int argc,char **argv)
     option=argv[i];
     if ((strlen(option) == 1) || ((*option != '-') && (*option != '+')))
       continue;
-    if ((LocaleCompare("debug",option+1) == 0) && (i < (long) (argc-1)))
-      (void) SetLogEventMask(argv[++i]);
     if (LocaleCompare("regard-warnings",option+1) == 0)
       regard_warnings=MagickTrue;
-    if ((LocaleCompare("version",option+1) == 0) ||
-        (LocaleCompare("-version",option+1) == 0))
-      {
-        (void) fprintf(stdout,"Version: %s\n",
-          GetMagickVersion((unsigned long *) NULL));
-        (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-        exit(0);
-      }
   }
   image_info=AcquireImageInfo();
   status=AnimateImageCommand(image_info,argc,argv,(char **) NULL,&exception);
