@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -287,7 +287,7 @@ static void CompositeUsage(void)
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas (setting)",
       "-quality value       JPEG/MIFF/PNG compression level",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
@@ -418,6 +418,18 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 4)
     CompositeUsage();
   (void) ResetMagickMemory(&option_info,0,sizeof(CompositeOptions));
@@ -1310,7 +1322,12 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           break;
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("virtual-pixel",option+1) == 0)
           {
             long
