@@ -17,7 +17,7 @@
 %                                April 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -192,7 +192,7 @@ static void ConvertUsage(void)
       "-layers method       optimize or compare image layers",
       "-level value         adjust the level of image contrast",
       "-linear-stretch geometry",
-      "                     improve contrast by `stretching with saturation' the intensity range",
+      "                     improve contrast by `stretching with saturation'",
       "-median radius       apply a median filter to the image",
       "-modulate value      vary the brightness, saturation, and hue",
       "-monochrome          transform image to black and white",
@@ -275,6 +275,7 @@ static void ConvertUsage(void)
       "-morph value         morph an image sequence",
       "-mosaic              create a mosaic from an image sequence",
       "-process arguments   process the image with a custom image filter",
+      "-reverse             reverse image sequence",
       "-separate            separate an image channel into a grayscale image",
       "-write filename      write images to this file",
       (char *) NULL
@@ -335,7 +336,7 @@ static void ConvertUsage(void)
       "-pointsize value     font point size",
       "-preview type        image preview type",
       "-quality value       JPEG/MIFF/PNG compression level",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
@@ -462,6 +463,18 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 3)
     ConvertUsage();
   filename=(char *) NULL;
@@ -1455,7 +1468,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertException(OptionError,"MissingArgument",option);
             type=ParseMagickOption(MagickLayersOptions,MagickFalse,argv[i]);
             if (type < 0)
-              ThrowConvertException(OptionError,"UnrecognizedLayerType",
+              ThrowConvertException(OptionError,"UnrecognizedLayerMethod",
                 argv[i]);
             break;
           }
@@ -1951,6 +1964,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("reverse",option+1) == 0)
+          break;
         if (LocaleCompare("roll",option+1) == 0)
           {
             if (*option == '+')
@@ -2432,7 +2447,12 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
           break;
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("view",option+1) == 0)
           {
             if (*option == '+')
