@@ -19,13 +19,6 @@
 #include <time.h>
 #include <wand/MagickWand.h>
 
-#if !defined(True)
-# define True 1
-#endif
-
-#if !defined(False)
-# define False 0
-#endif
 static void ScribbleImage (Image *image)
 {
   DrawingWand
@@ -50,7 +43,7 @@ static void ScribbleImage (Image *image)
     DrawSetFillColor(draw_wand,color);
     DrawSetStrokeColor(draw_wand,color);
 
-    DrawSetStrokeAntialias(draw_wand,True);
+    DrawSetStrokeAntialias(draw_wand,MagickTrue);
     DrawSetStrokeLineCap(draw_wand,RoundCap);
     DrawSetStrokeLineJoin(draw_wand,RoundJoin);
 
@@ -74,7 +67,7 @@ static void ScribbleImage (Image *image)
       
       (void) PushDrawingWand(draw_wand);
       {
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,4.032);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -90,7 +83,7 @@ static void ScribbleImage (Image *image)
       
       (void) PushDrawingWand(draw_wand);
       {
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,9);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -120,7 +113,7 @@ static void ScribbleImage (Image *image)
           { 378.1,81.72 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,2.016);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -136,7 +129,7 @@ static void ScribbleImage (Image *image)
       
       (void) PushDrawingWand(draw_wand);
       {
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,3.024);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -168,7 +161,7 @@ static void ScribbleImage (Image *image)
           { 207.4,31.82 }, { 209.2,28.87 }, { 211.3,26.64},  { 213.8,25.13 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,3.024);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -184,7 +177,7 @@ static void ScribbleImage (Image *image)
       
       (void) PushDrawingWand(draw_wand);
       {
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,12.02);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -199,7 +192,7 @@ static void ScribbleImage (Image *image)
 
       (void) PushDrawingWand(draw_wand);
       {
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,9);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -221,7 +214,7 @@ static void ScribbleImage (Image *image)
           { 77.26,578.6 }, { 180,504 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,9);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -244,7 +237,7 @@ static void ScribbleImage (Image *image)
           { 77.26,578.6 }, { 148.2,568.3 }, { 180,504 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,9);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -268,7 +261,7 @@ static void ScribbleImage (Image *image)
           { 540,172.8 },   { 540,223.2 },   { 540,288 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,5.976);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -290,7 +283,7 @@ static void ScribbleImage (Image *image)
           { 151.2,756 }, { 86.4,748.8 }, { 57.6,640.8 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,5.976);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -359,7 +352,7 @@ static void ScribbleImage (Image *image)
           { 27.86,565.3 }
         };
         
-        DrawSetStrokeAntialias(draw_wand,True);
+        DrawSetStrokeAntialias(draw_wand,MagickTrue);
         DrawSetStrokeWidth(draw_wand,5.904);
         DrawSetStrokeLineCap(draw_wand,RoundCap);
         DrawSetStrokeLineJoin(draw_wand,RoundJoin);
@@ -410,7 +403,7 @@ int main ( int argc, char **argv )
   rows=842;
   image_info=CloneImageInfo((ImageInfo*)NULL);
   GetExceptionInfo( &exception );
-  FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
+  (void) FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
   (void) CloneString(&image_info->size,size);
   (void) CopyMagickString(image_info->filename,"xc:white",MaxTextExtent);
   canvas=ReadImage ( image_info, &exception );
