@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -256,6 +256,7 @@ extern WandExport MagickBooleanType
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
   MagickSetImageOpacity(MagickWand *,const double),
+  MagickSetImageOrientation(MagickWand *,const OrientationType),
   MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickResetImagePage(MagickWand *,const char *),
@@ -346,6 +347,9 @@ extern WandExport MagickWand
   *MagickTransformImage(MagickWand *,const char *,const char *),
   *NewMagickWandFromImage(const Image *);
 
+extern WandExport OrientationType
+  MagickGetImageOrientation(MagickWand *);
+
 extern WandExport PixelWand
   **MagickGetImageHistogram(MagickWand *,unsigned long *);
 
