@@ -153,12 +153,13 @@ static void MontageUsage(void)
       "-mattecolor color    frame color",
       "-mode type           framing style",
       "-monitor             monitor progress",
+      "-origin geometry     image origin",
       "-page geometry       size and location of an image canvas (setting)",
       "-pointsize value     font point size",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quantize colorspace reduce colors in this colorspace",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
@@ -297,6 +298,18 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 3)
    MontageUsage();
   format="%w,%h,%m";
@@ -1093,6 +1106,21 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           break;
         ThrowMontageException(OptionError,"UnrecognizedOption",option)
       }
+      case 'o':
+      {
+        if (LocaleCompare("origin",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowMontageInvalidArgumentException(option,argv[i]);
+            break;
+          }
+        ThrowMontageException(OptionError,"UnrecognizedOption",option)
+      }
       case 'p':
       {
         if (LocaleCompare("page",option+1) == 0)
@@ -1472,7 +1500,12 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
           }
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("virtual-pixel",option+1) == 0)
           {
             long
