@@ -267,7 +267,7 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
       message=GetExceptionMessage(errno);
       ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   (void) ResetMagickMemory(iterator,0,sizeof(*iterator));
   iterator->id=AcquireWandId();
@@ -390,7 +390,7 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
       message=GetExceptionMessage(errno);
       ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   (void) ResetMagickMemory(iterator,0,sizeof(*iterator));
   iterator->id=AcquireWandId();
@@ -529,7 +529,7 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
       message=GetExceptionMessage(errno);
       ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   *description='\0';
   if (iterator->exception.reason != (char *) NULL)
@@ -739,7 +739,7 @@ WandExport PixelWand **PixelGetPreviousIteratorRow(PixelIterator *iterator,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  PixelResetIterator() resets the pixel iterator.  Use it in conjunction
-%  with PixelGetNextPixel() to iterate over all the pixels in a pixel
+%  with PixelGetNextIteratorRow() to iterate over all the pixels in a pixel
 %  container.
 %
 %  The format of the PixelResetIterator method is:
