@@ -23,7 +23,7 @@
 %                                March 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -1575,9 +1575,8 @@ WandExport MagickBooleanType PixelSetColor(PixelWand *wand,const char *color)
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
   status=QueryMagickColor(color,&pixel,&wand->exception);
-  if (status == MagickFalse)
-    return(status);
-  wand->pixel=pixel;
+  if (status != MagickFalse)
+    wand->pixel=pixel;
   return(status);
 }
 
