@@ -17,7 +17,7 @@
 %                              July 1992                                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -110,7 +110,7 @@ static void StreamUsage(void)
       "-map components      one or more pixel components",
       "-monitor             monitor progress",
       "-quantize colorspace reduce colors in this colorspace",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
@@ -212,6 +212,18 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 3)
     StreamUsage();
   channel=AllChannels;
@@ -644,7 +656,12 @@ WandExport MagickBooleanType StreamImageCommand(ImageInfo *image_info,
           break;
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("virtual-pixel",option+1) == 0)
           {
             long
