@@ -23,7 +23,7 @@
 %                                 March 2003                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  This software and documentation is provided "as is," and the copyright     %
@@ -182,7 +182,7 @@ int main(int argc,char **argv)
     ThrowAPIException(magick_wand);
   MagickResetIterator(magick_wand);
   background=NewPixelWand();
-  (void) PixelSetColor(background,"#000000");
+  status=PixelSetColor(background,"#000000");
   if (status == MagickFalse)
     ThrowAPIException(magick_wand);
   status=MagickRotateImage(magick_wand,background,90.0);
